@@ -31,7 +31,6 @@ class Chef::Application::Apply < Chef::Application
 
   banner "Usage: chef-apply [RECIPE_FILE] [-e RECIPE_TEXT] [-s]"
 
-
   option :execute,
     :short        => "-e RECIPE_TEXT",
     :long         => "--execute RECIPE_TEXT",
@@ -44,6 +43,12 @@ class Chef::Application::Apply < Chef::Application
     :description  => "Execute resources read from STDIN",
     :boolean      => true
 
+  option :json_attribs,
+    :short => "-j JSON_ATTRIBS",
+    :long => "--json-attributes JSON_ATTRIBS",
+    :description => "Load attributes from a JSON file or URL",
+    :proc => nil
+
   option :log_level,
     :short        => "-l LEVEL",
     :long         => "--log_level LEVEL",
@@ -80,6 +85,13 @@ class Chef::Application::Apply < Chef::Application
     :default      => !Chef::Platform.windows?,
     :description  => "Use colored output, defaults to enabled"
 
+  option :minimal_ohai,
+    :long           => "--minimal-ohai",
+    :description    => "Only run the bare minimum ohai plugins chef needs to function",
+    :boolean        => true
+
+  attr_reader :json_attribs
+
   def initialize
     super
   end
@@ -88,22 +100,34 @@ class Chef::Application::Apply < Chef::Application
     parse_options
     Chef::Config.merge!(config)
     configure_logging
+    configure_proxy_environment_variables
+    parse_json
+  end
+
+  def parse_json
+    if Chef::Config[:json_attribs]
+      config_fetcher = Chef::ConfigFetcher.new(Chef::Config[:json_attribs])
+      @json_attribs = config_fetcher.fetch_json
+    end
   end
 
   def read_recipe_file(file_name)
-    recipe_path = file_name
-    unless File.exist?(recipe_path)
-      Chef::Application.fatal!("No file exists at #{recipe_path}", 1)
+    if file_name.nil?
+      Chef::Application.fatal!("No recipe file was provided", 1)
+    else
+      recipe_path = File.expand_path(file_name)
+      unless File.exist?(recipe_path)
+        Chef::Application.fatal!("No file exists at #{recipe_path}", 1)
+      end
+      recipe_fh = open(recipe_path)
+      recipe_text = recipe_fh.read
+      [recipe_text, recipe_fh]
     end
-    recipe_path = File.expand_path(recipe_path)
-    recipe_fh = open(recipe_path)
-    recipe_text = recipe_fh.read
-    [recipe_text, recipe_fh]
   end
 
   def get_recipe_and_run_context
     Chef::Config[:solo] = true
-    @chef_client = Chef::Client.new
+    @chef_client = Chef::Client.new(@json_attribs)
     @chef_client.run_ohai
     @chef_client.load_node
     @chef_client.build_node
@@ -133,6 +157,10 @@ class Chef::Application::Apply < Chef::Application
       @recipe_text = STDIN.read
       temp_recipe_file
     else
+      if !ARGV[0]
+        puts opt_parser
+        Chef::Application.exit! "No recipe file provided", 1
+      end
       @recipe_filename = ARGV[0]
       @recipe_text,@recipe_fh = read_recipe_file @recipe_filename
     end
