@@ -7,6 +7,8 @@ class Chef
         def normalize(user, entry)
           normalize_hash(user, {
             'name' => remove_dot_json(entry.name),
+            'username' => remove_dot_json(entry.name),
+            'display_name' => remove_dot_json(entry.name),
             'admin' => false,
             'json_class' => 'Chef::WebUIUser',
             'chef_type' => 'webui_user',
@@ -16,7 +18,7 @@ class Chef
           })
         end
 
-        def preserve_key(key)
+        def preserve_key?(key)
           return key == 'name'
         end
 
