@@ -25,9 +25,12 @@ class Chef
     # if not available, loading them from the remote server.
     class RemoteFileVendor < FileVendor
 
+      attr_reader :rest
+      attr_reader :cookbook_name
+
       def initialize(manifest, rest)
         @manifest = manifest
-        @cookbook_name = @manifest[:cookbook_name]
+        @cookbook_name = @manifest[:cookbook_name] || @manifest[:name]
         @rest = rest
       end
 
