@@ -20,12 +20,11 @@
 # limitations under the License.
 
 require 'chef/log'
-require 'chef/node'
-require 'chef/resource_definition_list'
-require 'chef/recipe'
 require 'chef/cookbook/file_vendor'
 require 'chef/cookbook/metadata'
 require 'chef/version_class'
+require 'chef/digester'
+require 'chef/cookbook_manifest'
 
 class Chef
 
@@ -34,15 +33,13 @@ class Chef
   # cookbook. Chef supports maintaining multiple versions of a cookbook on a
   # single server; each version is represented by a distinct instance of this
   # class.
-  #--
-  # TODO: timh/cw: 5-24-2010: mutators for files (e.g., recipe_filenames=,
-  # recipe_filenames.insert) should dirty the manifest so it gets regenerated.
   class CookbookVersion
+
     include Comparable
 
     COOKBOOK_SEGMENTS = [ :resources, :providers, :recipes, :definitions, :libraries, :attributes, :files, :templates, :root_files ]
 
-    attr_accessor :root_dir
+    attr_accessor :root_paths
     attr_accessor :definition_filenames
     attr_accessor :template_filenames
     attr_accessor :file_filenames
@@ -51,9 +48,22 @@ class Chef
     attr_accessor :provider_filenames
     attr_accessor :root_filenames
     attr_accessor :name
-    attr_accessor :metadata
     attr_accessor :metadata_filenames
-    attr_accessor :status
+
+    def status=(new_status)
+      Chef::Log.deprecation("Deprecated method `status' called from #{caller(1).first}. This method will be removed")
+      @status = new_status
+    end
+
+    def status
+      Chef::Log.deprecation("Deprecated method `status' called from #{caller(1).first}. This method will be removed")
+      @status
+    end
+
+    # A Chef::Cookbook::Metadata object. It has a setter that fixes up the
+    # metadata to add descriptions of the recipes contained in this
+    # CookbookVersion.
+    attr_reader :metadata
 
     # attribute_filenames also has a setter that has non-default
     # functionality.
@@ -66,6 +76,23 @@ class Chef
     attr_reader :recipe_filenames_by_name
     attr_reader :attribute_filenames_by_short_filename
 
+    attr_accessor :chef_server_rest
+
+    # The `identifier` field is used for cookbook_artifacts, which are
+    # organized on the chef server according to their content. If the
+    # policy_mode option to CookbookManifest is set to true it will include
+    # this field in the manifest Hash and in the upload URL.
+    #
+    # This field may be removed or have different behavior in the future, don't
+    # use it in 3rd party code.
+    # @api private
+    attr_accessor :identifier
+
+    # The first root path is the primary cookbook dir, from which metadata is loaded
+    def root_dir
+      root_paths[0]
+    end
+
     # This is the one and only method that knows how cookbook files'
     # checksums are generated.
     def self.checksum_cookbook_file(filepath)
@@ -83,9 +110,11 @@ class Chef
     #
     # === Returns
     # object<Chef::CookbookVersion>:: Duh. :)
-    def initialize(name)
+    def initialize(name, *root_paths, chef_server_rest: nil)
       @name = name
+      @root_paths = root_paths
       @frozen = false
+
       @attribute_filenames = Array.new
       @definition_filenames = Array.new
       @template_filenames = Array.new
@@ -96,12 +125,13 @@ class Chef
       @resource_filenames = Array.new
       @provider_filenames = Array.new
       @metadata_filenames = Array.new
-      @root_dir = nil
       @root_filenames = Array.new
+
+      # deprecated
       @status = :ready
-      @manifest = nil
       @file_vendor = nil
       @metadata = Chef::Cookbook::Metadata.new
+      @chef_server_rest = chef_server_rest
     end
 
     def version
@@ -120,73 +150,10 @@ class Chef
     end
 
     def version=(new_version)
-      manifest["version"] = new_version
+      cookbook_manifest.reset!
       metadata.version(new_version)
     end
 
-    # A manifest is a Mash that maps segment names to arrays of manifest
-    # records (see #preferred_manifest_record for format of manifest records),
-    # as well as describing cookbook metadata. The manifest follows a form
-    # like the following:
-    #
-    #   {
-    #     :cookbook_name = "apache2",
-    #     :version = "1.0",
-    #     :name = "Apache 2"
-    #     :metadata = ???TODO: timh/cw: 5-24-2010: describe this format,
-    #
-    #     :files => [
-    #       {
-    #         :name => "afile.rb",
-    #         :path => "files/ubuntu-9.10/afile.rb",
-    #         :checksum => "2222",
-    #         :specificity => "ubuntu-9.10"
-    #       },
-    #     ],
-    #     :templates => [ manifest_record1, ... ],
-    #     ...
-    #   }
-    def manifest
-      unless @manifest
-        generate_manifest
-      end
-      @manifest
-    end
-
-    def manifest=(new_manifest)
-      @manifest = Mash.new new_manifest
-      @checksums = extract_checksums_from_manifest(@manifest)
-      @manifest_records_by_path = extract_manifest_records_by_path(@manifest)
-
-      COOKBOOK_SEGMENTS.each do |segment|
-        next unless @manifest.has_key?(segment)
-        filenames = @manifest[segment].map{|manifest_record| manifest_record['name']}
-
-        if segment == :recipes
-          self.recipe_filenames = filenames
-        elsif segment == :attributes
-          self.attribute_filenames = filenames
-        else
-          segment_filenames(segment).clear
-          filenames.each { |filename| segment_filenames(segment) << filename }
-        end
-      end
-    end
-
-    # Returns a hash of checksums to either nil or the on disk path (which is
-    # done by generate_manifest).
-    def checksums
-      unless @checksums
-        generate_manifest
-      end
-      @checksums
-    end
-
-    def manifest_records_by_path
-      @manifest_records_by_path || generate_manifest
-      @manifest_records_by_path
-    end
-
     def full_name
       "#{name}-#{version}"
     end
@@ -197,10 +164,34 @@ class Chef
       attribute_filenames
     end
 
+    def metadata=(metadata)
+      @metadata = metadata
+      @metadata.recipes_from_cookbook_version(self)
+      @metadata
+    end
+
     ## BACKCOMPAT/DEPRECATED - Remove these and fix breakage before release [DAN - 5/20/2010]##
     alias :attribute_files :attribute_filenames
     alias :attribute_files= :attribute_filenames=
 
+    def manifest
+      cookbook_manifest.manifest
+    end
+
+    # Returns a hash of checksums to either nil or the on disk path (which is
+    # done by generate_manifest).
+    def checksums
+      cookbook_manifest.checksums
+    end
+
+    def manifest_records_by_path
+      cookbook_manifest.manifest_records_by_path
+    end
+
+    def manifest=(new_manifest)
+      cookbook_manifest.update_from(new_manifest)
+    end
+
     # Return recipe names in the form of cookbook_name::recipe_name
     def fully_qualified_recipe_names
       results = Array.new
@@ -265,6 +256,17 @@ class Chef
       end
     end
 
+    def replace_segment_filenames(segment, filenames)
+      case segment.to_sym
+      when :recipes
+        self.recipe_filenames = filenames
+      when :attributes
+        self.attribute_filenames = filenames
+      else
+        segment_filenames(segment).replace(filenames)
+      end
+    end
+
     # Query whether a template file +template_filename+ is available. File
     # specificity for the given +node+ is obeyed in the lookup.
     def has_template_for_node?(node, template_filename)
@@ -292,17 +294,24 @@ class Chef
     def preferred_manifest_record(node, segment, filename)
       found_pref = find_preferred_manifest_record(node, segment, filename)
       if found_pref
-        @manifest_records_by_path[found_pref]
+        manifest_records_by_path[found_pref]
       else
         if segment == :files || segment == :templates
           error_message = "Cookbook '#{name}' (#{version}) does not contain a file at any of these locations:\n"
-          error_locations = [
-            "  #{segment}/#{node[:platform]}-#{node[:platform_version]}/#{filename}",
-            "  #{segment}/#{node[:platform]}/#{filename}",
-            "  #{segment}/default/#{filename}",
-          ]
+          error_locations = if filename.is_a?(Array)
+            filename.map{|name| "  #{File.join(segment.to_s, name)}"}
+          else
+            [
+              "  #{segment}/#{node[:platform]}-#{node[:platform_version]}/#{filename}",
+              "  #{segment}/#{node[:platform]}/#{filename}",
+              "  #{segment}/default/#{filename}",
+              "  #{segment}/#{filename}",
+            ]
+          end
           error_message << error_locations.join("\n")
           existing_files = segment_filenames(segment)
+          # Strip the root_dir prefix off all files for readability
+          existing_files.map!{|path| path[root_dir.length+1..-1]} if root_dir
           # Show the files that the cookbook does have. If the user made a typo,
           # hopefully they'll see it here.
           unless existing_files.empty?
@@ -396,64 +405,56 @@ class Chef
       records_by_pref[best_pref]
     end
 
-
     # Given a node, segment and path (filename or directory name),
     # return the priority-ordered list of preference locations to
     # look.
     def preferences_for_path(node, segment, path)
       # only files and templates can be platform-specific
       if segment.to_sym == :files || segment.to_sym == :templates
-        begin
-          platform, version = Chef::Platform.find_platform_and_version(node)
-        rescue ArgumentError => e
-          # Skip platform/version if they were not found by find_platform_and_version
-          if e.message =~ /Cannot find a (?:platform|version)/
-            platform = "/unknown_platform/"
-            version = "/unknown_platform_version/"
-          else
-            raise
+        relative_search_path = if path.is_a?(Array)
+          path
+        else
+          begin
+            platform, version = Chef::Platform.find_platform_and_version(node)
+          rescue ArgumentError => e
+            # Skip platform/version if they were not found by find_platform_and_version
+            if e.message =~ /Cannot find a (?:platform|version)/
+              platform = "/unknown_platform/"
+              version = "/unknown_platform_version/"
+            else
+              raise
+            end
           end
+
+          fqdn = node[:fqdn]
+
+          # Break version into components, eg: "5.7.1" => [ "5.7.1", "5.7", "5" ]
+          search_versions = []
+          parts = version.to_s.split('.')
+
+          parts.size.times do
+            search_versions << parts.join('.')
+            parts.pop
+          end
+
+          # Most specific to least specific places to find the path
+          search_path = [ File.join("host-#{fqdn}", path) ]
+          search_versions.each do |v|
+            search_path << File.join("#{platform}-#{v}", path)
+          end
+          search_path << File.join(platform.to_s, path)
+          search_path << File.join("default", path)
+          search_path << path
+
+          search_path
         end
-
-        fqdn = node[:fqdn]
-
-        # Break version into components, eg: "5.7.1" => [ "5.7.1", "5.7", "5" ]
-        search_versions = []
-        parts = version.to_s.split('.')
-
-        parts.size.times do
-          search_versions << parts.join('.')
-          parts.pop
-        end
-
-        # Most specific to least specific places to find the path
-        search_path = [ File.join(segment.to_s, "host-#{fqdn}", path) ]
-        search_versions.each do |v|
-          search_path << File.join(segment.to_s, "#{platform}-#{v}", path)
-        end
-        search_path << File.join(segment.to_s, platform.to_s, path)
-        search_path << File.join(segment.to_s, "default", path)
-
-        search_path
+        relative_search_path.map {|relative_path| File.join(segment.to_s, relative_path)}
       else
         [File.join(segment, path)]
       end
     end
     private :preferences_for_path
 
-    def to_hash
-      result = manifest.dup
-      result['frozen?'] = frozen_version?
-      result['chef_type'] = 'cookbook_version'
-      result.to_hash
-    end
-
-    def to_json(*a)
-      result = self.to_hash
-      result['json_class'] = self.class.name
-      result.to_json(*a)
-    end
-
     def self.json_create(o)
       cookbook_version = new(o["cookbook_name"])
       # We want the Chef::Cookbook::Metadata object to always be inflated
@@ -461,13 +462,26 @@ class Chef
       cookbook_version.manifest = o
 
       # We don't need the following step when we decide to stop supporting deprecated operators in the metadata (e.g. <<, >>)
-      cookbook_version.manifest["metadata"] = Chef::JSONCompat.from_json(cookbook_version.metadata.to_json)
+      cookbook_version.manifest["metadata"] = Chef::JSONCompat.from_json(Chef::JSONCompat.to_json(cookbook_version.metadata))
 
       cookbook_version.freeze_version if o["frozen?"]
       cookbook_version
     end
 
+    def self.from_cb_artifact_data(o)
+      cookbook_version = new(o["name"])
+      # We want the Chef::Cookbook::Metadata object to always be inflated
+      cookbook_version.metadata = Chef::Cookbook::Metadata.from_hash(o["metadata"])
+      cookbook_version.manifest = o
+      cookbook_version.identifier = o["identifier"]
+      cookbook_version
+    end
+
+    # @deprecated This method was used by the Ruby Chef Server and is no longer
+    #   needed. There is no replacement.
     def generate_manifest_with_urls(&url_generator)
+      Chef::Log.deprecation("Deprecated method #generate_manifest_with_urls called from #{caller(1).first}")
+
       rendered_manifest = manifest.dup
       COOKBOOK_SEGMENTS.each do |segment|
         if rendered_manifest.has_key?(segment)
@@ -480,12 +494,24 @@ class Chef
       rendered_manifest
     end
 
+
+    def to_hash
+      # TODO: this should become deprecated when the API for CookbookManifest becomes stable
+      cookbook_manifest.to_hash
+    end
+
+    def to_json(*a)
+      # TODO: this should become deprecated when the API for CookbookManifest becomes stable
+      cookbook_manifest.to_json
+    end
+
+
     def metadata_json_file
-      File.join(root_dir, "metadata.json")
+      File.join(root_paths[0], "metadata.json")
     end
 
     def metadata_rb_file
-      File.join(root_dir, "metadata.rb")
+      File.join(root_paths[0], "metadata.rb")
     end
 
     def reload_metadata!
@@ -497,26 +523,23 @@ class Chef
     ##
     # REST API
     ##
-    def self.chef_server_rest
-      Chef::REST.new(Chef::Config[:chef_server_url])
+
+    def save_url
+      # TODO: this should become deprecated when the API for CookbookManifest becomes stable
+      cookbook_manifest.save_url
+    end
+
+    def force_save_url
+      # TODO: this should become deprecated when the API for CookbookManifest becomes stable
+      cookbook_manifest.force_save_url
     end
 
     def chef_server_rest
-      self.class.chef_server_rest
+      @chef_server_rest ||= self.chef_server_rest
     end
 
-    # Return the URL to save (PUT) this object to the server via the
-    # REST api. If there is an existing document on the server and it
-    # is marked frozen, a PUT will result in a 409 Conflict.
-    def save_url
-      "cookbooks/#{name}/#{version}"
-    end
-
-    # Adds the `force=true` parameter to the upload URL. This allows
-    # the user to overwrite a frozen cookbook (a PUT against the
-    # normal #save_url raises a 409 Conflict in this case).
-    def force_save_url
-      "cookbooks/#{name}/#{version}?force=true"
+    def self.chef_server_rest
+      Chef::REST.new(Chef::Config[:chef_server_url])
     end
 
     def destroy
@@ -534,6 +557,11 @@ class Chef
       chef_server_rest.get_rest('cookbooks')
     end
 
+    # Alias latest_cookbooks as list
+    class << self
+      alias :latest_cookbooks :list
+    end
+
     def self.list_all_versions
       chef_server_rest.get_rest('cookbooks?num_versions=all')
     end
@@ -557,11 +585,6 @@ class Chef
       end
     end
 
-    # Get the newest version of all cookbooks
-    def self.latest_cookbooks
-      chef_server_rest.get_rest('cookbooks/_latest')
-    end
-
     def <=>(o)
       raise Chef::Exceptions::CookbookVersionNameMismatch if self.name != o.name
       # FIXME: can we change the interface to the Metadata class such
@@ -572,15 +595,15 @@ class Chef
 
     private
 
+    def cookbook_manifest
+      @cookbook_manifest ||= CookbookManifest.new(self)
+    end
+
     def find_preferred_manifest_record(node, segment, filename)
       preferences = preferences_for_path(node, segment, filename)
 
-      # ensure that we generate the manifest, which will also generate
-      # @manifest_records_by_path
-      manifest
-
       # in order of prefernce, look for the filename in the manifest
-      preferences.find {|preferred_filename| @manifest_records_by_path[preferred_filename] }
+      preferences.find {|preferred_filename| manifest_records_by_path[preferred_filename] }
     end
 
     # For each filename, produce a mapping of base filename (i.e. recipe name
@@ -589,73 +612,6 @@ class Chef
       filenames.select{|filename| filename =~ /\.rb$/}.inject({}){|memo, filename| memo[File.basename(filename, '.rb')] = filename ; memo }
     end
 
-    # See #manifest for a description of the manifest return value.
-    # See #preferred_manifest_record for a description an individual manifest record.
-    def generate_manifest
-      manifest = Mash.new({
-        :recipes => Array.new,
-        :definitions => Array.new,
-        :libraries => Array.new,
-        :attributes => Array.new,
-        :files => Array.new,
-        :templates => Array.new,
-        :resources => Array.new,
-        :providers => Array.new,
-        :root_files => Array.new
-      })
-      checksums_to_on_disk_paths = {}
-
-      COOKBOOK_SEGMENTS.each do |segment|
-        segment_filenames(segment).each do |segment_file|
-          next if File.directory?(segment_file)
-
-          file_name = nil
-          path = nil
-          specificity = "default"
-
-          if segment == :root_files
-            matcher = segment_file.match(".+/#{Regexp.escape(name.to_s)}/(.+)")
-            file_name = matcher[1]
-            path = file_name
-          elsif segment == :templates || segment == :files
-            matcher = segment_file.match("/#{Regexp.escape(name.to_s)}/(#{Regexp.escape(segment.to_s)}/(.+?)/(.+))")
-            unless matcher
-              Chef::Log.debug("Skipping file #{segment_file}, as it isn't in any of the proper directories (platform-version, platform or default)")
-              Chef::Log.debug("You probably need to move #{segment_file} into the 'default' sub-directory")
-              next
-            end
-            path = matcher[1]
-            specificity = matcher[2]
-            file_name = matcher[3]
-          else
-            matcher = segment_file.match("/#{Regexp.escape(name.to_s)}/(#{Regexp.escape(segment.to_s)}/(.+))")
-            path = matcher[1]
-            file_name = matcher[2]
-          end
-
-          csum = self.class.checksum_cookbook_file(segment_file)
-          checksums_to_on_disk_paths[csum] = segment_file
-          rs = Mash.new({
-            :name => file_name,
-            :path => path,
-            :checksum => csum
-          })
-          rs[:specificity] = specificity
-
-          manifest[segment] << rs
-        end
-      end
-
-      manifest[:cookbook_name] = name.to_s
-      manifest[:metadata] = metadata
-      manifest[:version] = metadata.version
-      manifest[:name] = full_name
-
-      @checksums = checksums_to_on_disk_paths
-      @manifest = manifest
-      @manifest_records_by_path = extract_manifest_records_by_path(manifest)
-    end
-
     def file_vendor
       unless @file_vendor
         @file_vendor = Chef::Cookbook::FileVendor.create_from_manifest(manifest)
@@ -663,27 +619,5 @@ class Chef
       @file_vendor
     end
 
-    def extract_checksums_from_manifest(manifest)
-      checksums = {}
-      COOKBOOK_SEGMENTS.each do |segment|
-        next unless manifest.has_key?(segment)
-        manifest[segment].each do |manifest_record|
-          checksums[manifest_record[:checksum]] = nil
-        end
-      end
-      checksums
-    end
-
-    def extract_manifest_records_by_path(manifest)
-      manifest_records_by_path = {}
-      COOKBOOK_SEGMENTS.each do |segment|
-        next unless manifest.has_key?(segment)
-        manifest[segment].each do |manifest_record|
-          manifest_records_by_path[manifest_record[:path]] = manifest_record
-        end
-      end
-      manifest_records_by_path
-    end
-
   end
 end
