@@ -37,6 +37,8 @@ class Chef
 
     VALID_ID = /^[\.\-[:alnum:]_]+$/
 
+    attr_accessor :chef_server_rest
+
     def self.validate_id!(id_str)
       if id_str.nil? || ( id_str !~ VALID_ID )
         raise Exceptions::InvalidDataBagItemID, "Data Bag items must have an id matching #{VALID_ID.inspect}, you gave: #{id_str.inspect}"
@@ -49,13 +51,14 @@ class Chef
     attr_reader :raw_data
 
     # Create a new Chef::DataBagItem
-    def initialize
+    def initialize(chef_server_rest: nil)
       @data_bag = nil
       @raw_data = Mash.new
+      @chef_server_rest = chef_server_rest
     end
 
     def chef_server_rest
-      Chef::REST.new(Chef::Config[:chef_server_url])
+      @chef_server_rest ||= Chef::REST.new(Chef::Config[:chef_server_url])
     end
 
     def self.chef_server_rest
@@ -112,13 +115,13 @@ class Chef
     # Serialize this object as a hash
     def to_json(*a)
       result = {
-        "name" => self.object_name,
+        "name"       => object_name,
         "json_class" => self.class.name,
-        "chef_type" => "data_bag_item",
-        "data_bag" => self.data_bag,
-        "raw_data" => self.raw_data
+        "chef_type"  => "data_bag_item",
+        "data_bag"   => data_bag,
+        "raw_data"   => raw_data
       }
-      result.to_json(*a)
+      Chef::JSONCompat.to_json(result, *a)
     end
 
     def self.from_hash(h)
@@ -158,7 +161,7 @@ class Chef
       end
     end
 
-    def destroy(data_bag=data_bag, databag_item=name)
+    def destroy(data_bag=data_bag(), databag_item=name)
       chef_server_rest.delete_rest("data/#{data_bag}/#{databag_item}")
     end
 
@@ -210,5 +213,3 @@ class Chef
 
   end
 end
-
-
