@@ -8,15 +8,18 @@ class Chef
     # "specdoc"
     class Doc < Formatters::Base
 
-      attr_reader :start_time, :end_time
+      attr_reader :start_time, :end_time, :successful_audits, :failed_audits
+      private :successful_audits, :failed_audits
+
       cli_name(:doc)
-      
 
       def initialize(out, err)
         super
 
         @updated_resources = 0
         @up_to_date_resources = 0
+        @successful_audits = 0
+        @failed_audits = 0
         @start_time = Time.now
         @end_time = @start_time
       end
@@ -26,28 +29,38 @@ class Chef
       end
 
       def run_start(version)
-        puts "Starting Chef Client, version #{version}"
+        puts_line "Starting Chef Client, version #{version}"
       end
 
       def total_resources
         @up_to_date_resources + @updated_resources
       end
 
+      def total_audits
+        successful_audits + failed_audits
+      end
+
       def run_completed(node)
         @end_time = Time.now
         if Chef::Config[:why_run]
-          puts "Chef Client finished, #{@updated_resources}/#{total_resources} resources would have been updated"
+          puts_line "Chef Client finished, #{@updated_resources}/#{total_resources} resources would have been updated"
         else
-          puts "Chef Client finished, #{@updated_resources}/#{total_resources} resources updated in #{elapsed_time} seconds"
+          puts_line "Chef Client finished, #{@updated_resources}/#{total_resources} resources updated in #{elapsed_time} seconds"
+          if total_audits > 0
+            puts_line "  #{successful_audits}/#{total_audits} controls succeeded"
+          end
         end
       end
 
       def run_failed(exception)
         @end_time = Time.now
         if Chef::Config[:why_run]
-          puts "Chef Client failed. #{@updated_resources} resources would have been updated"
+          puts_line "Chef Client failed. #{@updated_resources} resources would have been updated"
         else
-          puts "Chef Client failed. #{@updated_resources} resources updated in #{elapsed_time} seconds"
+          puts_line "Chef Client failed. #{@updated_resources} resources updated in #{elapsed_time} seconds"
+          if total_audits > 0
+            puts_line "  #{successful_audits} controls succeeded"
+          end
         end
       end
 
@@ -61,7 +74,7 @@ class Chef
 
       # About to attempt to register as +node_name+
       def registration_start(node_name, config)
-        puts "Creating a new client identity for #{node_name} using the validator key."
+        puts_line "Creating a new client identity for #{node_name} using the validator key."
       end
 
       def registration_completed
@@ -82,7 +95,7 @@ class Chef
 
       # Called before the cookbook collection is fetched from the server.
       def cookbook_resolution_start(expanded_run_list)
-        puts "resolving cookbooks for run list: #{expanded_run_list.inspect}"
+        puts_line "resolving cookbooks for run list: #{expanded_run_list.inspect}"
       end
 
       # Called when there is an error getting the cookbook collection from the
@@ -111,12 +124,13 @@ class Chef
 
       # Called before cookbook sync starts
       def cookbook_sync_start(cookbook_count)
-        puts "Synchronizing Cookbooks:"
+        puts_line "Synchronizing Cookbooks:"
+        indent
       end
 
       # Called when cookbook +cookbook_name+ has been sync'd
       def synchronized_cookbook(cookbook_name)
-        puts "  - #{cookbook_name}"
+        puts_line "- #{cookbook_name}"
       end
 
       # Called when an individual file in a cookbook has been updated
@@ -125,11 +139,12 @@ class Chef
 
       # Called after all cookbooks have been sync'd.
       def cookbook_sync_complete
+        unindent
       end
 
       # Called when cookbook loading starts.
       def library_load_start(file_count)
-        puts "Compiling Cookbooks..."
+        puts_line "Compiling Cookbooks..."
       end
 
       # Called after a file in a cookbook is loaded.
@@ -142,11 +157,44 @@ class Chef
 
       # Called before convergence starts
       def converge_start(run_context)
-        puts "Converging #{run_context.resource_collection.all_resources.size} resources"
+        puts_line "Converging #{run_context.resource_collection.all_resources.size} resources"
       end
 
       # Called when the converge phase is finished.
       def converge_complete
+        unindent if @current_recipe
+      end
+
+      def converge_failed(e)
+        # Currently a failed converge is handled the same way as a successful converge
+        converge_complete
+      end
+
+      # Called before audit phase starts
+      def audit_phase_start(run_status)
+        puts_line "Starting audit phase"
+      end
+
+      def audit_phase_complete
+        puts_line "Auditing complete"
+      end
+
+      def audit_phase_failed(error)
+        puts_line ""
+        puts_line "Audit phase exception:"
+        indent
+        puts_line "#{error.message}"
+        error.backtrace.each do |l|
+          puts_line l
+        end
+      end
+
+      def control_example_success(control_group_name, example_data)
+        @successful_audits += 1
+      end
+
+      def control_example_failure(control_group_name, example_data, error)
+        @failed_audits += 1
       end
 
       # Called before action is executed on a resource.
@@ -157,12 +205,15 @@ class Chef
           resource_recipe = "<Dynamically Defined Resource>"
         end
 
-        if resource_recipe != @current_recipe
-          puts "Recipe: #{resource_recipe}"
+        if resource_recipe != @current_recipe && !resource.enclosing_provider
+          unindent if @current_recipe
+          puts_line "Recipe: #{resource_recipe}"
           @current_recipe = resource_recipe
+          indent
         end
         # TODO: info about notifies
-        print "  * #{resource} action #{action}"
+        start_line "* #{resource} action #{action}", :stream => resource
+        indent
       end
 
       # Called when a resource fails, but will retry.
@@ -172,12 +223,14 @@ class Chef
       # Called when a resource fails and will not be retried.
       def resource_failed(resource, action, exception)
         super
+        unindent
       end
 
       # Called when a resource action has been skipped b/c of a conditional
       def resource_skipped(resource, action, conditional)
         # TODO: more info about conditional
-        puts " (skipped due to #{conditional.short_description})"
+        puts " (skipped due to #{conditional.short_description})", :stream => resource
+        unindent
       end
 
       # Called after #load_current_resource has run.
@@ -187,11 +240,13 @@ class Chef
       # Called when a resource has no converge actions, e.g., it was already correct.
       def resource_up_to_date(resource, action)
         @up_to_date_resources+= 1
-        puts " (up to date)"
+        puts " (up to date)", :stream => resource
+        unindent
       end
 
       def resource_bypassed(resource, action, provider)
-        puts " (Skipped: whyrun not supported by provider #{provider.class.name})"
+        puts " (Skipped: whyrun not supported by provider #{provider.class.name})", :stream => resource
+        unindent
       end
 
       def output_record(line)
@@ -207,12 +262,12 @@ class Chef
           next if line.nil?
           output_record line
           if line.kind_of? String
-            @output.color "\n    - #{prefix}#{line}", :green
+            start_line "- #{prefix}#{line}", :green
           elsif line.kind_of? Array
             # Expanded output - delta
             # @todo should we have a resource_update_delta callback?
             line.each do |detail|
-              @output.color "\n        #{detail}", :white
+              start_line detail, :white
             end
           end
         end
@@ -221,28 +276,36 @@ class Chef
       # Called after a resource has been completely converged.
       def resource_updated(resource, action)
         @updated_resources += 1
+        unindent
         puts "\n"
       end
 
       # Called when resource current state load is skipped due to the provider
       # not supporting whyrun mode.
       def resource_current_state_load_bypassed(resource, action, current_resource)
-        @output.color("\n    * Whyrun not supported for #{resource}, bypassing load.", :yellow)
+        puts_line("* Whyrun not supported for #{resource}, bypassing load.", :yellow)
+      end
+
+      def stream_output(stream, output, options = {})
+        print(output, { :stream => stream }.merge(options))
       end
 
       # Called before handlers run
       def handlers_start(handler_count)
-        puts "\nRunning handlers:"
+        puts ''
+        puts "Running handlers:"
+        indent
       end
 
       # Called after an individual handler has run
       def handler_executed(handler)
-        puts "  - #{handler.class.name}"
+        puts_line "- #{handler.class.name}"
       end
 
       # Called after all handlers have executed
       def handlers_completed
-        puts "Running handlers complete\n"
+        unindent
+        puts_line "Running handlers complete\n"
       end
 
       # Called when a provider makes an assumption after a failed assertion
@@ -250,7 +313,7 @@ class Chef
       def whyrun_assumption(action, resource, message)
         return unless message
         [ message ].flatten.each do |line|
-          @output.color("\n    * #{line}", :yellow)
+          start_line("* #{line}", :yellow)
         end
       end
 
@@ -259,9 +322,17 @@ class Chef
         return unless message
         color = Chef::Config[:why_run] ? :yellow : :red
         [ message ].flatten.each do |line|
-          @output.color("\n    * #{line}", color)
+          start_line("* #{line}", color)
         end
       end
+
+      def indent
+        indent_by(2)
+      end
+
+      def unindent
+        indent_by(-2)
+      end
     end
   end
 end
