@@ -24,7 +24,7 @@ class Chef
     class ErrorReport < ::Chef::Handler
 
       def report
-        Chef::FileCache.store("failed-run-data.json", Chef::JSONCompat.to_json_pretty(data))
+        Chef::FileCache.store("failed-run-data.json", Chef::JSONCompat.to_json_pretty(data), 0640)
         Chef::Log.fatal("Saving node information to #{Chef::FileCache.load("failed-run-data.json", false)}")
       end
 
