@@ -71,6 +71,20 @@ class Chef
           end
           Chef::Log.debug("---- End HTTP Status/Header Data ----")
 
+          # For non-400's, log the request and response bodies
+          if !response.code || !response.code.start_with?('2')
+            if response.body
+              Chef::Log.debug("---- HTTP Response Body ----")
+              Chef::Log.debug(response.body)
+              Chef::Log.debug("---- End HTTP Response Body -----")
+            end
+            if req_body
+              Chef::Log.debug("---- HTTP Request Body ----")
+              Chef::Log.debug(req_body)
+              Chef::Log.debug("---- End HTTP Request Body ----")
+            end
+          end
+
           yield response if block_given?
           # http_client.request may not have the return signature we want, so
           # force the issue:
@@ -83,9 +97,18 @@ class Chef
 
       #adapted from buildr/lib/buildr/core/transports.rb
       def proxy_uri
-        proxy = Chef::Config["#{url.scheme}_proxy"]
-        proxy = URI.parse(proxy) if String === proxy
-        excludes = Chef::Config[:no_proxy].to_s.split(/\s*,\s*/).compact
+        proxy = Chef::Config["#{url.scheme}_proxy"] ||
+                env["#{url.scheme.upcase}_PROXY"] || env["#{url.scheme}_proxy"]
+
+        # Check if the proxy string contains a scheme. If not, add the url's scheme to the
+        # proxy before parsing. The regex /^.*:\/\// matches, for example, http://.
+        proxy = if proxy.match(/^.*:\/\//)
+          URI.parse(proxy)
+        else
+          URI.parse("#{url.scheme}://#{proxy}")
+        end if String === proxy
+        no_proxy = Chef::Config[:no_proxy] || env['NO_PROXY'] || env['no_proxy']
+        excludes = no_proxy.to_s.split(/\s*,\s*/).compact
         excludes = excludes.map { |exclude| exclude =~ /:\d+$/ ? exclude : "#{exclude}:*" }
         return proxy unless excludes.any? { |exclude| File.fnmatch(exclude, "#{host}:#{port}") }
       end
@@ -98,6 +121,7 @@ class Chef
         end
 
         http_client.read_timeout = config[:rest_timeout]
+        http_client.open_timeout = config[:rest_timeout]
         http_client
       end
 
@@ -105,18 +129,32 @@ class Chef
         Chef::Config
       end
 
+      def env
+        ENV
+      end
+
       def http_client_builder
         http_proxy = proxy_uri
         if http_proxy.nil?
           Net::HTTP
         else
           Chef::Log.debug("Using #{http_proxy.host}:#{http_proxy.port} for proxy")
-          user = Chef::Config["#{url.scheme}_proxy_user"]
-          pass = Chef::Config["#{url.scheme}_proxy_pass"]
+          user = http_proxy_user(http_proxy)
+          pass = http_proxy_pass(http_proxy)
           Net::HTTP.Proxy(http_proxy.host, http_proxy.port, user, pass)
         end
       end
 
+      def http_proxy_user(http_proxy)
+        http_proxy.user || Chef::Config["#{url.scheme}_proxy_user"] ||
+        env["#{url.scheme.upcase}_PROXY_USER"] || env["#{url.scheme}_proxy_user"]
+      end
+
+      def http_proxy_pass(http_proxy)
+        http_proxy.password || Chef::Config["#{url.scheme}_proxy_pass"] ||
+        env["#{url.scheme.upcase}_PROXY_PASS"] || env["#{url.scheme}_proxy_pass"]
+      end
+
       def configure_ssl(http_client)
         http_client.use_ssl = true
         ssl_policy.apply_to(http_client)
