@@ -60,6 +60,8 @@ class Chef
 
       HOST_LOWER = "host".freeze
 
+      URI_SCHEME_DEFAULT_PORT = { 'http'  => 80, 'https' => 443 }.freeze
+
       def self.user_agent=(ua)
         @user_agent = ua
       end
@@ -138,7 +140,13 @@ class Chef
         # No response compression unless we asked for it explicitly:
         @headers[HTTPRequest::ACCEPT_ENCODING] ||= "identity"
         @headers['X-Chef-Version'] = ::Chef::VERSION
-        @headers['Host'] = "#{uri_safe_host}:#{port}" unless @headers.keys.any? {|k| k.downcase.to_s == HOST_LOWER }
+
+        # Only include port in Host header when it is not the default port
+        # for the url scheme (80;443) - Fixes CHEF-5355
+        host_header = uri_safe_host.dup
+        host_header << ":#{port}" unless URI_SCHEME_DEFAULT_PORT[@url.scheme] == port.to_i
+        @headers['Host'] = host_header unless @headers.keys.any? {|k| k.downcase.to_s == HOST_LOWER }
+
         @headers
       end
 
