@@ -17,16 +17,26 @@
 #
 
 require 'chef/version'
+require 'chef/util/path_helper'
 class Chef
   class Knife
     class SubcommandLoader
 
+      MATCHES_CHEF_GEM = %r{/chef-[\d]+\.[\d]+\.[\d]+}.freeze
+      MATCHES_THIS_CHEF_GEM = %r{/chef-#{Chef::VERSION}/}.freeze
+
       attr_reader :chef_config_dir
       attr_reader :env
 
-      def initialize(chef_config_dir, env=ENV)
-        @chef_config_dir, @env = chef_config_dir, env
+      def initialize(chef_config_dir, env=nil)
+        @chef_config_dir = chef_config_dir
         @forced_activate = {}
+
+        # Deprecated and un-used instance variable.
+        @env = env
+        unless env.nil?
+          Chef::Log.deprecation("The env argument to Chef::Knife::SubcommandLoader is deprecated. If you are using env to inject/mock HOME, consider mocking Chef::Util::PathHelper.home instead.")
+        end
       end
 
       # Load all the sub-commands
@@ -41,11 +51,13 @@ class Chef
         user_specific_files = []
 
         if chef_config_dir
-          user_specific_files.concat Dir.glob(File.expand_path("plugins/knife/*.rb", chef_config_dir))
+          user_specific_files.concat Dir.glob(File.expand_path("plugins/knife/*.rb", Chef::Util::PathHelper.escape_glob(chef_config_dir)))
         end
 
         # finally search ~/.chef/plugins/knife/*.rb
-        user_specific_files.concat Dir.glob(File.join(env['HOME'], '.chef', 'plugins', 'knife', '*.rb')) if env['HOME']
+        Chef::Util::PathHelper.home('.chef', 'plugins', 'knife') do |p|
+          user_specific_files.concat Dir.glob(File.join(Chef::Util::PathHelper.escape_glob(p), '*.rb'))
+        end
 
         user_specific_files
       end
@@ -107,7 +119,7 @@ class Chef
 
       def find_subcommands_via_dirglob
         # The "require paths" of the core knife subcommands bundled with chef
-        files = Dir[File.expand_path('../../../knife/*.rb', __FILE__)]
+        files = Dir[File.join(Chef::Util::PathHelper.escape_glob(File.expand_path('../../../knife', __FILE__)), '*.rb')]
         subcommand_files = {}
         files.each do |knife_file|
           rel_path = knife_file[/#{CHEF_ROOT}#{Regexp.escape(File::SEPARATOR)}(.*)\.rb/,1]
@@ -121,6 +133,14 @@ class Chef
         subcommand_files = {}
         files.each do |file|
           rel_path = file[/(#{Regexp.escape File.join('chef', 'knife', '')}.*)\.rb/, 1]
+
+          # When not installed as a gem (ChefDK/appbundler in particular), AND
+          # a different version of Chef is installed via gems, `files` will
+          # include some files from the 'other' Chef install. If this contains
+          # a knife command that doesn't exist in this version of Chef, we will
+          # get a LoadError later when we try to require it.
+          next if from_different_chef_version?(file)
+
           subcommand_files[rel_path] = file
         end
 
@@ -128,7 +148,7 @@ class Chef
       end
 
       def have_plugin_manifest?
-        ENV["HOME"] && File.exist?(plugin_manifest_path)
+        plugin_manifest_path && File.exist?(plugin_manifest_path)
       end
 
       def plugin_manifest
@@ -136,7 +156,7 @@ class Chef
       end
 
       def plugin_manifest_path
-        File.join(ENV['HOME'], '.chef', 'plugin_manifest.json')
+        Chef::Util::PathHelper.home('.chef', 'plugin_manifest.json')
       end
 
       private
@@ -146,7 +166,7 @@ class Chef
 
         if check_load_path
           files = $LOAD_PATH.map { |load_path|
-            Dir["#{File.expand_path glob, load_path}#{Gem.suffix_pattern}"]
+            Dir["#{File.expand_path glob, Chef::Util::PathHelper.escape_glob(load_path)}#{Gem.suffix_pattern}"]
           }.flatten.select { |file| File.file? file.untaint }
         end
 
@@ -180,10 +200,23 @@ class Chef
           spec.require_paths.first
         end
 
-        glob = File.join("#{spec.full_gem_path}/#{dirs}", glob)
+        glob = File.join(Chef::Util::PathHelper.escape_glob(spec.full_gem_path, dirs), glob)
 
         Dir[glob].map { |f| f.untaint }
       end
+
+      def from_different_chef_version?(path)
+        matches_any_chef_gem?(path) && !matches_this_chef_gem?(path)
+      end
+
+      def matches_any_chef_gem?(path)
+        path =~ MATCHES_CHEF_GEM
+      end
+
+      def matches_this_chef_gem?(path)
+        path =~ MATCHES_THIS_CHEF_GEM
+      end
+
     end
   end
 end
