@@ -30,6 +30,8 @@ class Chef
         require 'chef/exceptions'
         require 'chef/search/query'
         require 'chef/mixin/shell_out'
+        require 'chef/mixin/command'
+        require 'chef/util/path_helper'
         require 'mixlib/shellout'
       end
 
@@ -102,16 +104,16 @@ class Chef
         :boolean => true,
         :default => true
 
+      option :on_error,
+        :short => '-e',
+        :long => '--exit-on-error',
+        :description => "Immediately exit if an error is encountered",
+        :boolean => true,
+        :proc => Proc.new { :raise }
+
       def session
         config[:on_error] ||= :skip
         ssh_error_handler = Proc.new do |server|
-          if config[:manual]
-            node_name = server.host
-          else
-            @action_nodes.each do |n|
-              node_name = n if format_for_display(n)[config[:attribute]] == server.host
-            end
-          end
           case config[:on_error]
           when :skip
             ui.warn "Failed to connect to #{server.host} -- #{$!.class.name}: #{$!.message}"
@@ -169,12 +171,18 @@ class Chef
           # if a command line attribute was not passed, and we have a
           # cloud public_hostname, use that.  see #configure_attribute
           # for the source of config[:attribute] and
-          # config[:override_attribute]
-          if config[:override_attribute]
-            host = extract_nested_value(item, config[:override_attribute])
-          elsif item[:cloud] && item[:cloud][:public_hostname]
+          # config[:attribute_from_cli]
+          if config[:attribute_from_cli]
+            Chef::Log.debug("Using node attribute '#{config[:attribute_from_cli]}' from the command line as the ssh target")
+            host = extract_nested_value(item, config[:attribute_from_cli])
+          elsif item[:cloud] &&
+                item[:cloud][:public_hostname] &&
+                !item[:cloud][:public_hostname].empty?
+            Chef::Log.debug("Using node attribute 'cloud[:public_hostname]' automatically as the ssh target")
             host = item[:cloud][:public_hostname]
           else
+            # ssh attribute from a configuration file or the default will land here
+            Chef::Log.debug("Using node attribute '#{config[:attribute]}' as the ssh target")
             host = extract_nested_value(item, config[:attribute])
           end
           # next if we couldn't find the specified attribute in the
@@ -315,7 +323,7 @@ class Chef
         puts
         puts "To exit interactive mode, use 'quit!'"
         puts
-        while 1
+        loop do
           command = read_line
           case command
           when 'quit!'
@@ -337,8 +345,10 @@ class Chef
 
       def screen
         tf = Tempfile.new("knife-ssh-screen")
-        if File.exist? "#{ENV["HOME"]}/.screenrc"
-          tf.puts("source #{ENV["HOME"]}/.screenrc")
+        Chef::Util::PathHelper.home('.screenrc') do |screenrc_path|
+          if File.exist? screenrc_path
+            tf.puts("source #{screenrc_path}")
+          end
         end
         tf.puts("caption always '%-Lw%{= BW}%50>%n%f* %t%{-}%+Lw%<'")
         tf.puts("hardstatus alwayslastline 'knife ssh #{@name_args[0]}'")
@@ -412,10 +422,8 @@ class Chef
         # Thus we can differentiate between a config file value and a command line override at this point by checking config[:attribute]
         # We can tell here if fqdn was passed from the command line, rather than being the default, by checking config[:attribute]
         # However, after here, we cannot tell these things, so we must preserve config[:attribute]
-        config[:override_attribute] = config[:attribute] || Chef::Config[:knife][:ssh_attribute]
-        config[:attribute] = (Chef::Config[:knife][:ssh_attribute] ||
-                              config[:attribute] ||
-                              "fqdn").strip
+        config[:attribute_from_cli] = config[:attribute]
+        config[:attribute] = (config[:attribute_from_cli] || Chef::Config[:knife][:ssh_attribute] || "fqdn").strip
       end
 
       def cssh
@@ -430,6 +438,11 @@ class Chef
         end
         raise Chef::Exceptions::Exec, "no command found for cssh" unless cssh_cmd
 
+        # pass in the consolidated itentity file option to cssh(X)
+        if config[:identity_file]
+          cssh_cmd << " --ssh_args '-i #{File.expand_path(config[:identity_file])}'"
+        end
+
         session.servers_for.each do |server|
           cssh_cmd << " #{server.user ? "#{server.user}@#{server.host}" : server.host}"
         end
