@@ -42,8 +42,8 @@ class Chef
       #               method names.
       # :required:: Raise an exception if this parameter is missing. Valid values are true or false,
       #             by default, options are not required.
-      # :regex:: Match the value of the paramater against a regular expression.
-      # :equal_to:: Match the value of the paramater with ==.  An array means it can be equal to any
+      # :regex:: Match the value of the parameter against a regular expression.
+      # :equal_to:: Match the value of the parameter with ==.  An array means it can be equal to any
       #             of the values.
       def validate(opts, map)
         #--
@@ -95,6 +95,13 @@ class Chef
             val = arg
           else
             val = validate({ symbol => arg }, { symbol => validation })[symbol]
+
+            # Handle the case where the "default" was a DelayedEvaluator. In
+            # this case, the block yields an optional parameter of +self+,
+            # which is the equivalent of "new_resource"
+            if val.is_a?(DelayedEvaluator)
+              val = val.call(self)
+            end
           end
           self.instance_variable_set(iv_symbol, val)
         end
