@@ -1,5 +1,4 @@
 require 'chef/mixin/shell_out'
-require 'chef/mixin/check_helper'
 require 'chef/mixin/checksum'
 require 'chef/mixin/command'
 require 'chef/mixin/convert_to_class_name'
@@ -7,12 +6,9 @@ require 'chef/mixin/create_path'
 require 'chef/mixin/deep_merge'
 require 'chef/mixin/enforce_ownership_and_permissions'
 require 'chef/mixin/from_file'
-require 'chef/mixin/language'
-require 'chef/mixin/language_include_attribute'
-require 'chef/mixin/language_include_recipe'
 require 'chef/mixin/params_validate'
 require 'chef/mixin/path_sanity'
-require 'chef/mixin/recipe_definition_dsl_core'
 require 'chef/mixin/template'
 require 'chef/mixin/securable'
 require 'chef/mixin/xml_escape'
+
