@@ -34,6 +34,7 @@ require 'chef/node/attribute'
 require 'chef/mash'
 require 'chef/json_compat'
 require 'chef/search/query'
+require 'chef/whitelist'
 
 class Chef
   class Node
@@ -41,9 +42,13 @@ class Chef
     extend Forwardable
 
     def_delegators :attributes, :keys, :each_key, :each_value, :key?, :has_key?
+    def_delegators :attributes, :rm, :rm_default, :rm_normal, :rm_override
+    def_delegators :attributes, :default!, :normal!, :override!, :force_default!, :force_override!
 
     attr_accessor :recipe_list, :run_state, :override_runlist
 
+    attr_accessor :chef_server_rest
+
     # RunContext will set itself as run_context via this setter when
     # initialized. This is needed so DSL::IncludeAttribute (in particular,
     # #include_recipe) can access the run_context to determine if an attributes
@@ -59,7 +64,8 @@ class Chef
     include Chef::Mixin::ParamsValidate
 
     # Create a new Chef::Node object.
-    def initialize
+    def initialize(chef_server_rest: nil)
+      @chef_server_rest = chef_server_rest
       @name = nil
 
       @chef_environment = '_default'
@@ -77,7 +83,7 @@ class Chef
     end
 
     def chef_server_rest
-      Chef::REST.new(Chef::Config[:chef_server_url])
+      @chef_server_rest ||= Chef::REST.new(Chef::Config[:chef_server_url])
     end
 
     # Set the name of this Node, or return the current name.
@@ -124,6 +130,7 @@ class Chef
     # Set a normal attribute of this node, but auto-vivify any Mashes that
     # might be missing
     def normal
+      attributes.top_level_breadcrumb = nil
       attributes.set_unless_value_present = false
       attributes.normal
     end
@@ -133,28 +140,25 @@ class Chef
     # Set a normal attribute of this node, auto-vivifying any mashes that are
     # missing, but if the final value already exists, don't set it
     def normal_unless
+      attributes.top_level_breadcrumb = nil
       attributes.set_unless_value_present = true
       attributes.normal
     end
+
     alias_method :set_unless, :normal_unless
 
     # Set a default of this node, but auto-vivify any Mashes that might
     # be missing
     def default
+      attributes.top_level_breadcrumb = nil
       attributes.set_unless_value_present = false
       attributes.default
     end
 
-    # Set a force default attribute. Intermediate mashes will be created by
-    # auto-vivify if necessary.
-    def default!
-      attributes.set_unless_value_present = false
-      attributes.default!
-    end
-
     # Set a default attribute of this node, auto-vivifying any mashes that are
     # missing, but if the final value already exists, don't set it
     def default_unless
+      attributes.top_level_breadcrumb = nil
       attributes.set_unless_value_present = true
       attributes.default
     end
@@ -162,50 +166,38 @@ class Chef
     # Set an override attribute of this node, but auto-vivify any Mashes that
     # might be missing
     def override
+      attributes.top_level_breadcrumb = nil
       attributes.set_unless_value_present = false
       attributes.override
     end
 
-    # Set a force override attribute. Intermediate mashes will be created by
-    # auto-vivify if needed.
-    def override!
-      attributes.set_unless_value_present = false
-      attributes.override!
-    end
-
     # Set an override attribute of this node, auto-vivifying any mashes that
     # are missing, but if the final value already exists, don't set it
     def override_unless
+      attributes.top_level_breadcrumb = nil
       attributes.set_unless_value_present = true
       attributes.override
     end
 
-
-    def override_attrs
-     attributes.override
-    end
+    alias :override_attrs :override
+    alias :default_attrs :default
+    alias :normal_attrs :normal
 
     def override_attrs=(new_values)
       attributes.override = new_values
     end
 
-    def default_attrs
-      attributes.default
-    end
-
     def default_attrs=(new_values)
       attributes.default = new_values
     end
 
-    def normal_attrs
-      attributes.normal
-    end
-
     def normal_attrs=(new_values)
       attributes.normal = new_values
     end
 
     def automatic_attrs
+      attributes.top_level_breadcrumb = nil
+      attributes.set_unless_value_present = false
       attributes.automatic
     end
 
@@ -331,7 +323,7 @@ class Chef
         if attrs.key?("recipes") || attrs.key?("run_list")
           raise Chef::Exceptions::AmbiguousRunlistSpecification, "please set the node's run list using the 'run_list' attribute only."
         end
-        Chef::Log.info("Setting the run_list to #{new_run_list.inspect} from CLI options")
+        Chef::Log.info("Setting the run_list to #{new_run_list.to_s} from CLI options")
         run_list(new_run_list)
       end
       attrs
@@ -397,7 +389,7 @@ class Chef
       end
       index_hash["recipe"] = run_list.recipe_names if run_list.recipe_names.length > 0
       index_hash["role"] = run_list.role_names if run_list.role_names.length > 0
-      index_hash["run_list"] = run_list.run_list if run_list.run_list.length > 0
+      index_hash["run_list"] = run_list.run_list_items
       index_hash
     end
 
@@ -409,13 +401,13 @@ class Chef
       display["normal"]           = normal_attrs
       display["default"]          = attributes.combined_default
       display["override"]         = attributes.combined_override
-      display["run_list"]         = run_list.run_list
+      display["run_list"]         = run_list.run_list_items
       display
     end
 
     # Serialize this object as a hash
     def to_json(*a)
-      for_json.to_json(*a)
+      Chef::JSONCompat.to_json(for_json, *a)
     end
 
     def for_json
@@ -498,7 +490,7 @@ class Chef
     def self.build(node_name)
       node = new
       node.name(node_name)
-      node.chef_environment(Chef::Config[:environment]) unless Chef::Config[:environment].nil? || Chef::Config[:environment].chop.empty?
+      node.chef_environment(Chef::Config[:environment]) unless Chef::Config[:environment].nil? || Chef::Config[:environment].chomp.empty?
       node
     end
 
@@ -520,18 +512,18 @@ class Chef
         if Chef::Config[:why_run]
           Chef::Log.warn("In whyrun mode, so NOT performing node save.")
         else
-          chef_server_rest.put_rest("nodes/#{name}", self)
+          chef_server_rest.put_rest("nodes/#{name}", data_for_save)
         end
       rescue Net::HTTPServerException => e
         raise e unless e.response.code == "404"
-        chef_server_rest.post_rest("nodes", self)
+        chef_server_rest.post_rest("nodes", data_for_save)
       end
       self
     end
 
     # Create the node via the REST API
     def create
-      chef_server_rest.post_rest("nodes", self)
+      chef_server_rest.post_rest("nodes", data_for_save)
       self
     end
 
@@ -543,5 +535,20 @@ class Chef
       self.name <=> other_node.name
     end
 
+    private
+
+    def data_for_save
+      data = for_json
+      ["automatic", "default", "normal", "override"].each do |level|
+        whitelist_config_option = "#{level}_attribute_whitelist".to_sym
+        whitelist = Chef::Config[whitelist_config_option]
+        unless whitelist.nil? # nil => save everything
+          Chef::Log.info("Whitelisting #{level} node attributes for save.")
+          data[level] = Chef::Whitelist.filter(data[level], whitelist)
+        end
+      end
+      data
+    end
+
   end
 end
