@@ -17,15 +17,12 @@
 #
 
 require 'chef/provider/group/groupadd'
-require 'chef/mixin/shell_out'
 
 class Chef
   class Provider
     class Group
       class Suse < Chef::Provider::Group::Groupadd
 
-        include Chef::Mixin::ShellOut
-
         def load_current_resource
           super
         end
