@@ -18,7 +18,9 @@
 
 require 'chef/log'
 require 'chef/mixin/command'
+require 'chef/mixin/shell_out'
 require 'chef/provider'
+require 'chef/resource/file'
 require 'chef/exceptions'
 require 'erb'
 
@@ -37,6 +39,7 @@ require 'erb'
 class Chef
   class Provider
     class Ifconfig < Chef::Provider
+      include Chef::Mixin::ShellOut
       include Chef::Mixin::Command
 
       attr_accessor :config_template
@@ -58,32 +61,30 @@ class Chef
         @ifconfig_success = true
         @interfaces = {}
 
-        @status = popen4("ifconfig") do |pid, stdin, stdout, stderr|
-          stdout.each do |line|
+        @status = shell_out("ifconfig")
+        @status.stdout.each_line do |line|
+          if !line[0..9].strip.empty?
+            @int_name = line[0..9].strip
+            @interfaces[@int_name] = {"hwaddr" => (line =~ /(HWaddr)/ ? ($') : "nil").strip.chomp }
+          else
+            @interfaces[@int_name]["inet_addr"] = (line =~ /inet addr:(\S+)/ ? ($1) : "nil") if line =~ /inet addr:/
+            @interfaces[@int_name]["bcast"] = (line =~ /Bcast:(\S+)/ ? ($1) : "nil") if line =~ /Bcast:/
+            @interfaces[@int_name]["mask"] = (line =~ /Mask:(\S+)/ ? ($1) : "nil") if line =~ /Mask:/
+            @interfaces[@int_name]["mtu"] = (line =~ /MTU:(\S+)/ ? ($1) : "nil") if line =~ /MTU:/
+            @interfaces[@int_name]["metric"] = (line =~ /Metric:(\S+)/ ? ($1) : "nil") if line =~ /Metric:/
+          end
 
-            if !line[0..9].strip.empty?
-              @int_name = line[0..9].strip
-              @interfaces[@int_name] = {"hwaddr" => (line =~ /(HWaddr)/ ? ($') : "nil").strip.chomp }
-            else
-              @interfaces[@int_name]["inet_addr"] = (line =~ /inet addr:(\S+)/ ? ($1) : "nil") if line =~ /inet addr:/
-              @interfaces[@int_name]["bcast"] = (line =~ /Bcast:(\S+)/ ? ($1) : "nil") if line =~ /Bcast:/
-              @interfaces[@int_name]["mask"] = (line =~ /Mask:(\S+)/ ? ($1) : "nil") if line =~ /Mask:/
-              @interfaces[@int_name]["mtu"] = (line =~ /MTU:(\S+)/ ? ($1) : "nil") if line =~ /MTU:/
-              @interfaces[@int_name]["metric"] = (line =~ /Metric:(\S+)/ ? ($1) : "nil") if line =~ /Metric:/
-            end
+          if @interfaces.has_key?(@new_resource.device)
+            @interface = @interfaces.fetch(@new_resource.device)
 
-            if @interfaces.has_key?(@new_resource.device)
-              @interface = @interfaces.fetch(@new_resource.device)
-
-              @current_resource.target(@new_resource.target)
-              @current_resource.device(@new_resource.device)
-              @current_resource.inet_addr(@interface["inet_addr"])
-              @current_resource.hwaddr(@interface["hwaddr"])
-              @current_resource.bcast(@interface["bcast"])
-              @current_resource.mask(@interface["mask"])
-              @current_resource.mtu(@interface["mtu"])
-              @current_resource.metric(@interface["metric"])
-            end
+            @current_resource.target(@new_resource.target)
+            @current_resource.device(@new_resource.device)
+            @current_resource.inet_addr(@interface["inet_addr"])
+            @current_resource.hwaddr(@interface["hwaddr"])
+            @current_resource.bcast(@interface["bcast"])
+            @current_resource.mask(@interface["mask"])
+            @current_resource.mtu(@interface["mtu"])
+            @current_resource.metric(@interface["metric"])
           end
         end
         @current_resource
@@ -109,11 +110,11 @@ class Chef
                 :command => command
               )
               Chef::Log.info("#{@new_resource} added")
-              # Write out the config files
-              generate_config
             end
           end
         end
+        # Write out the config files
+        generate_config
       end
 
       def action_enable
@@ -140,12 +141,12 @@ class Chef
             run_command(
               :command => command
             )
-            delete_config
             Chef::Log.info("#{@new_resource} deleted")
           end
         else
           Chef::Log.debug("#{@new_resource} does not exist - nothing to do")
         end
+        delete_config
       end
 
       def action_disable
@@ -168,27 +169,25 @@ class Chef
         ! @config_template.nil? and ! @config_path.nil?
       end
 
+      def resource_for_config(path)
+        Chef::Resource::File.new(path, run_context)
+      end
+
       def generate_config
         return unless can_generate_config?
         b = binding
         template = ::ERB.new(@config_template)
-        converge_by ("generate configuration file : #{@config_path}") do
-          network_file = ::File.new(@config_path, "w")
-          network_file.puts(template.result(b))
-          network_file.close
-        end
-        Chef::Log.info("#{@new_resource} created configuration file")
+        config = resource_for_config(@config_path)
+        config.content(template.result(b))
+        config.run_action(:create)
+        @new_resource.updated_by_last_action(true) if config.updated?
       end
 
       def delete_config
         return unless can_generate_config?
-        require 'fileutils'
-        if ::File.exist?(@config_path)
-          converge_by ("delete the #{@config_path}") do
-            FileUtils.rm_f(@config_path, :verbose => false)
-          end
-        end
-        Chef::Log.info("#{@new_resource} deleted configuration file")
+        config = resource_for_config(@config_path)
+        config.run_action(:delete)
+        @new_resource.updated_by_last_action(true) if config.updated?
       end
 
       private
