@@ -17,14 +17,13 @@
 #
 
 require 'chef/log'
-require 'chef/mixin/shell_out'
 require 'chef/provider'
 
 class Chef
   class Provider
     class Mdadm < Chef::Provider
 
-      include Chef::Mixin::ShellOut
+      provides :mdadm
 
       def popen4
         raise Exception, "deprecated"
