@@ -18,13 +18,11 @@
 
 require 'chef/provider/mount'
 require 'chef/log'
-require 'chef/mixin/shell_out'
 
 class Chef
   class Provider
     class Mount
       class Mount < Chef::Provider::Mount
-        include Chef::Mixin::ShellOut
 
         def initialize(new_resource, run_context)
           super
@@ -87,7 +85,7 @@ class Chef
 
           shell_out!("mount").stdout.each_line do |line|
             case line
-            when /^#{device_mount_regex}\s+on\s+#{Regexp.escape(real_mount_point)}/
+            when /^#{device_mount_regex}\s+on\s+#{Regexp.escape(real_mount_point)}\s/
               mounted = true
               Chef::Log.debug("Special device #{device_logstring} mounted as #{real_mount_point}")
             when /^([\/\w])+\son\s#{Regexp.escape(real_mount_point)}\s+/
@@ -129,7 +127,7 @@ class Chef
         end
 
         def remount_command
-           return "mount -o remount #{@new_resource.mount_point}"
+          return "mount -o remount,#{@new_resource.options.join(',')} #{@new_resource.mount_point}"
         end
 
         def remount_fs
@@ -169,7 +167,7 @@ class Chef
 
             found = false
             ::File.readlines("/etc/fstab").reverse_each do |line|
-              if !found && line =~ /^#{device_fstab_regex}\s+#{Regexp.escape(@new_resource.mount_point)}/
+              if !found && line =~ /^#{device_fstab_regex}\s+#{Regexp.escape(@new_resource.mount_point)}\s/
                 found = true
                 Chef::Log.debug("#{@new_resource} is removed from fstab")
                 next
@@ -193,7 +191,7 @@ class Chef
         def device_should_exist?
           ( @new_resource.device != "none" ) &&
             ( not network_device? ) &&
-            ( not %w[ tmpfs fuse ].include? @new_resource.fstype )
+            ( not %w[ cgroup tmpfs fuse ].include? @new_resource.fstype )
         end
 
         private
@@ -215,10 +213,9 @@ class Chef
               @real_device = @new_resource.device
             else
               @real_device = ""
-              status = popen4("/sbin/findfs #{device_fstab}") do |pid, stdin, stdout, stderr|
-                device_line = stdout.first # stdout.first consumes
-                @real_device = device_line.chomp unless device_line.nil?
-              end
+              ret = shell_out("/sbin/findfs #{device_fstab}")
+              device_line = ret.stdout.lines.first # stdout.first consumes
+              @real_device = device_line.chomp unless device_line.nil?
             end
           end
           @real_device
