@@ -26,6 +26,8 @@ class Chef
     class Package
       class Aix < Chef::Provider::Package
 
+        provides :bff_package, os: "aix"
+
         include Chef::Mixin::GetSourceFromPackage
 
         def define_resource_requirements
@@ -50,34 +52,30 @@ class Chef
             @package_source_found = ::File.exists?(@new_resource.source)
             if @package_source_found
               Chef::Log.debug("#{@new_resource} checking pkg status")
-              status = popen4("installp -L -d #{@new_resource.source}") do |pid, stdin, stdout, stderr|
-                package_found = false
-                stdout.each do |line|
-                  case line
-                  when /#{@new_resource.package_name}:/
-                    package_found = true
-                    fields = line.split(":")
-                    @new_resource.version(fields[2])
-                  end
+              ret = shell_out("installp -L -d #{@new_resource.source}")
+              ret.stdout.each_line do | line |
+                case line
+                when /#{@new_resource.package_name}:/
+                  fields = line.split(":")
+                  @new_resource.version(fields[2])
                 end
               end
             end
           end
 
           Chef::Log.debug("#{@new_resource} checking install state")
-          status = popen4("lslpp -lcq #{@current_resource.package_name}") do |pid, stdin, stdout, stderr|
-            stdout.each do |line|
-              case line
-              when /#{@current_resource.package_name}/
-                fields = line.split(":")
-                Chef::Log.debug("#{@new_resource} version #{fields[2]} is already installed")
-                @current_resource.version(fields[2])
-              end
+          ret = shell_out("lslpp -lcq #{@current_resource.package_name}")
+          ret.stdout.each_line do | line |
+            case line
+            when /#{@current_resource.package_name}/
+              fields = line.split(":")
+              Chef::Log.debug("#{@new_resource} version #{fields[2]} is already installed")
+              @current_resource.version(fields[2])
             end
           end
 
-          unless status.exitstatus == 0 || status.exitstatus == 1
-            raise Chef::Exceptions::Package, "lslpp failed - #{status.inspect}!"
+          unless ret.exitstatus == 0 || ret.exitstatus == 1
+            raise Chef::Exceptions::Package, "lslpp failed - #{ret.format_for_exception}!"
           end
 
           @current_resource
@@ -85,19 +83,18 @@ class Chef
 
         def candidate_version
           return @candidate_version if @candidate_version
-          status = popen4("installp -L -d #{@new_resource.source}") do |pid, stdin, stdout, stderr|
-            stdout.each_line do |line|
-              case line
-              when /\w:#{Regexp.escape(@new_resource.package_name)}:(.*)/
-                fields = line.split(":")
-                @candidate_version = fields[2]
-                @new_resource.version(fields[2])
-                Chef::Log.debug("#{@new_resource} setting install candidate version to #{@candidate_version}")
-              end
+          ret = shell_out("installp -L -d #{@new_resource.source}")
+          ret.stdout.each_line do | line |
+            case line
+            when /\w:#{Regexp.escape(@new_resource.package_name)}:(.*)/
+              fields = line.split(":")
+              @candidate_version = fields[2]
+              @new_resource.version(fields[2])
+              Chef::Log.debug("#{@new_resource} setting install candidate version to #{@candidate_version}")
             end
           end
-          unless status.exitstatus == 0
-            raise Chef::Exceptions::Package, "installp -L -d #{@new_resource.source} - #{status.inspect}!"
+          unless ret.exitstatus == 0
+            raise Chef::Exceptions::Package, "installp -L -d #{@new_resource.source} - #{ret.format_for_exception}!"
           end
           @candidate_version
         end
@@ -112,14 +109,10 @@ class Chef
         def install_package(name, version)
           Chef::Log.debug("#{@new_resource} package install options: #{@new_resource.options}")
           if @new_resource.options.nil?
-            run_command_with_systems_locale(
-                    :command => "installp -aYF -d #{@new_resource.source} #{@new_resource.package_name}"
-                  )
+            shell_out!( "installp -aYF -d #{@new_resource.source} #{@new_resource.package_name}" )
             Chef::Log.debug("#{@new_resource} installed version #{@new_resource.version} from: #{@new_resource.source}")
           else
-            run_command_with_systems_locale(
-              :command => "installp -aYF #{expand_options(@new_resource.options)} -d #{@new_resource.source} #{@new_resource.package_name}"
-            )
+            shell_out!( "installp -aYF #{expand_options(@new_resource.options)} -d #{@new_resource.source} #{@new_resource.package_name}" )
             Chef::Log.debug("#{@new_resource} installed version #{@new_resource.version} from: #{@new_resource.source}")
           end
         end
@@ -128,14 +121,10 @@ class Chef
 
         def remove_package(name, version)
           if @new_resource.options.nil?
-            run_command_with_systems_locale(
-                    :command => "installp -u #{name}"
-                  )
+            shell_out!( "installp -u #{name}" )
             Chef::Log.debug("#{@new_resource} removed version #{@new_resource.version}")
           else
-            run_command_with_systems_locale(
-              :command => "installp -u #{expand_options(@new_resource.options)} #{name}"
-            )
+            shell_out!( "installp -u #{expand_options(@new_resource.options)} #{name}" )
             Chef::Log.debug("#{@new_resource} removed version #{@new_resource.version}")
           end
         end
