@@ -2,6 +2,10 @@ class Chef
   class Provider
     class Package
       class Macports < Chef::Provider::Package
+
+        provides :macports_package
+        provides :package, os: "darwin"
+
         def load_current_resource
           @current_resource = Chef::Resource::Package.new(@new_resource.name)
           @current_resource.package_name(@new_resource.package_name)
@@ -45,27 +49,21 @@ class Chef
           unless @current_resource.version == version
             command = "port#{expand_options(@new_resource.options)} install #{name}"
             command << " @#{version}" if version and !version.empty?
-            run_command_with_systems_locale(
-              :command => command
-            )
+            shell_out!(command)
           end
         end
 
         def purge_package(name, version)
           command = "port#{expand_options(@new_resource.options)} uninstall #{name}"
           command << " @#{version}" if version and !version.empty?
-          run_command_with_systems_locale(
-            :command => command
-          )
+          shell_out!(command)
         end
 
         def remove_package(name, version)
           command = "port#{expand_options(@new_resource.options)} deactivate #{name}"
           command << " @#{version}" if version and !version.empty?
 
-          run_command_with_systems_locale(
-            :command => command
-          )
+          shell_out!(command)
         end
 
         def upgrade_package(name, version)
@@ -78,21 +76,18 @@ class Chef
             # that hasn't been installed.
             install_package(name, version)
           elsif current_version != version
-            run_command_with_systems_locale(
-              :command => "port#{expand_options(@new_resource.options)} upgrade #{name} @#{version}"
-            )
+            shell_out!( "port#{expand_options(@new_resource.options)} upgrade #{name} @#{version}" )
           end
         end
 
         private
         def get_response_from_command(command)
           output = nil
-          status = popen4(command) do |pid, stdin, stdout, stderr|
-            begin
-              output = stdout.read
-            rescue Exception
-              raise Chef::Exceptions::Package, "Could not read from STDOUT on command: #{command}"
-            end
+          status = shell_out(command)
+          begin
+            output = status.stdout
+          rescue Exception
+            raise Chef::Exceptions::Package, "Could not read from STDOUT on command: #{command}"
           end
           unless status.exitstatus == 0 || status.exitstatus == 1
             raise Chef::Exceptions::Package, "#{command} failed - #{status.insect}!"
