@@ -19,6 +19,7 @@
 require 'chef/provider/package'
 require 'chef/mixin/command'
 require 'chef/resource/package'
+require 'chef/util/path_helper'
 
 class Chef
   class Provider
@@ -34,7 +35,9 @@ class Chef
 
           category, pkg = %r{^#{PACKAGE_NAME_PATTERN}$}.match(@new_resource.package_name)[1,2]
 
-          possibilities = Dir["/var/db/pkg/#{category || "*"}/#{pkg}-*"].map {|d| d.sub(%r{/var/db/pkg/}, "") }
+          globsafe_category = category ? Chef::Util::PathHelper.escape_glob(category) : nil
+          globsafe_pkg = Chef::Util::PathHelper.escape_glob(pkg)
+          possibilities = Dir["/var/db/pkg/#{globsafe_category || "*"}/#{globsafe_pkg}-*"].map {|d| d.sub(%r{/var/db/pkg/}, "") }
           versions = possibilities.map do |entry|
             if(entry =~ %r{[^/]+/#{Regexp.escape(pkg)}\-(\d[\.\d]*((_(alpha|beta|pre|rc|p)\d*)*)?(-r\d+)?)})
               [$&, $1]
@@ -55,7 +58,6 @@ class Chef
           @current_resource
         end
 
-
         def parse_emerge(package, txt)
           availables = {}
           found_package_name = nil
@@ -90,10 +92,9 @@ class Chef
         def candidate_version
           return @candidate_version if @candidate_version
 
-          status = popen4("emerge --color n --nospinner --search #{@new_resource.package_name.split('/').last}") do |pid, stdin, stdout, stderr|
-            available, installed = parse_emerge(@new_resource.package_name, stdout.read)
-            @candidate_version = available
-          end
+          status = shell_out("emerge --color n --nospinner --search #{@new_resource.package_name.split('/').last}")
+          available, installed = parse_emerge(@new_resource.package_name, status.stdout)
+          @candidate_version = available
 
           unless status.exitstatus == 0
             raise Chef::Exceptions::Package, "emerge --search failed - #{status.inspect}!"
@@ -103,7 +104,6 @@ class Chef
 
         end
 
-
         def install_package(name, version)
           pkg = "=#{name}-#{version}"
 
@@ -112,9 +112,7 @@ class Chef
             pkg = "~#{name}-#{$1}"
           end
 
-          run_command_with_systems_locale(
-            :command => "emerge -g --color n --nospinner --quiet#{expand_options(@new_resource.options)} #{pkg}"
-          )
+          shell_out!( "emerge -g --color n --nospinner --quiet#{expand_options(@new_resource.options)} #{pkg}" )
         end
 
         def upgrade_package(name, version)
@@ -128,9 +126,7 @@ class Chef
             pkg = "#{@new_resource.package_name}"
           end
 
-          run_command_with_systems_locale(
-            :command => "emerge --unmerge --color n --nospinner --quiet#{expand_options(@new_resource.options)} #{pkg}"
-          )
+          shell_out!( "emerge --unmerge --color n --nospinner --quiet#{expand_options(@new_resource.options)} #{pkg}" )
         end
 
         def purge_package(name, version)
