@@ -27,6 +27,8 @@ class Chef
 
         include Chef::Mixin::GetSourceFromPackage
 
+        provides :solaris_package, os: "solaris2"
+
         # def initialize(*args)
         #   super
         #   @current_resource = Chef::Resource::Package.new(@new_resource.name)
@@ -53,25 +55,22 @@ class Chef
             @package_source_found = ::File.exists?(@new_resource.source)
             if @package_source_found
               Chef::Log.debug("#{@new_resource} checking pkg status")
-              status = popen4("pkginfo -l -d #{@new_resource.source} #{@new_resource.package_name}") do |pid, stdin, stdout, stderr|
-                stdout.each do |line|
-                  case line
-                  when /VERSION:\s+(.+)/
-                    @new_resource.version($1)
-                  end
+              shell_out("pkginfo -l -d #{@new_resource.source} #{@new_resource.package_name}").stdout.each_line do |line|
+                case line
+                when /VERSION:\s+(.+)/
+                  @new_resource.version($1)
                 end
               end
             end
           end
 
           Chef::Log.debug("#{@new_resource} checking install state")
-          status = popen4("pkginfo -l #{@current_resource.package_name}") do |pid, stdin, stdout, stderr|
-            stdout.each do |line|
-              case line
-              when /VERSION:\s+(.+)/
-                Chef::Log.debug("#{@new_resource} version #{$1} is already installed")
-                @current_resource.version($1)
-              end
+          status = shell_out("pkginfo -l #{@current_resource.package_name}")
+          status.stdout.each_line do |line|
+            case line
+            when /VERSION:\s+(.+)/
+              Chef::Log.debug("#{@new_resource} version #{$1} is already installed")
+              @current_resource.version($1)
             end
           end
 
@@ -88,14 +87,13 @@ class Chef
 
         def candidate_version
           return @candidate_version if @candidate_version
-          status = popen4("pkginfo -l -d #{@new_resource.source} #{new_resource.package_name}") do |pid, stdin, stdout, stderr|
-            stdout.each_line do |line|
-              case line
-              when /VERSION:\s+(.+)/
-                @candidate_version = $1
-                @new_resource.version($1)
-                Chef::Log.debug("#{@new_resource} setting install candidate version to #{@candidate_version}")
-              end
+          status = shell_out("pkginfo -l -d #{@new_resource.source} #{new_resource.package_name}")
+          status.stdout.each_line do |line|
+            case line
+            when /VERSION:\s+(.+)/
+              @candidate_version = $1
+              @new_resource.version($1)
+              Chef::Log.debug("#{@new_resource} setting install candidate version to #{@candidate_version}")
             end
           end
           unless status.exitstatus == 0
@@ -112,9 +110,7 @@ class Chef
             else
               command = "pkgadd -n -d #{@new_resource.source} all"
             end
-            run_command_with_systems_locale(
-                    :command => command
-                  )
+            shell_out!(command)
             Chef::Log.debug("#{@new_resource} installed version #{@new_resource.version} from: #{@new_resource.source}")
           else
             if ::File.directory?(@new_resource.source) # CHEF-4469
@@ -122,23 +118,17 @@ class Chef
             else
               command = "pkgadd -n#{expand_options(@new_resource.options)} -d #{@new_resource.source} all"
             end
-            run_command_with_systems_locale(
-              :command => command
-            )
+            shell_out!(command)
             Chef::Log.debug("#{@new_resource} installed version #{@new_resource.version} from: #{@new_resource.source}")
           end
         end
 
         def remove_package(name, version)
           if @new_resource.options.nil?
-            run_command_with_systems_locale(
-                    :command => "pkgrm -n #{name}"
-                  )
+            shell_out!( "pkgrm -n #{name}" )
             Chef::Log.debug("#{@new_resource} removed version #{@new_resource.version}")
           else
-            run_command_with_systems_locale(
-              :command => "pkgrm -n#{expand_options(@new_resource.options)} #{name}"
-            )
+            shell_out!( "pkgrm -n#{expand_options(@new_resource.options)} #{name}" )
             Chef::Log.debug("#{@new_resource} removed version #{@new_resource.version}")
           end
         end
