@@ -22,7 +22,6 @@
 require 'chef/provider/package'
 require 'chef/mixin/command'
 require 'chef/resource/package'
-require 'chef/mixin/shell_out'
 require 'singleton'
 
 class Chef
@@ -30,8 +29,6 @@ class Chef
     class Package
       class Zypper < Chef::Provider::Package
 
-        include Chef::Mixin::ShellOut
-
         def load_current_resource
           @current_resource = Chef::Resource::Package.new(@new_resource.name)
           @current_resource.package_name(@new_resource.package_name)
@@ -41,24 +38,23 @@ class Chef
           version=''
           oud_version=''
           Chef::Log.debug("#{@new_resource} checking zypper")
-          status = popen4("zypper --non-interactive info #{@new_resource.package_name}") do |pid, stdin, stdout, stderr|
-            stdout.each do |line|
-              case line
-              when /^Version: (.+)$/
-                version = $1
-                Chef::Log.debug("#{@new_resource} version #{$1}")
-              when /^Installed: Yes$/
-                is_installed=true
-                Chef::Log.debug("#{@new_resource} is installed")
+          status = shell_out("zypper --non-interactive info #{@new_resource.package_name}")
+          status.stdout.each_line do |line|
+            case line
+            when /^Version: (.+)$/
+              version = $1
+              Chef::Log.debug("#{@new_resource} version #{$1}")
+            when /^Installed: Yes$/
+              is_installed=true
+              Chef::Log.debug("#{@new_resource} is installed")
 
-              when /^Installed: No$/
-                is_installed=false
-                Chef::Log.debug("#{@new_resource} is not installed")
-              when /^Status: out-of-date \(version (.+) installed\)$/
-                is_out_of_date=true
-                oud_version=$1
-                Chef::Log.debug("#{@new_resource} out of date version #{$1}")
-              end
+            when /^Installed: No$/
+              is_installed=false
+              Chef::Log.debug("#{@new_resource} is not installed")
+            when /^Status: out-of-date \(version (.+) installed\)$/
+              is_out_of_date=true
+              oud_version=$1
+              Chef::Log.debug("#{@new_resource} out of date version #{$1}")
             end
           end
 
@@ -106,7 +102,7 @@ class Chef
 
         private
         def zypper_package(command, pkgname, version)
-          version = "=#{version}" unless version.empty?
+          version = "=#{version}" unless version.nil? || version.empty?
           if zypper_version < 1.0
             shell_out!("zypper#{gpg_checks} #{command} -y #{pkgname}")
           else
