@@ -17,10 +17,15 @@
 #
 
 require 'chef/provider/service/init'
-require 'chef/mixin/command'
 
 class Chef::Provider::Service::Arch < Chef::Provider::Service::Init
 
+  provides :service, platform_family: "arch"
+
+  def self.supports?(resource, action)
+    Chef::Platform::ServiceHelpers.config_for_service(resource.service_name).include?(:etc_rcd)
+  end
+
   def initialize(new_resource, run_context)
     super
     @init_command = "/etc/rc.d/#{@new_resource.service_name}"
