@@ -16,8 +16,6 @@
 # limitations under the License.
 #
 
-require 'chef/mixin/shell_out'
-require 'chef/provider/service'
 require 'chef/provider/service/simple'
 require 'chef/mixin/command'
 
@@ -26,7 +24,13 @@ class Chef
     class Service
       class Init < Chef::Provider::Service::Simple
 
-        include Chef::Mixin::ShellOut
+        attr_accessor :init_command
+
+        provides :service, os: "!windows"
+
+        def self.supports?(resource, action)
+          Chef::Platform::ServiceHelpers.config_for_service(resource.service_name).include?(:initd)
+        end
 
         def initialize(new_resource, run_context)
           super
@@ -52,7 +56,7 @@ class Chef
           if @new_resource.start_command
             super
           else
-            shell_out!("#{default_init_command} start")
+            shell_out_with_systems_locale!("#{default_init_command} start")
           end
         end
 
@@ -60,7 +64,7 @@ class Chef
           if @new_resource.stop_command
             super
           else
-            shell_out!("#{default_init_command} stop")
+            shell_out_with_systems_locale!("#{default_init_command} stop")
           end
         end
 
@@ -68,7 +72,7 @@ class Chef
           if @new_resource.restart_command
             super
           elsif @new_resource.supports[:restart]
-            shell_out!("#{default_init_command} restart")
+            shell_out_with_systems_locale!("#{default_init_command} restart")
           else
             stop_service
             sleep 1
@@ -80,7 +84,7 @@ class Chef
           if @new_resource.reload_command
             super
           elsif @new_resource.supports[:reload]
-            shell_out!("#{default_init_command} reload")
+            shell_out_with_systems_locale!("#{default_init_command} reload")
           end
         end
       end
