@@ -16,17 +16,18 @@
 # limitations under the License.
 #
 
-require 'chef/mixin/shell_out'
 require 'chef/provider/service'
+require 'chef/resource/service'
 require 'chef/mixin/command'
 
 class Chef
   class Provider
     class Service
       class Solaris < Chef::Provider::Service
-        include Chef::Mixin::ShellOut
         attr_reader :maintenance
 
+        provides :service, os: "solaris2"
+
         def initialize(new_resource, run_context=nil)
           super
           @init_command = "/usr/sbin/svcadm"
@@ -34,7 +35,6 @@ class Chef
           @maintenace     = false
         end
 
-
         def load_current_resource
           @current_resource = Chef::Resource::Service.new(@new_resource.name)
           @current_resource.service_name(@new_resource.service_name)
@@ -58,7 +58,7 @@ class Chef
         alias_method :start_service, :enable_service
 
         def reload_service
-          shell_out!("#{default_init_command} refresh #{@new_resource.service_name}")
+          shell_out_with_systems_locale!("#{default_init_command} refresh #{@new_resource.service_name}")
         end
 
         def restart_service
@@ -68,7 +68,7 @@ class Chef
         end
 
         def service_status
-          status = shell_out!("#{@status_command} #{@current_resource.service_name}")
+          status = shell_out!("#{@status_command} #{@current_resource.service_name}", :returns => [0, 1])
           status.stdout.each_line do |line|
             case line
             when /state\s+online/
