@@ -22,10 +22,11 @@ class Chef
   class Resource
     class EasyInstallPackage < Chef::Resource::Package
 
+      provides :easy_install_package
+
       def initialize(name, run_context=nil)
         super
         @resource_name = :easy_install_package
-        @provider = Chef::Provider::Package::EasyInstall
       end
 
       def easy_install_binary(arg=nil)
