@@ -19,8 +19,8 @@
 
 require 'chef/resource'
 require 'chef/platform/query_helpers'
-require 'chef/provider/file'
 require 'chef/mixin/securable'
+require 'chef/resource/file/verification'
 
 class Chef
   class Resource
@@ -38,7 +38,7 @@ class Chef
 
       attr_writer :checksum
 
-      provides :file, :on_platforms => :all
+      provides :file
 
       def initialize(name, run_context=nil)
         super
@@ -47,12 +47,11 @@ class Chef
         @backup = 5
         @action = "create"
         @allowed_actions.push(:create, :delete, :touch, :create_if_missing)
-        @provider = Chef::Provider::File
         @atomic_update = Chef::Config[:file_atomic_update]
         @force_unlink = false
         @manage_symlink_source = nil
         @diff = nil
-        @sensitive = false
+        @verifications = []
       end
 
       def content(arg=nil)
@@ -119,12 +118,16 @@ class Chef
         )
       end
 
-      def sensitive(arg=nil)
-        set_or_return(
-          :sensitive,
-          arg,
-          :kind_of => [ TrueClass, FalseClass ]
-        )
+      def verify(command=nil, opts={}, &block)
+        if ! (command.nil? || [String, Symbol].include?(command.class))
+          raise ArgumentError, "verify requires either a string, symbol, or a block"
+        end
+
+        if command || block_given?
+          @verifications << Verification.new(self, command, opts, &block)
+        else
+          @verifications
+        end
       end
     end
   end
