@@ -22,10 +22,11 @@ class Chef
   class Resource
     class Git < Chef::Resource::Scm
 
+      provides :git
+
       def initialize(name, run_context=nil)
         super
         @resource_name = :git
-        @provider = Chef::Provider::Git
         @additional_remotes = Hash[]
       end
 
