@@ -23,10 +23,20 @@ class Chef
   class Resource
     class RpmPackage < Chef::Resource::Package
 
+      provides :rpm_package, os: [ "linux", "aix" ]
+
       def initialize(name, run_context=nil)
         super
         @resource_name = :rpm_package
-        @provider = Chef::Provider::Package::Rpm
+        @allow_downgrade = false
+      end
+
+      def allow_downgrade(arg=nil)
+        set_or_return(
+          :allow_downgrade,
+          arg,
+          :kind_of => [ TrueClass, FalseClass ]
+        )
       end
 
     end
