@@ -17,6 +17,9 @@
 # limitations under the License.
 #
 
+require 'chef/resource'
+require 'chef/provider/ruby_block'
+
 class Chef
   class Resource
     class RubyBlock < Chef::Resource
