@@ -26,6 +26,8 @@ class Chef
 
       state_attrs :uid, :gid, :home
 
+      provides :user
+
       def initialize(name, run_context=nil)
         super
         @resource_name = :user
@@ -38,12 +40,15 @@ class Chef
         @password = nil
         @system = false
         @manage_home = false
+        @force = false
         @non_unique = false
         @action = :create
         @supports = {
           :manage_home => false,
           :non_unique => false
         }
+        @iterations = 27855
+        @salt = nil
         @allowed_actions.push(:create, :remove, :modify, :manage, :lock, :unlock)
       end
 
@@ -105,6 +110,22 @@ class Chef
         )
       end
 
+      def salt(arg=nil)
+        set_or_return(
+          :salt,
+          arg,
+          :kind_of => [ String ]
+        )
+      end
+
+      def iterations(arg=nil)
+        set_or_return(
+          :iterations,
+          arg,
+          :kind_of => [ Integer ]
+        )
+      end
+
       def system(arg=nil)
         set_or_return(
           :system,
@@ -121,6 +142,14 @@ class Chef
         )
       end
 
+      def force(arg=nil)
+        set_or_return(
+          :force,
+          arg,
+          :kind_of => [ TrueClass, FalseClass ]
+        )
+      end
+
       def non_unique(arg=nil)
         set_or_return(
           :non_unique,
