@@ -23,10 +23,12 @@ class Chef
   class Resource
     class YumPackage < Chef::Resource::Package
 
+      provides :yum_package
+      provides :package, os: "linux", platform_family: [ "rhel", "fedora" ]
+
       def initialize(name, run_context=nil)
         super
         @resource_name = :yum_package
-        @provider = Chef::Provider::Package::Yum
         @flush_cache = { :before => false, :after => false }
         @allow_downgrade = false
       end
