@@ -39,6 +39,7 @@ require 'chef/platform/query_helpers'
 require 'chef/http/remote_request_id'
 
 class Chef
+
   # == Chef::REST
   # Chef's custom REST client with built-in JSON support and RSA signed header
   # authentication.
@@ -57,6 +58,9 @@ class Chef
     # http://localhost:4000, a call to +get_rest+ with 'nodes' will make an
     # HTTP GET request to http://localhost:4000/nodes
     def initialize(url, client_name=Chef::Config[:node_name], signing_key_filename=Chef::Config[:client_key], options={})
+
+      signing_key_filename = nil if chef_zero_uri?(url)
+
       options = options.dup
       options[:client_name] = client_name
       options[:signing_key_filename] = signing_key_filename
@@ -188,11 +192,6 @@ class Chef
 
     public :create_url
 
-    def http_client(base_url=nil)
-      base_url ||= url
-      BasicClient.new(base_url, :ssl_policy => Chef::HTTP::APISSLPolicy)
-    end
-
     ############################################################################
     # DEPRECATED
     ############################################################################
