@@ -32,17 +32,20 @@ class Chef
     include Chef::Mixin::FromFile
     include Chef::Mixin::ParamsValidate
 
+    attr_accessor :chef_server_rest
+
     # Create a new Chef::Role object.
-    def initialize
+    def initialize(chef_server_rest: nil)
       @name = ''
       @description = ''
       @default_attributes = Mash.new
       @override_attributes = Mash.new
       @env_run_lists = {"_default" => Chef::RunList.new}
+      @chef_server_rest = chef_server_rest
     end
 
     def chef_server_rest
-      Chef::REST.new(Chef::Config[:chef_server_url])
+      @chef_server_rest ||= Chef::REST.new(Chef::Config[:chef_server_url])
     end
 
     def self.chef_server_rest
@@ -103,6 +106,16 @@ class Chef
 
     alias :env_run_list :env_run_lists
 
+    def env_run_lists_add(env_run_lists=nil)
+      if (!env_run_lists.nil?)
+        env_run_lists.each { |k,v| @env_run_lists[k] = Chef::RunList.new(*Array(v))}
+      end
+      @env_run_lists
+    end
+
+    alias :env_run_list_add :env_run_lists_add
+
+
     def default_attributes(arg=nil)
       set_or_return(
         :default_attributes,
@@ -143,7 +156,7 @@ class Chef
 
     # Serialize this object as a hash
     def to_json(*a)
-      to_hash.to_json(*a)
+      Chef::JSONCompat.to_json(to_hash, *a)
     end
 
     def update_from!(o)
@@ -231,21 +244,25 @@ class Chef
     end
 
     # Load a role from disk - prefers to load the JSON, but will happily load
-    # the raw rb files as well.
-    def self.from_disk(name, force=nil)
+    # the raw rb files as well. Can search within directories in the role_path.
+    def self.from_disk(name)
       paths = Array(Chef::Config[:role_path])
+      paths.each do |path|
+        roles_files = Dir.glob(File.join(Chef::Util::PathHelper.escape_glob(path), "**", "**"))
+        js_files = roles_files.select { |file| file.match(/\/#{name}\.json$/) }
+        rb_files = roles_files.select { |file| file.match(/\/#{name}\.rb$/) }
+        if js_files.count > 1 or rb_files.count > 1
+          raise Chef::Exceptions::DuplicateRole, "Multiple roles of same type found named #{name}"
+        end
+        js_path, rb_path = js_files.first, rb_files.first
 
-      paths.each do |p|
-        js_file = File.join(p, "#{name}.json")
-        rb_file = File.join(p, "#{name}.rb")
-
-        if File.exists?(js_file) || force == "json"
+        if js_path && File.exists?(js_path)
           # from_json returns object.class => json_class in the JSON.
-          return Chef::JSONCompat.from_json(IO.read(js_file))
-        elsif File.exists?(rb_file) || force == "ruby"
+          return Chef::JSONCompat.from_json(IO.read(js_path))
+        elsif rb_path && File.exists?(rb_path)
           role = Chef::Role.new
           role.name(name)
-          role.from_file(rb_file)
+          role.from_file(rb_path)
           return role
         end
       end
