@@ -85,8 +85,12 @@ class Chef
       @run_list_items.join(", ")
     end
 
-    def to_json(*args)
-      to_a.map { |item| item.to_s}.to_json(*args)
+    def for_json
+      to_a.map { |item| item.to_s }
+    end
+
+    def to_json(*a)
+      Chef::JSONCompat.to_json(for_json, *a)
     end
 
     def empty?
@@ -158,6 +162,5 @@ class Chef
       end
     end
 
-
   end
 end
