@@ -211,8 +211,8 @@ E
       def version
         puts  "This is the chef-shell.\n" +
               " Chef Version: #{::Chef::VERSION}\n" +
-              " http://www.opscode.com/chef\n" +
-              " http://docs.opscode.com/"
+              " http://www.chef.io/\n" +
+              " http://docs.chef.io/"
         :ucanhaz_automation
       end
       alias :shell :version
@@ -547,7 +547,7 @@ E
       desc "list all the resources on the current recipe"
       def resources(*args)
         if args.empty?
-          pp run_context.resource_collection.instance_variable_get(:@resources_by_name).keys
+          pp run_context.resource_collection.keys
         else
           pp resources = original_resources(*args)
           resources
