@@ -18,10 +18,15 @@
 
 require 'chef/win32/api'
 require 'chef/win32/api/system'
+require 'wmi-lite/wmi'
 
 class Chef
   module ReservedNames::Win32
     class Version
+      class << self
+        include Chef::ReservedNames::Win32::API::System
+      end
+
       include Chef::ReservedNames::Win32::API::Macros
       include Chef::ReservedNames::Win32::API::System
 
@@ -29,20 +34,22 @@ class Chef
       # http://msdn.microsoft.com/en-us/library/ms724833(v=vs.85).aspx
       # http://msdn.microsoft.com/en-us/library/ms724358(v=vs.85).aspx
 
-      private
-
       def self.get_system_metrics(n_index)
-        Win32API.new('user32', 'GetSystemMetrics', 'I', 'I').call(n_index)
+        GetSystemMetrics(n_index)
       end
 
+      private_class_method :get_system_metrics
+
       def self.method_name_from_marketing_name(marketing_name)
         "#{marketing_name.gsub(/\s/, '_').gsub(/\./, '_').downcase}?"
-        # "#{marketing_name.gsub(/\s/, '_').gsub(//, '_').downcase}?"       
+        # "#{marketing_name.gsub(/\s/, '_').gsub(//, '_').downcase}?"
       end
 
-      public
+      private_class_method :method_name_from_marketing_name
 
       WIN_VERSIONS = {
+        "Windows 10" => {:major => 6, :minor => 4, :callable => lambda{ |product_type, suite_mask| product_type == VER_NT_WORKSTATION }},
+        "Windows Server 10" => {:major => 6, :minor => 4, :callable => lambda {|product_type, suite_mask| product_type != VER_NT_WORKSTATION }},
         "Windows 8.1" => {:major => 6, :minor => 3, :callable => lambda{ |product_type, suite_mask| product_type == VER_NT_WORKSTATION }},
         "Windows Server 2012 R2" => {:major => 6, :minor => 3, :callable => lambda {|product_type, suite_mask| product_type != VER_NT_WORKSTATION }},
         "Windows 8" => {:major => 6, :minor => 2, :callable => lambda{ |product_type, suite_mask| product_type == VER_NT_WORKSTATION }},
@@ -114,18 +121,14 @@ class Chef
         # version numbers on Windows Server 2012 R2 and Windows 8.1 --
         # WMI always returns the truth. See article at
         # http://msdn.microsoft.com/en-us/library/windows/desktop/ms724439(v=vs.85).aspx
-        require 'ruby-wmi'
 
         # CHEF-4888: Work around ruby #2618, expected to be fixed in Ruby 2.1.0
         # https://github.com/ruby/ruby/commit/588504b20f5cc880ad51827b93e571e32446e5db
         # https://github.com/ruby/ruby/commit/27ed294c7134c0de582007af3c915a635a6506cd
 
-        WIN32OLE.ole_initialize
-
-        os_info = WMI::Win32_OperatingSystem.find(:first)
-        os_version = os_info.send('Version')
-
-        WIN32OLE.ole_uninitialize
+        wmi = WmiLite::Wmi.new
+        os_info = wmi.first_of('Win32_OperatingSystem')
+        os_version = os_info['version']
 
         # The operating system version is a string in the following form
         # that can be split into components based on the '.' delimiter:
