@@ -19,13 +19,13 @@
 require 'spec_helper'
 if Chef::Platform.windows?
   require 'chef/win32/version'
-  require 'ruby-wmi'
 end
 
 describe "Chef::ReservedNames::Win32::Version", :windows_only, :not_supported_on_win2k3 do
   before do
 
-    host = WMI::Win32_OperatingSystem.find(:first)
+    wmi = WmiLite::Wmi.new
+    host = wmi.first_of('Win32_OperatingSystem')
 
     # Use WMI to determine current OS version.
     # On Win2k8R2 and later, we can dynamically obtain marketing
@@ -44,7 +44,7 @@ describe "Chef::ReservedNames::Win32::Version", :windows_only, :not_supported_on
       # The name from WMI is actually what we want in Win2k8R2+.
       # So this expectation sould continue to hold without modification
       # as new versions of Windows are released.
-      @current_os_version = host.caption
+      @current_os_version = host['caption']
     end
 
     @version = Chef::ReservedNames::Win32::Version.new
@@ -62,8 +62,8 @@ describe "Chef::ReservedNames::Win32::Version", :windows_only, :not_supported_on
     it "should have have one method for each marketing version" do
       versions = 0
       for_each_windows_version { versions += 1 }
-      versions.should > 0
-      versions.should == Chef::ReservedNames::Win32::Version::WIN_VERSIONS.length
+      expect(versions).to be > 0
+      expect(versions).to eq(Chef::ReservedNames::Win32::Version::WIN_VERSIONS.length)
     end
 
     it "should only contain version methods with legal method names" do
@@ -71,8 +71,8 @@ describe "Chef::ReservedNames::Win32::Version", :windows_only, :not_supported_on
 
       for_each_windows_version do |method_name|
         method_match = method_name_pattern.match(method_name.to_s)
-        method_match.should_not be_nil
-        method_name.to_s.should == method_match[0]
+        expect(method_match).not_to be_nil
+        expect(method_name.to_s).to eq(method_match[0])
       end
     end
 
@@ -81,7 +81,7 @@ describe "Chef::ReservedNames::Win32::Version", :windows_only, :not_supported_on
       for_each_windows_version do |method_name|
         true_versions += 1 if @version.send(method_name)
       end
-      true_versions.should == 1
+      expect(true_versions).to eq(1)
     end
 
     it "should successfully execute all version methods" do
@@ -91,14 +91,14 @@ describe "Chef::ReservedNames::Win32::Version", :windows_only, :not_supported_on
 
   context "Windows Operating System version" do
     it "should match the version from WMI" do
-      @current_os_version.should include(@version.marketing_name)
+      expect(@current_os_version).to include(@version.marketing_name)
     end
   end
 
   def is_windows_server_2008?(wmi_host)
     is_win2k8 = false
 
-    os_version = wmi_host.send('Version')
+    os_version = wmi_host['version']
 
     # The operating system version is a string in the following form
     # that can be split into components based on the '.' delimiter:
