@@ -16,27 +16,30 @@
 # limitations under the License.
 
 require 'support/shared/integration/integration_helper'
+require 'support/shared/context/config'
 require 'chef/knife/deps'
 
-describe 'knife deps' do
-  extend IntegrationSupport
+describe 'knife deps', :workstation do
+  include IntegrationSupport
   include KnifeSupport
 
   context 'local' do
     when_the_repository 'has a role with no run_list' do
-      file 'roles/starring.json', {}
+      before { file 'roles/starring.json', {} }
       it 'knife deps reports no dependencies' do
         knife('deps /roles/starring.json').should_succeed "/roles/starring.json\n"
       end
     end
 
     when_the_repository 'has a role with a default run_list' do
-      file 'roles/starring.json', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
-      file 'roles/minor.json', {}
-      file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
-      file 'cookbooks/quiche/recipes/default.rb', ''
-      file 'cookbooks/soup/metadata.rb', 'name "soup"'
-      file 'cookbooks/soup/recipes/chicken.rb', ''
+      before do
+        file 'roles/starring.json', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+        file 'roles/minor.json', {}
+        file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
+        file 'cookbooks/quiche/recipes/default.rb', ''
+        file 'cookbooks/soup/metadata.rb', 'name "soup"'
+        file 'cookbooks/soup/recipes/chicken.rb', ''
+      end
       it 'knife deps reports all dependencies' do
         knife('deps /roles/starring.json').should_succeed <<EOM
 /roles/minor.json
@@ -48,12 +51,14 @@ EOM
     end
 
     when_the_repository 'has a role with an env_run_list' do
-      file 'roles/starring.json', { 'env_run_lists' => { 'desert' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) } }
-      file 'roles/minor.json', {}
-      file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
-      file 'cookbooks/quiche/recipes/default.rb', ''
-      file 'cookbooks/soup/metadata.rb', 'name "soup"'
-      file 'cookbooks/soup/recipes/chicken.rb', ''
+      before do
+        file 'roles/starring.json', { 'env_run_lists' => { 'desert' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) } }
+        file 'roles/minor.json', {}
+        file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
+        file 'cookbooks/quiche/recipes/default.rb', ''
+        file 'cookbooks/soup/metadata.rb', 'name "soup"'
+        file 'cookbooks/soup/recipes/chicken.rb', ''
+      end
       it 'knife deps reports all dependencies' do
         knife('deps /roles/starring.json').should_succeed <<EOM
 /roles/minor.json
@@ -65,25 +70,29 @@ EOM
     end
 
     when_the_repository 'has a node with no environment or run_list' do
-      file 'nodes/mort.json', {}
+      before { file 'nodes/mort.json', {} }
       it 'knife deps reports just the node' do
         knife('deps /nodes/mort.json').should_succeed "/nodes/mort.json\n"
       end
     end
     when_the_repository 'has a node with an environment' do
-      file 'environments/desert.json', {}
-      file 'nodes/mort.json', { 'chef_environment' => 'desert' }
+      before do
+        file 'environments/desert.json', {}
+        file 'nodes/mort.json', { 'chef_environment' => 'desert' }
+      end
       it 'knife deps reports just the node' do
         knife('deps /nodes/mort.json').should_succeed "/environments/desert.json\n/nodes/mort.json\n"
       end
     end
     when_the_repository 'has a node with roles and recipes in its run_list' do
-      file 'roles/minor.json', {}
-      file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
-      file 'cookbooks/quiche/recipes/default.rb', ''
-      file 'cookbooks/soup/metadata.rb', 'name "soup"'
-      file 'cookbooks/soup/recipes/chicken.rb', ''
-      file 'nodes/mort.json', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+      before do
+        file 'roles/minor.json', {}
+        file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
+        file 'cookbooks/quiche/recipes/default.rb', ''
+        file 'cookbooks/soup/metadata.rb', 'name "soup"'
+        file 'cookbooks/soup/recipes/chicken.rb', ''
+        file 'nodes/mort.json', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+      end
       it 'knife deps reports just the node' do
         knife('deps /nodes/mort.json').should_succeed <<EOM
 /roles/minor.json
@@ -94,42 +103,49 @@ EOM
       end
     end
     when_the_repository 'has a cookbook with no dependencies' do
-      file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
-      file 'cookbooks/quiche/recipes/default.rb', ''
+      before do
+        file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
+        file 'cookbooks/quiche/recipes/default.rb', ''
+      end
       it 'knife deps reports just the cookbook' do
         knife('deps /cookbooks/quiche').should_succeed "/cookbooks/quiche\n"
       end
     end
     when_the_repository 'has a cookbook with dependencies' do
-      file 'cookbooks/kettle/metadata.rb', 'name "kettle"'
-      file 'cookbooks/quiche/metadata.rb', "name 'quiche'\ndepends 'kettle'\n"
-      file 'cookbooks/quiche/recipes/default.rb', ''
+      before do
+        file 'cookbooks/kettle/metadata.rb', 'name "kettle"'
+        file 'cookbooks/quiche/metadata.rb', 'name "quiche"
+depends "kettle"'
+        file 'cookbooks/quiche/recipes/default.rb', ''
+      end
       it 'knife deps reports just the cookbook' do
         knife('deps /cookbooks/quiche').should_succeed "/cookbooks/kettle\n/cookbooks/quiche\n"
       end
     end
     when_the_repository 'has a data bag' do
-      file 'data_bags/bag/item.json', {}
+      before { file 'data_bags/bag/item.json', {} }
       it 'knife deps reports just the data bag' do
         knife('deps /data_bags/bag/item.json').should_succeed "/data_bags/bag/item.json\n"
       end
     end
     when_the_repository 'has an environment' do
-      file 'environments/desert.json', {}
+      before { file 'environments/desert.json', {} }
       it 'knife deps reports just the environment' do
         knife('deps /environments/desert.json').should_succeed "/environments/desert.json\n"
       end
     end
     when_the_repository 'has a deep dependency tree' do
-      file 'roles/starring.json', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
-      file 'roles/minor.json', {}
-      file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
-      file 'cookbooks/quiche/recipes/default.rb', ''
-      file 'cookbooks/soup/metadata.rb', 'name "soup"'
-      file 'cookbooks/soup/recipes/chicken.rb', ''
-      file 'environments/desert.json', {}
-      file 'nodes/mort.json', { 'chef_environment' => 'desert', 'run_list' => [ 'role[starring]' ] }
-      file 'nodes/bart.json', { 'run_list' => [ 'role[minor]' ] }
+      before do
+        file 'roles/starring.json', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+        file 'roles/minor.json', {}
+        file 'cookbooks/quiche/metadata.rb', 'name "quiche"'
+        file 'cookbooks/quiche/recipes/default.rb', ''
+        file 'cookbooks/soup/metadata.rb', 'name "soup"'
+        file 'cookbooks/soup/recipes/chicken.rb', ''
+        file 'environments/desert.json', {}
+        file 'nodes/mort.json', { 'chef_environment' => 'desert', 'run_list' => [ 'role[starring]' ] }
+        file 'nodes/bart.json', { 'run_list' => [ 'role[minor]' ] }
+      end
 
       it 'knife deps reports all dependencies' do
         knife('deps /nodes/mort.json').should_succeed <<EOM
@@ -188,10 +204,17 @@ EOM
 
     context 'circular dependencies' do
       when_the_repository 'has cookbooks with circular dependencies' do
-        file 'cookbooks/foo/metadata.rb', "name 'foo'\ndepends 'bar'\n"
-        file 'cookbooks/bar/metadata.rb', "name 'bar'\ndepends 'baz'\n"
-        file 'cookbooks/baz/metadata.rb', "name 'baz'\ndepends 'foo'\n"
-        file 'cookbooks/self/metadata.rb', "name 'self'\ndepends 'self'\n"
+        before do
+          file 'cookbooks/foo/metadata.rb', 'name "foo"
+depends "bar"'
+          file 'cookbooks/bar/metadata.rb', 'name "bar"
+depends "baz"'
+          file 'cookbooks/baz/metadata.rb', 'name "baz"
+depends "foo"'
+          file 'cookbooks/self/metadata.rb', 'name "self"
+depends "self"'
+        end
+
         it 'knife deps prints each once' do
           knife('deps /cookbooks/foo /cookbooks/self').should_succeed <<EOM
 /cookbooks/baz
@@ -212,10 +235,12 @@ EOM
         end
       end
       when_the_repository 'has roles with circular dependencies' do
-        file 'roles/foo.json', { 'run_list' => [ 'role[bar]' ] }
-        file 'roles/bar.json', { 'run_list' => [ 'role[baz]' ] }
-        file 'roles/baz.json', { 'run_list' => [ 'role[foo]' ] }
-        file 'roles/self.json', { 'run_list' => [ 'role[self]' ] }
+        before do
+          file 'roles/foo.json', { 'run_list' => [ 'role[bar]' ] }
+          file 'roles/bar.json', { 'run_list' => [ 'role[baz]' ] }
+          file 'roles/baz.json', { 'run_list' => [ 'role[foo]' ] }
+          file 'roles/self.json', { 'run_list' => [ 'role[self]' ] }
+        end
         it 'knife deps prints each once' do
           knife('deps /roles/foo.json /roles/self.json').should_succeed <<EOM
 /roles/baz.json
@@ -226,8 +251,8 @@ EOM
         end
         it 'knife deps --tree prints each once' do
           knife('deps --tree /roles/foo.json /roles/self.json') do
-            stdout.should == "/roles/foo.json\n  /roles/bar.json\n    /roles/baz.json\n      /roles/foo.json\n/roles/self.json\n  /roles/self.json\n"
-            stderr.should == "WARNING: No knife configuration file found\n"
+            expect(stdout).to eq("/roles/foo.json\n  /roles/bar.json\n    /roles/baz.json\n      /roles/foo.json\n/roles/self.json\n  /roles/self.json\n")
+            expect(stderr).to eq("WARNING: No knife configuration file found\n")
           end
         end
       end
@@ -279,7 +304,9 @@ EOM
         end
       end
       when_the_repository 'is missing a dependent cookbook' do
-        file 'roles/starring.json', { 'run_list' => [ 'recipe[quiche]'] }
+        before do
+          file 'roles/starring.json', { 'run_list' => [ 'recipe[quiche]'] }
+        end
         it 'knife deps reports the cookbook, along with an error' do
           knife('deps /roles/starring.json').should_fail(
             :exit_code => 2,
@@ -289,7 +316,9 @@ EOM
         end
       end
       when_the_repository 'is missing a dependent environment' do
-        file 'nodes/mort.json', { 'chef_environment' => 'desert' }
+        before do
+          file 'nodes/mort.json', { 'chef_environment' => 'desert' }
+        end
         it 'knife deps reports the environment, along with an error' do
           knife('deps /nodes/mort.json').should_fail(
             :exit_code => 2,
@@ -299,7 +328,9 @@ EOM
         end
       end
       when_the_repository 'is missing a dependent role' do
-        file 'roles/starring.json', { 'run_list' => [ 'role[minor]'] }
+        before do
+          file 'roles/starring.json', { 'run_list' => [ 'role[minor]'] }
+        end
         it 'knife deps reports the role, along with an error' do
           knife('deps /roles/starring.json').should_fail(
             :exit_code => 2,
@@ -323,13 +354,13 @@ EOM
         end
       end
       when_the_repository 'has a data bag' do
-        file 'data_bags/bag/item.json', ''
+        before { file 'data_bags/bag/item.json', '' }
         it 'knife deps /data_bags/bag shows no dependencies' do
           knife('deps /data_bags/bag').should_succeed("/data_bags/bag\n")
         end
       end
       when_the_repository 'has a cookbook' do
-        file 'cookbooks/blah/metadata.rb', 'name "blah"'
+        before { file 'cookbooks/blah/metadata.rb', 'name "blah"' }
         it 'knife deps on a cookbook file shows no dependencies' do
           knife('deps /cookbooks/blah/metadata.rb').should_succeed(
             "/cookbooks/blah/metadata.rb\n"
@@ -340,18 +371,22 @@ EOM
   end
 
   context 'remote' do
+    include_context "default config options"
+
     when_the_chef_server 'has a role with no run_list' do
-      role 'starring', {}
+      before { role 'starring', {} }
       it 'knife deps reports no dependencies' do
         knife('deps --remote /roles/starring.json').should_succeed "/roles/starring.json\n"
       end
     end
 
     when_the_chef_server 'has a role with a default run_list' do
-      role 'starring', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
-      role 'minor', {}
-      cookbook 'quiche', '1.0.0', { 'metadata.rb' => "name 'quiche'\nversion '1.0.0'\n", 'recipes' => { 'default.rb' => '' } }
-      cookbook 'soup', '1.0.0', { 'metadata.rb' => "name 'soup'\nversion '1.0.0'\n", 'recipes' => { 'chicken.rb' => '' } }
+      before do
+        role 'starring', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+        role 'minor', {}
+        cookbook 'quiche', '1.0.0', { 'metadata.rb' => %Q{name "quiche"\nversion "1.0.0"\n}, 'recipes' => { 'default.rb' => '' } }
+        cookbook 'soup', '1.0.0', { 'metadata.rb' => %Q{name "soup"\nversion "1.0.0"\n}, 'recipes' => { 'chicken.rb' => '' } }
+      end
       it 'knife deps reports all dependencies' do
         knife('deps --remote /roles/starring.json').should_succeed <<EOM
 /roles/minor.json
@@ -363,10 +398,12 @@ EOM
     end
 
     when_the_chef_server 'has a role with an env_run_list' do
-      role 'starring', { 'env_run_lists' => { 'desert' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) } }
-      role 'minor', {}
-      cookbook 'quiche', '1.0.0', { 'metadata.rb' => "name 'quiche'\nversion '1.0.0'\n", 'recipes' => { 'default.rb' => '' } }
-      cookbook 'soup', '1.0.0', { 'metadata.rb' =>   "name 'soup'\nversion '1.0.0'\n", 'recipes' => { 'chicken.rb' => '' } }
+      before do
+        role 'starring', { 'env_run_lists' => { 'desert' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) } }
+        role 'minor', {}
+        cookbook 'quiche', '1.0.0', { 'metadata.rb' => %Q{name "quiche"\nversion "1.0.0"\n}, 'recipes' => { 'default.rb' => '' } }
+        cookbook 'soup', '1.0.0', { 'metadata.rb' =>   %Q{name "soup"\nversion "1.0.0"\n}, 'recipes' => { 'chicken.rb' => '' } }
+      end
       it 'knife deps reports all dependencies' do
         knife('deps --remote /roles/starring.json').should_succeed <<EOM
 /roles/minor.json
@@ -378,23 +415,27 @@ EOM
     end
 
     when_the_chef_server 'has a node with no environment or run_list' do
-      node 'mort', {}
+      before { node 'mort', {} }
       it 'knife deps reports just the node' do
         knife('deps --remote /nodes/mort.json').should_succeed "/nodes/mort.json\n"
       end
     end
     when_the_chef_server 'has a node with an environment' do
-      environment 'desert', {}
-      node 'mort', { 'chef_environment' => 'desert' }
+      before do
+        environment 'desert', {}
+        node 'mort', { 'chef_environment' => 'desert' }
+      end
       it 'knife deps reports just the node' do
         knife('deps --remote /nodes/mort.json').should_succeed "/environments/desert.json\n/nodes/mort.json\n"
       end
     end
     when_the_chef_server 'has a node with roles and recipes in its run_list' do
-      role 'minor', {}
-      cookbook 'quiche', '1.0.0', { 'metadata.rb' => "name 'quiche'\nversion '1.0.0'\n", 'recipes' => { 'default.rb' => '' } }
-      cookbook 'soup', '1.0.0', { 'metadata.rb' =>   "name 'soup'\nversion '1.0.0'\n", 'recipes' => { 'chicken.rb' => '' } }
-      node 'mort', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+      before do
+        role 'minor', {}
+        cookbook 'quiche', '1.0.0', { 'metadata.rb' => %Q{name "quiche"\nversion "1.0.0"\n}, 'recipes' => { 'default.rb' => '' } }
+        cookbook 'soup', '1.0.0', { 'metadata.rb' =>   %Q{name "soup"\nversion "1.0.0"\n}, 'recipes' => { 'chicken.rb' => '' } }
+        node 'mort', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+      end
       it 'knife deps reports just the node' do
         knife('deps --remote /nodes/mort.json').should_succeed <<EOM
 /roles/minor.json
@@ -405,38 +446,45 @@ EOM
       end
     end
     when_the_chef_server 'has a cookbook with no dependencies' do
-      cookbook 'quiche', '1.0.0', { 'metadata.rb' => "name 'quiche'\nversion '1.0.0'\n", 'recipes' => { 'default.rb' => '' } }
+      before do
+        cookbook 'quiche', '1.0.0', { 'metadata.rb' => %Q{name "quiche"\nversion "1.0.0"\n}, 'recipes' => { 'default.rb' => '' } }
+      end
       it 'knife deps reports just the cookbook' do
         knife('deps --remote /cookbooks/quiche').should_succeed "/cookbooks/quiche\n"
       end
     end
     when_the_chef_server 'has a cookbook with dependencies' do
-      cookbook 'kettle', '1.0.0', { 'metadata.rb' => "name 'kettle'\nversion '1.0.0'\n" }
-      cookbook 'quiche', '1.0.0', { 'metadata.rb' => "name 'quiche'\ndepends 'kettle'\n", 'recipes' => { 'default.rb' => '' } }
+      before do
+        cookbook 'kettle', '1.0.0', { 'metadata.rb' => %Q{name "kettle"\nversion "1.0.0"\n} }
+        cookbook 'quiche', '1.0.0', { 'metadata.rb' => 'name "quiche"
+depends "kettle"', 'recipes' => { 'default.rb' => '' } }
+      end
       it 'knife deps reports the cookbook and its dependencies' do
         knife('deps --remote /cookbooks/quiche').should_succeed "/cookbooks/kettle\n/cookbooks/quiche\n"
       end
     end
     when_the_chef_server 'has a data bag' do
-      data_bag 'bag', { 'item' => {} }
+      before { data_bag 'bag', { 'item' => {} } }
       it 'knife deps reports just the data bag' do
         knife('deps --remote /data_bags/bag/item.json').should_succeed "/data_bags/bag/item.json\n"
       end
     end
     when_the_chef_server 'has an environment' do
-      environment 'desert', {}
+      before { environment 'desert', {} }
       it 'knife deps reports just the environment' do
         knife('deps --remote /environments/desert.json').should_succeed "/environments/desert.json\n"
       end
     end
     when_the_chef_server 'has a deep dependency tree' do
-      role 'starring', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
-      role 'minor', {}
-      cookbook 'quiche', '1.0.0', { 'metadata.rb' => "name 'quiche'\nversion '1.0.0'\n", 'recipes' => { 'default.rb' => '' } }
-      cookbook 'soup', '1.0.0', { 'metadata.rb' =>   "name 'soup'\nversion '1.0.0'\n", 'recipes' => { 'chicken.rb' => '' } }
-      environment 'desert', {}
-      node 'mort', { 'chef_environment' => 'desert', 'run_list' => [ 'role[starring]' ] }
-      node 'bart', { 'run_list' => [ 'role[minor]' ] }
+      before do
+        role 'starring', { 'run_list' => %w(role[minor] recipe[quiche] recipe[soup::chicken]) }
+        role 'minor', {}
+        cookbook 'quiche', '1.0.0', { 'metadata.rb' => %Q{name "quiche"\nversion "1.0.0"\n}, 'recipes' => { 'default.rb' => '' } }
+        cookbook 'soup', '1.0.0', { 'metadata.rb' =>   %Q{name "soup"\nversion "1.0.0"\n}, 'recipes' => { 'chicken.rb' => '' } }
+        environment 'desert', {}
+        node 'mort', { 'chef_environment' => 'desert', 'run_list' => [ 'role[starring]' ] }
+        node 'bart', { 'run_list' => [ 'role[minor]' ] }
+      end
 
       it 'knife deps reports all dependencies' do
         knife('deps --remote /nodes/mort.json').should_succeed <<EOM
@@ -495,10 +543,16 @@ EOM
 
     context 'circular dependencies' do
       when_the_chef_server 'has cookbooks with circular dependencies' do
-        cookbook 'foo', '1.0.0', { 'metadata.rb'  => "name 'foo'\ndepends 'bar'\n" }
-        cookbook 'bar', '1.0.0', { 'metadata.rb'  => "name 'bar'\ndepends 'baz'\n" }
-        cookbook 'baz', '1.0.0', { 'metadata.rb'  => "name 'baz'\ndepends 'foo'\n" }
-        cookbook 'self', '1.0.0', { 'metadata.rb' => "name 'self'\ndepends 'self'\n" }
+        before do
+          cookbook 'foo', '1.0.0', { 'metadata.rb'  => 'name "foo"
+depends "bar"' }
+          cookbook 'bar', '1.0.0', { 'metadata.rb'  => 'name "bar"
+depends "baz"' }
+          cookbook 'baz', '1.0.0', { 'metadata.rb'  => 'name "baz"
+depends "foo"' }
+          cookbook 'self', '1.0.0', { 'metadata.rb' => 'name "self"
+depends "self"' }
+        end
         it 'knife deps prints each once' do
           knife('deps --remote /cookbooks/foo /cookbooks/self').should_succeed <<EOM
 /cookbooks/baz
@@ -519,10 +573,12 @@ EOM
         end
       end
       when_the_chef_server 'has roles with circular dependencies' do
-        role 'foo', { 'run_list' => [ 'role[bar]' ] }
-        role 'bar', { 'run_list' => [ 'role[baz]' ] }
-        role 'baz', { 'run_list' => [ 'role[foo]' ] }
-        role 'self', { 'run_list' => [ 'role[self]' ] }
+        before do
+          role 'foo', { 'run_list' => [ 'role[bar]' ] }
+          role 'bar', { 'run_list' => [ 'role[baz]' ] }
+          role 'baz', { 'run_list' => [ 'role[foo]' ] }
+          role 'self', { 'run_list' => [ 'role[self]' ] }
+        end
         it 'knife deps prints each once' do
           knife('deps --remote /roles/foo.json /roles/self.json').should_succeed <<EOM
 /roles/baz.json
@@ -533,8 +589,8 @@ EOM
         end
         it 'knife deps --tree prints each once' do
           knife('deps --remote --tree /roles/foo.json /roles/self.json') do
-            stdout.should == "/roles/foo.json\n  /roles/bar.json\n    /roles/baz.json\n      /roles/foo.json\n/roles/self.json\n  /roles/self.json\n"
-            stderr.should == "WARNING: No knife configuration file found\n"
+            expect(stdout).to eq("/roles/foo.json\n  /roles/bar.json\n    /roles/baz.json\n      /roles/foo.json\n/roles/self.json\n  /roles/self.json\n")
+            expect(stderr).to eq("WARNING: No knife configuration file found\n")
           end
         end
       end
@@ -586,7 +642,9 @@ EOM
         end
       end
       when_the_chef_server 'is missing a dependent cookbook' do
-        role 'starring', { 'run_list' => [ 'recipe[quiche]'] }
+        before do
+          role 'starring', { 'run_list' => [ 'recipe[quiche]'] }
+        end
         it 'knife deps reports the cookbook, along with an error' do
           knife('deps --remote /roles/starring.json').should_fail(
             :exit_code => 2,
@@ -596,7 +654,9 @@ EOM
         end
       end
       when_the_chef_server 'is missing a dependent environment' do
-        node 'mort', { 'chef_environment' => 'desert' }
+        before do
+          node 'mort', { 'chef_environment' => 'desert' }
+        end
         it 'knife deps reports the environment, along with an error' do
           knife('deps --remote /nodes/mort.json').should_fail(
             :exit_code => 2,
@@ -606,7 +666,9 @@ EOM
         end
       end
       when_the_chef_server 'is missing a dependent role' do
-        role 'starring', { 'run_list' => [ 'role[minor]'] }
+        before do
+          role 'starring', { 'run_list' => [ 'role[minor]'] }
+        end
         it 'knife deps reports the role, along with an error' do
           knife('deps --remote /roles/starring.json').should_fail(
             :exit_code => 2,
@@ -626,13 +688,15 @@ EOM
         end
       end
       when_the_chef_server 'has a data bag' do
-        data_bag 'bag', { 'item' => {} }
+        before { data_bag 'bag', { 'item' => {} } }
         it 'knife deps /data_bags/bag shows no dependencies' do
           knife('deps --remote /data_bags/bag').should_succeed("/data_bags/bag\n")
         end
       end
       when_the_chef_server 'has a cookbook' do
-        cookbook 'blah', '1.0.0', { 'metadata.rb' => 'name "blah"' }
+        before do
+          cookbook 'blah', '1.0.0', { 'metadata.rb' => 'name "blah"' }
+        end
         it 'knife deps on a cookbook file shows no dependencies' do
           knife('deps --remote /cookbooks/blah/metadata.rb').should_succeed(
             "/cookbooks/blah/metadata.rb\n"
