@@ -19,28 +19,33 @@ require 'support/shared/integration/integration_helper'
 require 'chef/knife/download'
 require 'chef/knife/diff'
 
-describe 'knife download' do
-  extend IntegrationSupport
+describe 'knife download', :workstation do
+  include IntegrationSupport
   include KnifeSupport
 
   context 'without versioned cookbooks' do
     when_the_chef_server "has one of each thing" do
-      client 'x', {}
-      cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"' }
-      data_bag 'x', { 'y' => {} }
-      environment 'x', {}
-      node 'x', {}
-      role 'x', {}
-      user 'x', {}
+
+      before do
+        client 'x', {}
+        cookbook 'x', '1.0.0'
+        data_bag 'x', { 'y' => {} }
+        environment 'x', {}
+        node 'x', {}
+        role 'x', {}
+        user 'x', {}
+      end
 
       when_the_repository 'has only top-level directories' do
-        directory 'clients'
-        directory 'cookbooks'
-        directory 'data_bags'
-        directory 'environments'
-        directory 'nodes'
-        directory 'roles'
-        directory 'users'
+        before do
+          directory 'clients'
+          directory 'cookbooks'
+          directory 'data_bags'
+          directory 'environments'
+          directory 'nodes'
+          directory 'roles'
+          directory 'users'
+        end
 
         it 'knife download downloads everything' do
           knife('download /').should_succeed <<EOM
@@ -63,17 +68,19 @@ EOM
       end
 
       when_the_repository 'has an identical copy of each thing' do
-        file 'clients/chef-validator.json', { 'validator' => true, 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'clients/chef-webui.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'clients/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'cookbooks/x/metadata.rb', 'version "1.0.0"'
-        file 'data_bags/x/y.json', {}
-        file 'environments/_default.json', { "description" => "The default Chef environment" }
-        file 'environments/x.json', {}
-        file 'nodes/x.json', {}
-        file 'roles/x.json', {}
-        file 'users/admin.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'users/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+        before do
+          file 'clients/chef-validator.json', { 'validator' => true, 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'clients/chef-webui.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'clients/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'cookbooks/x/metadata.rb', cb_metadata("x", "1.0.0")
+          file 'data_bags/x/y.json', {}
+          file 'environments/_default.json', { "description" => "The default Chef environment" }
+          file 'environments/x.json', {}
+          file 'nodes/x.json', {}
+          file 'roles/x.json', {}
+          file 'users/admin.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'users/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+        end
 
         it 'knife download makes no changes' do
           knife('download /').should_succeed ''
@@ -86,7 +93,8 @@ EOM
         end
 
         context 'except the role file' do
-          file 'roles/x.json', <<EOM
+          before do
+            file 'roles/x.json', <<EOM
 {
   "chef_type": "role",
   "default_attributes": {
@@ -103,6 +111,8 @@ EOM
   ]
 }
 EOM
+          end
+
           it 'knife download changes the role' do
             knife('download /').should_succeed "Updated /roles/x.json\n"
             knife('diff --name-status /').should_succeed ''
@@ -115,7 +125,8 @@ EOM
         end
 
         context 'except the role file is textually different, but not ACTUALLY different' do
-          file 'roles/x.json', <<EOM
+          before do
+            file 'roles/x.json', <<EOM
 {
   "chef_type": "role",
   "default_attributes": {
@@ -132,6 +143,8 @@ EOM
   ]
 }
 EOM
+          end
+
           it 'knife download / does not change anything' do
             knife('download /').should_succeed ''
             knife('diff --name-status /').should_succeed ''
@@ -139,15 +152,17 @@ EOM
         end
 
         context 'as well as one extra copy of each thing' do
-          file 'clients/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
-          file 'cookbooks/x/blah.rb', ''
-          file 'cookbooks/y/metadata.rb', 'version "1.0.0"'
-          file 'data_bags/x/z.json', {}
-          file 'data_bags/y/zz.json', {}
-          file 'environments/y.json', {}
-          file 'nodes/y.json', {}
-          file 'roles/y.json', {}
-          file 'users/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+          before do
+            file 'clients/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+            file 'cookbooks/x/blah.rb', ''
+            file 'cookbooks/y/metadata.rb', cb_metadata("x", "1.0.0")
+            file 'data_bags/x/z.json', {}
+            file 'data_bags/y/zz.json', {}
+            file 'environments/y.json', {}
+            file 'nodes/y.json', {}
+            file 'roles/y.json', {}
+            file 'users/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+          end
 
           it 'knife download does nothing' do
             knife('download /').should_succeed ''
@@ -235,7 +250,10 @@ EOM
         end
 
         context 'when current directory is top level' do
-          cwd '.'
+          before do
+            cwd '.'
+          end
+
           it 'knife download with no parameters reports an error' do
             knife('download').should_fail "FATAL: Must specify at least one argument.  If you want to download everything in this directory, type \"knife download .\"\n", :stdout => /USAGE/
           end
@@ -246,7 +264,9 @@ EOM
     # Test download of an item when the other end doesn't even have the container
     when_the_repository 'is empty' do
       when_the_chef_server 'has two data bag items' do
-        data_bag 'x', { 'y' => {}, 'z' => {} }
+        before do
+          data_bag 'x', { 'y' => {}, 'z' => {} }
+        end
 
         it 'knife download of one data bag item itself succeeds' do
           knife('download /data_bags/x/y.json').should_succeed <<EOM
@@ -271,28 +291,32 @@ EOM
     end
 
     when_the_repository 'has three data bag items' do
-      file 'data_bags/x/deleted.json', <<EOM
+      before do
+        file 'data_bags/x/deleted.json', <<EOM
 {
   "id": "deleted"
 }
 EOM
-      file 'data_bags/x/modified.json', <<EOM
+        file 'data_bags/x/modified.json', <<EOM
 {
   "id": "modified"
 }
 EOM
-      file 'data_bags/x/unmodified.json', <<EOM
+        file 'data_bags/x/unmodified.json', <<EOM
 {
   "id": "unmodified"
 }
 EOM
+      end
 
       when_the_chef_server 'has a modified, unmodified, added and deleted data bag item' do
-        data_bag 'x', {
-          'added' => {},
-          'modified' => { 'foo' => 'bar' },
-          'unmodified' => {}
-        }
+        before do
+          data_bag 'x', {
+            'added' => {},
+            'modified' => { 'foo' => 'bar' },
+            'unmodified' => {}
+          }
+        end
 
         it 'knife download of the modified file succeeds' do
           knife('download /data_bags/x/modified.json').should_succeed <<EOM
@@ -355,7 +379,9 @@ EOM
           knife('diff --name-status /data_bags').should_succeed ''
         end
         context 'when cwd is the /data_bags directory' do
-          cwd 'data_bags'
+          before do
+            cwd 'data_bags'
+          end
           it 'knife download fails' do
             knife('download').should_fail "FATAL: Must specify at least one argument.  If you want to download everything in this directory, type \"knife download .\"\n", :stdout => /USAGE/
           end
@@ -380,11 +406,15 @@ EOM
     end
 
     when_the_repository 'has a cookbook' do
-      file 'cookbooks/x/metadata.rb', 'version "1.0.0"'
-      file 'cookbooks/x/z.rb', ''
+      before do
+        file 'cookbooks/x/metadata.rb', cb_metadata("x", "1.0.0")
+        file 'cookbooks/x/z.rb', ''
+      end
 
       when_the_chef_server 'has a modified, added and deleted file for the cookbook' do
-        cookbook 'x', '1.0.0', { 'metadata.rb' => 'version  "1.0.0"', 'y.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.0', { 'metadata.rb' => cb_metadata("x", "1.0.0", "#extra content"), 'y.rb' => 'hi' }
+        end
 
         it 'knife download of a modified file succeeds' do
           knife('download /cookbooks/x/metadata.rb').should_succeed "Updated /cookbooks/x/metadata.rb\n"
@@ -436,12 +466,16 @@ EOM
     end
 
     when_the_repository 'has a cookbook' do
-      file 'cookbooks/x/metadata.rb', 'version "1.0.0"'
-      file 'cookbooks/x/onlyin1.0.0.rb', 'old_text'
+      before do
+        file 'cookbooks/x/metadata.rb', cb_metadata("x", "1.0.0")
+        file 'cookbooks/x/onlyin1.0.0.rb', 'old_text'
+      end
 
       when_the_chef_server 'has a later version for the cookbook' do
-        cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"', 'onlyin1.0.0.rb' => '' }
-        cookbook 'x', '1.0.1', { 'metadata.rb' => 'version "1.0.1"', 'onlyin1.0.1.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.0', { 'onlyin1.0.0.rb' => '' }
+          cookbook 'x', '1.0.1', { 'onlyin1.0.1.rb' => 'hi' }
+        end
 
         it 'knife download /cookbooks/x downloads the latest version' do
           knife('download --purge /cookbooks/x').should_succeed <<EOM
@@ -454,8 +488,11 @@ EOM
       end
 
       when_the_chef_server 'has an earlier version for the cookbook' do
-        cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"', 'onlyin1.0.0.rb' => ''}
-        cookbook 'x', '0.9.9', { 'metadata.rb' => 'version "0.9.9"', 'onlyin0.9.9.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.0', { 'onlyin1.0.0.rb' => ''}
+          cookbook 'x', '0.9.9', { 'onlyin0.9.9.rb' => 'hi' }
+        end
+
         it 'knife download /cookbooks/x downloads the updated file' do
           knife('download --purge /cookbooks/x').should_succeed <<EOM
 Updated /cookbooks/x/onlyin1.0.0.rb
@@ -465,7 +502,9 @@ EOM
       end
 
       when_the_chef_server 'has a later version for the cookbook, and no current version' do
-        cookbook 'x', '1.0.1', { 'metadata.rb' => 'version "1.0.1"', 'onlyin1.0.1.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.1', { 'onlyin1.0.1.rb' => 'hi' }
+        end
 
         it 'knife download /cookbooks/x downloads the latest version' do
           knife('download --purge /cookbooks/x').should_succeed <<EOM
@@ -478,7 +517,9 @@ EOM
       end
 
       when_the_chef_server 'has an earlier version for the cookbook, and no current version' do
-        cookbook 'x', '0.9.9', { 'metadata.rb' => 'version "0.9.9"', 'onlyin0.9.9.rb' => 'hi' }
+        before do
+          cookbook 'x', '0.9.9', { 'onlyin0.9.9.rb' => 'hi' }
+        end
 
         it 'knife download /cookbooks/x downloads the old version' do
           knife('download --purge /cookbooks/x').should_succeed <<EOM
@@ -492,17 +533,29 @@ EOM
     end
 
     when_the_chef_server 'has an environment' do
-      environment 'x', {}
+      before do
+        environment 'x', {}
+      end
       when_the_repository 'has an environment with bad JSON' do
-        file 'environments/x.json', '{'
+        before do
+          file 'environments/x.json', '{'
+        end
         it 'knife download succeeds' do
-          knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n", :stderr => "WARN: Parse error reading #{path_to('environments/x.json')} as JSON: A JSON text must at least contain two octets!\n"
+          warning = <<-EOH
+WARN: Parse error reading #{path_to('environments/x.json')} as JSON: parse error: premature EOF
+                                       {
+                     (right here) ------^
+
+EOH
+          knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n", :stderr => warning
           knife('diff --name-status /environments/x.json').should_succeed ''
         end
       end
 
       when_the_repository 'has the same environment with the wrong name in the file' do
-        file 'environments/x.json', { 'name' => 'y' }
+        before do
+          file 'environments/x.json', { 'name' => 'y' }
+        end
         it 'knife download succeeds' do
           knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n"
           knife('diff --name-status /environments/x.json').should_succeed ''
@@ -510,7 +563,9 @@ EOM
       end
 
       when_the_repository 'has the same environment with no name in the file' do
-        file 'environments/x.json', { 'description' => 'hi' }
+        before do
+          file 'environments/x.json', { 'description' => 'hi' }
+        end
         it 'knife download succeeds' do
           knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n"
           knife('diff --name-status /environments/x.json').should_succeed ''
@@ -521,22 +576,26 @@ EOM
 
   with_versioned_cookbooks do
     when_the_chef_server "has one of each thing" do
-      client 'x', {}
-      cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"' }
-      data_bag 'x', { 'y' => {} }
-      environment 'x', {}
-      node 'x', {}
-      role 'x', {}
-      user 'x', {}
+      before do
+        client 'x', {}
+        cookbook 'x', '1.0.0'
+        data_bag 'x', { 'y' => {} }
+        environment 'x', {}
+        node 'x', {}
+        role 'x', {}
+        user 'x', {}
+      end
 
       when_the_repository 'has only top-level directories' do
-        directory 'clients'
-        directory 'cookbooks'
-        directory 'data_bags'
-        directory 'environments'
-        directory 'nodes'
-        directory 'roles'
-        directory 'users'
+        before do
+          directory 'clients'
+          directory 'cookbooks'
+          directory 'data_bags'
+          directory 'environments'
+          directory 'nodes'
+          directory 'roles'
+          directory 'users'
+        end
 
         it 'knife download downloads everything' do
           knife('download /').should_succeed <<EOM
@@ -559,17 +618,19 @@ EOM
       end
 
       when_the_repository 'has an identical copy of each thing' do
-        file 'clients/chef-validator.json', { 'validator' => true, 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'clients/chef-webui.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'clients/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'cookbooks/x-1.0.0/metadata.rb', 'version "1.0.0"'
-        file 'data_bags/x/y.json', {}
-        file 'environments/_default.json', { "description" => "The default Chef environment" }
-        file 'environments/x.json', {}
-        file 'nodes/x.json', {}
-        file 'roles/x.json', {}
-        file 'users/admin.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
-        file 'users/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+        before do
+          file 'clients/chef-validator.json', { 'validator' => true, 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'clients/chef-webui.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'clients/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'cookbooks/x-1.0.0/metadata.rb', cb_metadata("x", "1.0.0")
+          file 'data_bags/x/y.json', {}
+          file 'environments/_default.json', { "description" => "The default Chef environment" }
+          file 'environments/x.json', {}
+          file 'nodes/x.json', {}
+          file 'roles/x.json', {}
+          file 'users/admin.json', { 'admin' => true, 'public_key' => ChefZero::PUBLIC_KEY }
+          file 'users/x.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+        end
 
         it 'knife download makes no changes' do
           knife('download /').should_succeed ''
@@ -582,7 +643,9 @@ EOM
         end
 
         context 'except the role file' do
-          file 'roles/x.json', { "description" => "blarghle" }
+          before do
+            file 'roles/x.json', { "description" => "blarghle" }
+          end
 
           it 'knife download changes the role' do
             knife('download /').should_succeed "Updated /roles/x.json\n"
@@ -591,7 +654,8 @@ EOM
         end
 
         context 'except the role file is textually different, but not ACTUALLY different' do
-          file 'roles/x.json', <<EOM
+          before do
+            file 'roles/x.json', <<EOM
 {
   "chef_type": "role" ,
   "default_attributes": {
@@ -608,6 +672,8 @@ EOM
   ]
 }
 EOM
+          end
+
           it 'knife download / does not change anything' do
             knife('download /').should_succeed ''
             knife('diff --name-status /').should_succeed ''
@@ -615,16 +681,18 @@ EOM
         end
 
         context 'as well as one extra copy of each thing' do
-          file 'clients/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
-          file 'cookbooks/x-1.0.0/blah.rb', ''
-          file 'cookbooks/x-2.0.0/metadata.rb', 'version "2.0.0"'
-          file 'cookbooks/y-1.0.0/metadata.rb', 'version "1.0.0"'
-          file 'data_bags/x/z.json', {}
-          file 'data_bags/y/zz.json', {}
-          file 'environments/y.json', {}
-          file 'nodes/y.json', {}
-          file 'roles/y.json', {}
-          file 'users/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+          before do
+            file 'clients/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+            file 'cookbooks/x-1.0.0/blah.rb', ''
+            file 'cookbooks/x-2.0.0/metadata.rb', 'version "2.0.0"'
+            file 'cookbooks/y-1.0.0/metadata.rb', 'version "1.0.0"'
+            file 'data_bags/x/z.json', {}
+            file 'data_bags/y/zz.json', {}
+            file 'environments/y.json', {}
+            file 'nodes/y.json', {}
+            file 'roles/y.json', {}
+            file 'users/y.json', { 'public_key' => ChefZero::PUBLIC_KEY }
+          end
 
           it 'knife download does nothing' do
             knife('download /').should_succeed ''
@@ -688,7 +756,9 @@ EOM
         end
 
         context 'when current directory is top level' do
-          cwd '.'
+          before do
+            cwd '.'
+          end
           it 'knife download with no parameters reports an error' do
             knife('download').should_fail "FATAL: Must specify at least one argument.  If you want to download everything in this directory, type \"knife download .\"\n", :stdout => /USAGE/
           end
@@ -699,7 +769,9 @@ EOM
     # Test download of an item when the other end doesn't even have the container
     when_the_repository 'is empty' do
       when_the_chef_server 'has two data bag items' do
-        data_bag 'x', { 'y' => {}, 'z' => {} }
+        before do
+          data_bag 'x', { 'y' => {}, 'z' => {} }
+        end
 
         it 'knife download of one data bag item itself succeeds' do
           knife('download /data_bags/x/y.json').should_succeed <<EOM
@@ -715,28 +787,32 @@ EOM
     end
 
     when_the_repository 'has three data bag items' do
-      file 'data_bags/x/deleted.json', <<EOM
+      before do
+        file 'data_bags/x/deleted.json', <<EOM
 {
   "id": "deleted"
 }
 EOM
-      file 'data_bags/x/modified.json', <<EOM
+        file 'data_bags/x/modified.json', <<EOM
 {
   "id": "modified"
 }
 EOM
-      file 'data_bags/x/unmodified.json', <<EOM
+        file 'data_bags/x/unmodified.json', <<EOM
 {
   "id": "unmodified"
 }
 EOM
+      end
 
       when_the_chef_server 'has a modified, unmodified, added and deleted data bag item' do
-        data_bag 'x', {
-          'added' => {},
-          'modified' => { 'foo' => 'bar' },
-          'unmodified' => {}
-        }
+        before do
+          data_bag 'x', {
+            'added' => {},
+            'modified' => { 'foo' => 'bar' },
+            'unmodified' => {}
+          }
+        end
 
         it 'knife download of the modified file succeeds' do
           knife('download /data_bags/x/modified.json').should_succeed <<EOM
@@ -799,7 +875,9 @@ EOM
           knife('diff --name-status /data_bags').should_succeed ''
         end
         context 'when cwd is the /data_bags directory' do
-          cwd 'data_bags'
+          before do
+            cwd 'data_bags'
+          end
           it 'knife download fails' do
             knife('download').should_fail "FATAL: Must specify at least one argument.  If you want to download everything in this directory, type \"knife download .\"\n", :stdout => /USAGE/
           end
@@ -824,11 +902,15 @@ EOM
     end
 
     when_the_repository 'has a cookbook' do
-      file 'cookbooks/x-1.0.0/metadata.rb', 'version "1.0.0"'
-      file 'cookbooks/x-1.0.0/z.rb', ''
+      before do
+        file 'cookbooks/x-1.0.0/metadata.rb', 'name "x"; version "1.0.0"#unmodified'
+        file 'cookbooks/x-1.0.0/z.rb', ''
+      end
 
       when_the_chef_server 'has a modified, added and deleted file for the cookbook' do
-        cookbook 'x', '1.0.0', { 'metadata.rb' => 'version  "1.0.0"', 'y.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.0', { 'y.rb' => 'hi' }
+        end
 
         it 'knife download of a modified file succeeds' do
           knife('download /cookbooks/x-1.0.0/metadata.rb').should_succeed "Updated /cookbooks/x-1.0.0/metadata.rb\n"
@@ -880,12 +962,16 @@ EOM
     end
 
     when_the_repository 'has a cookbook' do
-      file 'cookbooks/x-1.0.0/metadata.rb', 'version "1.0.0"'
-      file 'cookbooks/x-1.0.0/onlyin1.0.0.rb', 'old_text'
+      before do
+        file 'cookbooks/x-1.0.0/metadata.rb', cb_metadata("x", "1.0.0")
+        file 'cookbooks/x-1.0.0/onlyin1.0.0.rb', 'old_text'
+      end
 
       when_the_chef_server 'has a later version for the cookbook' do
-        cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"', 'onlyin1.0.0.rb' => '' }
-        cookbook 'x', '1.0.1', { 'metadata.rb' => 'version "1.0.1"', 'onlyin1.0.1.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.0', { 'onlyin1.0.0.rb' => '' }
+          cookbook 'x', '1.0.1', { 'onlyin1.0.1.rb' => 'hi' }
+        end
 
         it 'knife download /cookbooks/x downloads the latest version' do
           knife('download --purge /cookbooks').should_succeed <<EOM
@@ -899,8 +985,11 @@ EOM
       end
 
       when_the_chef_server 'has an earlier version for the cookbook' do
-        cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"', 'onlyin1.0.0.rb' => ''}
-        cookbook 'x', '0.9.9', { 'metadata.rb' => 'version "0.9.9"', 'onlyin0.9.9.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.0', { 'onlyin1.0.0.rb' => ''}
+          cookbook 'x', '0.9.9', { 'onlyin0.9.9.rb' => 'hi' }
+        end
+
         it 'knife download /cookbooks downloads the updated file' do
           knife('download --purge /cookbooks').should_succeed <<EOM
 Created /cookbooks/x-0.9.9
@@ -913,7 +1002,9 @@ EOM
       end
 
       when_the_chef_server 'has a later version for the cookbook, and no current version' do
-        cookbook 'x', '1.0.1', { 'metadata.rb' => 'version "1.0.1"', 'onlyin1.0.1.rb' => 'hi' }
+        before do
+          cookbook 'x', '1.0.1', { 'onlyin1.0.1.rb' => 'hi' }
+        end
 
         it 'knife download /cookbooks/x downloads the latest version' do
           knife('download --purge /cookbooks').should_succeed <<EOM
@@ -927,7 +1018,9 @@ EOM
       end
 
       when_the_chef_server 'has an earlier version for the cookbook, and no current version' do
-        cookbook 'x', '0.9.9', { 'metadata.rb' => 'version "0.9.9"', 'onlyin0.9.9.rb' => 'hi' }
+        before do
+          cookbook 'x', '0.9.9', { 'onlyin0.9.9.rb' => 'hi' }
+        end
 
         it 'knife download --purge /cookbooks downloads the old version and deletes the new version' do
           knife('download --purge /cookbooks').should_succeed <<EOM
@@ -942,17 +1035,15 @@ EOM
     end
 
     when_the_chef_server 'has an environment' do
-      environment 'x', {}
-      when_the_repository 'has an environment with bad JSON' do
-        file 'environments/x.json', '{'
-        it 'knife download succeeds' do
-          knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n", :stderr => "WARN: Parse error reading #{path_to('environments/x.json')} as JSON: A JSON text must at least contain two octets!\n"
-          knife('diff --name-status /environments/x.json').should_succeed ''
-        end
+      before do
+        environment 'x', {}
       end
 
       when_the_repository 'has the same environment with the wrong name in the file' do
-        file 'environments/x.json', { 'name' => 'y' }
+        before do
+          file 'environments/x.json', { 'name' => 'y' }
+        end
+
         it 'knife download succeeds' do
           knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n"
           knife('diff --name-status /environments/x.json').should_succeed ''
@@ -960,7 +1051,10 @@ EOM
       end
 
       when_the_repository 'has the same environment with no name in the file' do
-        file 'environments/x.json', { 'description' => 'hi' }
+        before do
+          file 'environments/x.json', { 'description' => 'hi' }
+        end
+
         it 'knife download succeeds' do
           knife('download /environments/x.json').should_succeed "Updated /environments/x.json\n"
           knife('diff --name-status /environments/x.json').should_succeed ''
@@ -970,22 +1064,24 @@ EOM
   end # with versioned cookbooks
 
   when_the_chef_server 'has a cookbook' do
-    cookbook 'x', '1.0.0', { 'metadata.rb' => 'version "1.0.0"' }
+    before do
+      cookbook 'x', '1.0.0'
+    end
 
     when_the_repository 'is empty' do
-      it 'knife download /cookbooks/x signs all requests', :ruby_gte_19_only do
+      it 'knife download /cookbooks/x signs all requests' do
 
         # Check that BasicClient.request() always gets called with X-OPS-USERID
         original_new = Chef::HTTP::BasicClient.method(:new)
-        Chef::HTTP::BasicClient.should_receive(:new) do |args|
+        expect(Chef::HTTP::BasicClient).to receive(:new) { |args|
           new_result = original_new.call(*args)
           original_request = new_result.method(:request)
-          new_result.should_receive(:request) do |method, url, body, headers, &response_handler|
-            headers['X-OPS-USERID'].should_not be_nil
+          expect(new_result).to receive(:request) { |method, url, body, headers, &response_handler|
+            expect(headers['X-OPS-USERID']).not_to be_nil
             original_request.call(method, url, body, headers, &response_handler)
-          end.at_least(:once)
+          }.at_least(:once)
           new_result
-        end.at_least(:once)
+        }.at_least(:once)
 
         knife('download /cookbooks/x').should_succeed <<EOM
 Created /cookbooks
@@ -995,4 +1091,80 @@ EOM
       end
     end
   end
+
+  when_the_chef_server "is in Enterprise mode", :osc_compat => false, :single_org => false do
+    before do
+      organization 'foo' do
+        container 'x', {}
+        group 'x', {}
+      end
+    end
+
+    before :each do
+      Chef::Config.chef_server_url = URI.join(Chef::Config.chef_server_url, '/organizations/foo')
+    end
+
+    when_the_repository 'is empty' do
+      it 'knife download / downloads everything' do
+        knife('download /').should_succeed <<EOM
+Created /acls
+Created /acls/clients
+Created /acls/clients/foo-validator.json
+Created /acls/containers
+Created /acls/containers/clients.json
+Created /acls/containers/containers.json
+Created /acls/containers/cookbooks.json
+Created /acls/containers/data.json
+Created /acls/containers/environments.json
+Created /acls/containers/groups.json
+Created /acls/containers/nodes.json
+Created /acls/containers/roles.json
+Created /acls/containers/sandboxes.json
+Created /acls/containers/x.json
+Created /acls/cookbooks
+Created /acls/data_bags
+Created /acls/environments
+Created /acls/environments/_default.json
+Created /acls/groups
+Created /acls/groups/admins.json
+Created /acls/groups/billing-admins.json
+Created /acls/groups/clients.json
+Created /acls/groups/users.json
+Created /acls/groups/x.json
+Created /acls/nodes
+Created /acls/roles
+Created /acls/organization.json
+Created /clients
+Created /clients/foo-validator.json
+Created /containers
+Created /containers/clients.json
+Created /containers/containers.json
+Created /containers/cookbooks.json
+Created /containers/data.json
+Created /containers/environments.json
+Created /containers/groups.json
+Created /containers/nodes.json
+Created /containers/roles.json
+Created /containers/sandboxes.json
+Created /containers/x.json
+Created /cookbooks
+Created /data_bags
+Created /environments
+Created /environments/_default.json
+Created /groups
+Created /groups/admins.json
+Created /groups/billing-admins.json
+Created /groups/clients.json
+Created /groups/users.json
+Created /groups/x.json
+Created /invitations.json
+Created /members.json
+Created /nodes
+Created /org.json
+Created /roles
+EOM
+        knife('diff --name-status /').should_succeed ''
+      end
+    end
+  end
 end
