@@ -16,20 +16,23 @@
 # limitations under the License.
 
 require 'support/shared/integration/integration_helper'
+require 'support/shared/context/config'
 require 'chef/knife/list'
 
-describe 'redirection' do
-  extend IntegrationSupport
+describe 'redirection', :workstation do
+  include IntegrationSupport
   include KnifeSupport
   include AppServerSupport
 
+  include_context "default config options"
+
   when_the_chef_server 'has a role' do
-    role 'x', {}
+    before { role 'x', {} }
 
     context 'and another server redirects to it with 302' do
       before :each do
         real_chef_server_url = Chef::Config.chef_server_url
-        Chef::Config.chef_server_url = "http://127.0.0.1:9018"
+        Chef::Config.chef_server_url = "http://localhost:9018"
         app = lambda do |env|
           [302, {'Content-Type' => 'text','Location' => "#{real_chef_server_url}#{env['PATH_INFO']}" }, ['302 found'] ]
         end
