@@ -24,20 +24,14 @@ describe 'Chef::ReservedNames::Win32::File', :windows_only do
     @path = File.expand_path(File.join(File.dirname(__FILE__), "..", "..", "data", "old_home_dir", "my-dot-emacs"))
   end
 
-  it "should not leak memory" do
-    pending "Fix required for CHEF-5004"
+  it "should not leak significant memory", :volatile do
     test = lambda { Chef::ReservedNames::Win32::File.symlink?(@path) }
-    test.should_not leak_memory(:warmup => 50, :iterations => 100)
+    expect(test).not_to leak_memory(:warmup => 50000, :iterations => 50000)
   end
 
-  it "should not leak significant memory" do
+  it "should not leak handles", :volatile do
     test = lambda { Chef::ReservedNames::Win32::File.symlink?(@path) }
-    test.should_not leak_memory(:warmup => 50000, :iterations => 100)
-  end
-
-  it "should not leak handles" do
-    test = lambda { Chef::ReservedNames::Win32::File.symlink?(@path) }
-    test.should_not leak_handles(:warmup => 50, :iterations => 100)
+    expect(test).not_to leak_handles(:warmup => 50, :iterations => 100)
   end
 
 end
