@@ -6,8 +6,15 @@
 # testing code that mixes in platform specific modules like +Chef::Mixin::Securable+
 # or +Chef::FileAccessControl+
 def platform_mock(platform = :unix, &block)
-  Chef::Platform.stub(:windows?).and_return(platform == :windows ? true : false)
+  allow(Chef::Platform).to receive(:windows?).and_return(platform == :windows ? true : false)
   ENV['SYSTEMDRIVE'] = (platform == :windows ? 'C:' : nil)
+
+  if platform == :windows
+    Chef::Config.set_defaults_for_windows
+  else
+    Chef::Config.set_defaults_for_nix
+  end
+
   if block_given?
     mock_constants({"RUBY_PLATFORM" => (platform == :windows ? 'i386-mingw32' : 'x86_64-darwin11.2.0'),
                     "File::PATH_SEPARATOR" => (platform == :windows ? ";" : ":"),
