@@ -48,10 +48,10 @@ end
 shared_examples_for "a file with the wrong content" do
   before do
     # Assert starting state is as expected
-    File.should exist(path)
+    expect(File).to exist(path)
     # Kinda weird, in this case @expected_checksum is the cksum of the file
     # with incorrect content.
-    sha256_checksum(path).should == @expected_checksum
+    expect(sha256_checksum(path)).to eq(@expected_checksum)
   end
 
   describe "when diff is disabled" do
@@ -65,20 +65,20 @@ shared_examples_for "a file with the wrong content" do
         end
 
         it "overwrites the file with the updated content when the :create action is run" do
-          File.stat(path).mtime.should > @expected_mtime
-          sha256_checksum(path).should_not == @expected_checksum
+          expect(File.stat(path).mtime).to be > @expected_mtime
+          expect(sha256_checksum(path)).not_to eq(@expected_checksum)
         end
 
         it "backs up the existing file" do
-          Dir.glob(backup_glob).size.should equal(1)
+          expect(Dir.glob(backup_glob).size).to equal(1)
         end
 
         it "is marked as updated by last action" do
-          resource.should be_updated_by_last_action
+          expect(resource).to be_updated_by_last_action
         end
 
         it "should restore the security contexts on selinux", :selinux_only do
-          selinux_security_context_restored?(path).should be_true
+          expect(selinux_security_context_restored?(path)).to be_truthy
         end
       end
 
@@ -89,11 +89,21 @@ shared_examples_for "a file with the wrong content" do
         end
 
         it "should not attempt to backup the existing file if :backup == 0" do
-          Dir.glob(backup_glob).size.should equal(0)
+          expect(Dir.glob(backup_glob).size).to equal(0)
         end
 
         it "should restore the security contexts on selinux", :selinux_only do
-          selinux_security_context_restored?(path).should be_true
+          expect(selinux_security_context_restored?(path)).to be_truthy
+        end
+      end
+
+      context "with a checksum that does not match the content to deploy" do
+        before do
+          resource.checksum("aAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaAaA")
+        end
+
+        it "raises an exception" do
+          expect{ resource.run_action(:create) }.to raise_error(Chef::Exceptions::ChecksumMismatch)
         end
       end
     end
@@ -104,16 +114,16 @@ shared_examples_for "a file with the wrong content" do
       end
 
       it "doesn't overwrite the file when the :create_if_missing action is run" do
-        File.stat(path).mtime.should == @expected_mtime
-        sha256_checksum(path).should == @expected_checksum
+        expect(File.stat(path).mtime).to eq(@expected_mtime)
+        expect(sha256_checksum(path)).to eq(@expected_checksum)
       end
 
       it "is not marked as updated" do
-        resource.should_not be_updated_by_last_action
+        expect(resource).not_to be_updated_by_last_action
       end
 
       it "should restore the security contexts on selinux", :selinux_only do
-        selinux_security_context_restored?(path).should be_true
+        expect(selinux_security_context_restored?(path)).to be_truthy
       end
     end
 
@@ -123,11 +133,11 @@ shared_examples_for "a file with the wrong content" do
       end
 
       it "deletes the file" do
-        File.should_not exist(path)
+        expect(File).not_to exist(path)
       end
 
       it "is marked as updated by last action" do
-        resource.should be_updated_by_last_action
+        expect(resource).to be_updated_by_last_action
       end
     end
 
@@ -136,14 +146,14 @@ shared_examples_for "a file with the wrong content" do
   context "when diff is enabled" do
     describe 'sensitive attribute' do
       context "should be insensitive by default" do
-        it { expect(resource.sensitive).to(be_false) }
+        it { expect(resource.sensitive).to(be_falsey) }
       end
 
       context "when set" do
         before { resource.sensitive(true) }
 
         it "should be set on the resource" do
-          expect(resource.sensitive).to(be_true)
+          expect(resource.sensitive).to(be_truthy)
         end
 
         context "when running :create action" do
@@ -171,8 +181,8 @@ end
 shared_examples_for "a file with the correct content" do
   before do
     # Assert starting state is as expected
-    File.should exist(path)
-    sha256_checksum(path).should == @expected_checksum
+    expect(File).to exist(path)
+    expect(sha256_checksum(path)).to eq(@expected_checksum)
   end
 
   include_context "diff disabled"
@@ -182,19 +192,19 @@ shared_examples_for "a file with the correct content" do
       resource.run_action(:create)
     end
     it "does not overwrite the original when the :create action is run" do
-      sha256_checksum(path).should == @expected_checksum
+      expect(sha256_checksum(path)).to eq(@expected_checksum)
     end
 
     it "does not update the mtime of the file when the :create action is run" do
-      File.stat(path).mtime.should == @expected_mtime
+      expect(File.stat(path).mtime).to eq(@expected_mtime)
     end
 
     it "is not marked as updated by last action" do
-      resource.should_not be_updated_by_last_action
+      expect(resource).not_to be_updated_by_last_action
     end
 
     it "should restore the security contexts on selinux", :selinux_only do
-      selinux_security_context_restored?(path).should be_true
+      expect(selinux_security_context_restored?(path)).to be_truthy
     end
   end
 
@@ -204,15 +214,15 @@ shared_examples_for "a file with the correct content" do
     end
 
     it "doesn't overwrite the file when the :create_if_missing action is run" do
-      sha256_checksum(path).should == @expected_checksum
+      expect(sha256_checksum(path)).to eq(@expected_checksum)
     end
 
     it "is not marked as updated by last action" do
-      resource.should_not be_updated_by_last_action
+      expect(resource).not_to be_updated_by_last_action
     end
 
     it "should restore the security contexts on selinux", :selinux_only do
-      selinux_security_context_restored?(path).should be_true
+      expect(selinux_security_context_restored?(path)).to be_truthy
     end
   end
 
@@ -222,11 +232,11 @@ shared_examples_for "a file with the correct content" do
     end
 
     it "deletes the file when the :delete action is run" do
-      File.should_not exist(path)
+      expect(File).not_to exist(path)
     end
 
     it "is marked as updated by last action" do
-      resource.should be_updated_by_last_action
+      expect(resource).to be_updated_by_last_action
     end
   end
 end
@@ -274,6 +284,7 @@ shared_examples_for "a file resource" do
 
     before do
       Chef::Config[:why_run] = true
+      Chef::Config[:ssl_verify_mode] = :verify_none
     end
 
     after do
@@ -289,7 +300,7 @@ shared_examples_for "a file resource" do
 
       it "successfully doesn't create the file" do
         resource.run_action(:create) # should not raise
-        File.should_not exist(path)
+        expect(File).not_to exist(path)
       end
     end
 
@@ -297,14 +308,14 @@ shared_examples_for "a file resource" do
 
   describe "when setting atomic_update" do
     it "booleans should work" do
-      lambda {resource.atomic_update(true)}.should_not raise_error
-      lambda {resource.atomic_update(false)}.should_not raise_error
+      expect {resource.atomic_update(true)}.not_to raise_error
+      expect {resource.atomic_update(false)}.not_to raise_error
     end
 
     it "anything else should raise an error" do
-      lambda {resource.atomic_update(:copy)}.should raise_error(ArgumentError)
-      lambda {resource.atomic_update(:move)}.should raise_error(ArgumentError)
-      lambda {resource.atomic_update(958)}.should raise_error(ArgumentError)
+      expect {resource.atomic_update(:copy)}.to raise_error(ArgumentError)
+      expect {resource.atomic_update(:move)}.to raise_error(ArgumentError)
+      expect {resource.atomic_update(958)}.to raise_error(ArgumentError)
     end
   end
 
@@ -323,26 +334,30 @@ shared_examples_for "file resource not pointing to a real file" do
     !symlink?(file_path) && File.file?(file_path)
   end
 
+  before do
+    Chef::Config[:ssl_verify_mode] = :verify_none
+  end
+
   describe "when force_unlink is set to true" do
     it ":create unlinks the target" do
-      real_file?(path).should be_false
+      expect(real_file?(path)).to be_falsey
       resource.force_unlink(true)
       resource.run_action(:create)
-      real_file?(path).should be_true
-      binread(path).should == expected_content
-      resource.should be_updated_by_last_action
+      expect(real_file?(path)).to be_truthy
+      expect(binread(path)).to eq(expected_content)
+      expect(resource).to be_updated_by_last_action
     end
   end
 
   describe "when force_unlink is set to false" do
     it ":create raises an error" do
-      lambda {resource.run_action(:create) }.should raise_error(Chef::Exceptions::FileTypeMismatch)
+      expect {resource.run_action(:create) }.to raise_error(Chef::Exceptions::FileTypeMismatch)
     end
   end
 
   describe "when force_unlink is not set (default)" do
     it ":create raises an error" do
-      lambda {resource.run_action(:create) }.should raise_error(Chef::Exceptions::FileTypeMismatch)
+      expect {resource.run_action(:create) }.to raise_error(Chef::Exceptions::FileTypeMismatch)
     end
   end
 end
@@ -353,6 +368,7 @@ shared_examples_for "a configured file resource" do
 
   before do
     Chef::Log.level = :info
+    Chef::Config[:ssl_verify_mode] = :verify_none
   end
 
    # note the stripping of the drive letter from the tmpdir on windows
@@ -425,7 +441,7 @@ shared_examples_for "a configured file resource" do
 
         after(:each) do
           # symlink should never be followed
-          binread(symlink_target).should == "This is so wrong!!!"
+          expect(binread(symlink_target)).to eq("This is so wrong!!!")
         end
 
         it_behaves_like "file resource not pointing to a real file"
@@ -461,7 +477,7 @@ shared_examples_for "a configured file resource" do
         end
 
         it "raises an InvalidSymlink error" do
-          lambda { resource.run_action(:create) }.should raise_error(Chef::Exceptions::InvalidSymlink)
+          expect { resource.run_action(:create) }.to raise_error(Chef::Exceptions::InvalidSymlink)
         end
 
         it "issues a warning/assumption in whyrun mode" do
@@ -489,7 +505,7 @@ shared_examples_for "a configured file resource" do
           FileUtils.rm_rf(link_path)
         end
         it "raises an InvalidSymlink error" do
-          lambda { resource.run_action(:create) }.should raise_error(Chef::Exceptions::InvalidSymlink)
+          expect { resource.run_action(:create) }.to raise_error(Chef::Exceptions::InvalidSymlink)
         end
 
         it "issues a warning/assumption in whyrun mode" do
@@ -520,7 +536,7 @@ shared_examples_for "a configured file resource" do
         end
 
         it "raises an InvalidSymlink error" do
-          lambda { resource.run_action(:create) }.should raise_error(Chef::Exceptions::FileTypeMismatch)
+          expect { resource.run_action(:create) }.to raise_error(Chef::Exceptions::FileTypeMismatch)
         end
 
         it "issues a warning/assumption in whyrun mode" do
@@ -548,7 +564,7 @@ shared_examples_for "a configured file resource" do
         after(:each) do
           # shared examples should not change our test setup of a file resource
           # pointing at a symlink:
-          resource.path.should == link_path
+          expect(resource.path).to eq(link_path)
           FileUtils.rm_rf(link_path)
         end
 
@@ -565,7 +581,7 @@ shared_examples_for "a configured file resource" do
 
           it "does not replace the symlink with a real file" do
             resource.run_action(:create)
-            File.should be_symlink(link_path)
+            expect(File).to be_symlink(link_path)
           end
 
         end
@@ -577,17 +593,17 @@ shared_examples_for "a configured file resource" do
           end
 
           it "updates the source file content" do
-            pending
+            skip
           end
 
           it "marks the resource as updated" do
             resource.run_action(:create)
-            resource.should be_updated_by_last_action
+            expect(resource).to be_updated_by_last_action
           end
 
           it "does not replace the symlink with a real file" do
             resource.run_action(:create)
-            File.should be_symlink(link_path)
+            expect(File).to be_symlink(link_path)
           end
         end
 
@@ -630,21 +646,73 @@ shared_examples_for "a configured file resource" do
         after(:each) do
           # shared examples should not change our test setup of a file resource
           # pointing at a symlink:
-          resource.path.should == link_to_link_path
+          expect(resource.path).to eq(link_to_link_path)
           FileUtils.rm_rf(link_to_file_path)
           FileUtils.rm_rf(link_to_link_path)
         end
 
         it "does not replace the symlink with a real file" do
           resource.run_action(:create)
-          File.should be_symlink(link_to_link_path)
-          File.should be_symlink(link_to_file_path)
+          expect(File).to be_symlink(link_to_link_path)
+          expect(File).to be_symlink(link_to_file_path)
         end
 
       end
     end
   end
 
+  context "when the target file does not exist" do
+    before(:each) do
+      FileUtils.rm_rf(path)
+    end
+
+    after(:each) do
+      FileUtils.rm_rf(path)
+    end
+
+    def symlink?(file_path)
+      if windows?
+        Chef::ReservedNames::Win32::File.symlink?(file_path)
+      else
+        File.symlink?(file_path)
+      end
+    end
+
+    def real_file?(file_path)
+      !symlink?(file_path) && File.file?(file_path)
+    end
+
+    describe "when force_unlink is set to true" do
+      it ":create updates the target" do
+        resource.force_unlink(true)
+        resource.run_action(:create)
+        expect(real_file?(path)).to be_truthy
+        expect(binread(path)).to eq(expected_content)
+        expect(resource).to be_updated_by_last_action
+      end
+    end
+
+    describe "when force_unlink is set to false" do
+      it ":create updates the target" do
+        resource.force_unlink(true)
+        resource.run_action(:create)
+        expect(real_file?(path)).to be_truthy
+        expect(binread(path)).to eq(expected_content)
+        expect(resource).to be_updated_by_last_action
+      end
+    end
+
+    describe "when force_unlink is not set (default)" do
+      it ":create updates the target" do
+        resource.force_unlink(true)
+        resource.run_action(:create)
+        expect(real_file?(path)).to be_truthy
+        expect(binread(path)).to eq(expected_content)
+        expect(resource).to be_updated_by_last_action
+      end
+    end
+  end
+
   context "when the target file is a directory" do
     before(:each) do
       FileUtils.mkdir_p(path)
@@ -732,7 +800,7 @@ shared_examples_for "a configured file resource" do
     end
 
     before(:each) do
-      path.bytesize.should <= 104
+      expect(path.bytesize).to be <= 104
       UNIXServer.new(path)
     end
 
@@ -745,7 +813,7 @@ shared_examples_for "a configured file resource" do
 
   # Regression test for http://tickets.opscode.com/browse/CHEF-4082
   context "when notification is configured" do
-    describe "when path is specified with normal seperator" do
+    describe "when path is specified with normal separator" do
       before do
         @notified_resource = Chef::Resource.new("punk", resource.run_context)
         resource.notifies(:run, @notified_resource, :immediately)
@@ -753,12 +821,12 @@ shared_examples_for "a configured file resource" do
       end
 
       it "should notify the other resources correctly" do
-        resource.should be_updated_by_last_action
-        resource.run_context.immediate_notifications(resource).length.should == 1
+        expect(resource).to be_updated_by_last_action
+        expect(resource.run_context.immediate_notifications(resource).length).to eq(1)
       end
     end
 
-    describe "when path is specified with windows seperator", :windows_only do
+    describe "when path is specified with windows separator", :windows_only do
       let(:path) {
         File.join(test_file_dir, make_tmpname(file_base)).gsub(::File::SEPARATOR, ::File::ALT_SEPARATOR)
       }
@@ -770,8 +838,8 @@ shared_examples_for "a configured file resource" do
       end
 
       it "should notify the other resources correctly" do
-        resource.should be_updated_by_last_action
-        resource.run_context.immediate_notifications(resource).length.should == 1
+        expect(resource).to be_updated_by_last_action
+        expect(resource.run_context.immediate_notifications(resource).length).to eq(1)
       end
     end
   end
@@ -779,7 +847,7 @@ shared_examples_for "a configured file resource" do
   context "when the target file does not exist" do
     before do
       # Assert starting state is expected
-      File.should_not exist(path)
+      expect(File).not_to exist(path)
     end
 
     describe "when running action :create" do
@@ -788,19 +856,19 @@ shared_examples_for "a configured file resource" do
       end
 
       it "creates the file when the :create action is run" do
-        File.should exist(path)
+        expect(File).to exist(path)
       end
 
       it "creates the file with the correct content when the :create action is run" do
-        binread(path).should == expected_content
+        expect(binread(path)).to eq(expected_content)
       end
 
       it "is marked as updated by last action" do
-        resource.should be_updated_by_last_action
+        expect(resource).to be_updated_by_last_action
       end
 
       it "should restore the security contexts on selinux", :selinux_only do
-        selinux_security_context_restored?(path).should be_true
+        expect(selinux_security_context_restored?(path)).to be_truthy
       end
     end
 
@@ -810,15 +878,15 @@ shared_examples_for "a configured file resource" do
       end
 
       it "creates the file with the correct content" do
-        binread(path).should == expected_content
+        expect(binread(path)).to eq(expected_content)
       end
 
       it "is marked as updated by last action" do
-        resource.should be_updated_by_last_action
+        expect(resource).to be_updated_by_last_action
       end
 
       it "should restore the security contexts on selinux", :selinux_only do
-        selinux_security_context_restored?(path).should be_true
+        expect(selinux_security_context_restored?(path)).to be_truthy
       end
     end
 
@@ -828,11 +896,11 @@ shared_examples_for "a configured file resource" do
       end
 
       it "deletes the file when the :delete action is run" do
-        File.should_not exist(path)
+        expect(File).not_to exist(path)
       end
 
       it "is not marked updated by last action" do
-        resource.should_not be_updated_by_last_action
+        expect(resource).not_to be_updated_by_last_action
       end
     end
   end
@@ -933,21 +1001,21 @@ shared_examples_for "a configured file resource" do
     describe ":create action should run without any updates" do
       before do
         # Assert starting state is as expected
-        File.should exist(path)
-        sha256_checksum(path).should == @expected_checksum
+        expect(File).to exist(path)
+        expect(sha256_checksum(path)).to eq(@expected_checksum)
         resource.run_action(:create)
       end
 
       it "does not overwrite the original when the :create action is run" do
-        sha256_checksum(path).should == @expected_checksum
+        expect(sha256_checksum(path)).to eq(@expected_checksum)
       end
 
       it "does not update the mtime of the file when the :create action is run" do
-        File.stat(path).mtime.should == @expected_mtime
+        expect(File.stat(path).mtime).to eq(@expected_mtime)
       end
 
       it "is not marked as updated by last action" do
-        resource.should_not be_updated_by_last_action
+        expect(resource).not_to be_updated_by_last_action
       end
     end
   end
