@@ -23,12 +23,12 @@ describe Chef::Daemon do
     if windows?
       mock_struct = #Struct::Passwd.new(nil, nil, 111, 111)
       mock_struct = OpenStruct.new(:uid => 2342, :gid => 2342)
-      Etc.stub(:getpwnam).and_return mock_struct
-      Etc.stub(:getgrnam).and_return mock_struct
+      allow(Etc).to receive(:getpwnam).and_return mock_struct
+      allow(Etc).to receive(:getgrnam).and_return mock_struct
       # mock unimplemented methods
-      Process.stub(:initgroups).and_return nil
-      Process::GID.stub(:change_privilege).and_return 11
-      Process::UID.stub(:change_privilege).and_return 11
+      allow(Process).to receive(:initgroups).and_return nil
+      allow(Process::GID).to receive(:change_privilege).and_return 11
+      allow(Process::UID).to receive(:change_privilege).and_return 11
     end
   end
 
@@ -41,7 +41,7 @@ describe Chef::Daemon do
       end
 
       it "should return the supplied value" do
-        Chef::Daemon.pid_file.should eql("/var/run/chef/chef-client.pid")
+        expect(Chef::Daemon.pid_file).to eql("/var/run/chef/chef-client.pid")
       end
     end
 
@@ -52,7 +52,7 @@ describe Chef::Daemon do
       end
 
       it "should return a valued based on @name" do
-        Chef::Daemon.pid_file.should eql("/tmp/chef-client.pid")
+        expect(Chef::Daemon.pid_file).to eql("/tmp/chef-client.pid")
       end
 
     end
@@ -65,7 +65,7 @@ describe Chef::Daemon do
     end
 
     it "should suck the pid out of pid_file" do
-      File.should_receive(:read).with("/var/run/chef/chef-client.pid").and_return("1337")
+      expect(File).to receive(:read).with("/var/run/chef/chef-client.pid").and_return("1337")
       Chef::Daemon.pid_from_file
     end
   end
@@ -73,13 +73,13 @@ describe Chef::Daemon do
   describe ".change_privilege" do
 
     before do
-      Chef::Application.stub(:fatal!).and_return(true)
+      allow(Chef::Application).to receive(:fatal!).and_return(true)
       Chef::Config[:user] = 'aj'
-      Dir.stub(:chdir)
+      allow(Dir).to receive(:chdir)
     end
 
     it "changes the working directory to root" do
-      Dir.should_receive(:chdir).with("/").and_return(0)
+      expect(Dir).to receive(:chdir).with("/").and_return(0)
       Chef::Daemon.change_privilege
     end
 
@@ -90,24 +90,24 @@ describe Chef::Daemon do
       end
 
       it "should log an appropriate info message" do
-        Chef::Log.should_receive(:info).with("About to change privilege to aj:staff")
+        expect(Chef::Log).to receive(:info).with("About to change privilege to aj:staff")
         Chef::Daemon.change_privilege
       end
 
       it "should call _change_privilege with the user and group" do
-        Chef::Daemon.should_receive(:_change_privilege).with("aj", "staff")
+        expect(Chef::Daemon).to receive(:_change_privilege).with("aj", "staff")
         Chef::Daemon.change_privilege
       end
     end
 
     describe "when just the user option is supplied" do
       it "should log an appropriate info message" do
-        Chef::Log.should_receive(:info).with("About to change privilege to aj")
+        expect(Chef::Log).to receive(:info).with("About to change privilege to aj")
         Chef::Daemon.change_privilege
       end
 
       it "should call _change_privilege with just the user" do
-        Chef::Daemon.should_receive(:_change_privilege).with("aj")
+        expect(Chef::Daemon).to receive(:_change_privilege).with("aj")
         Chef::Daemon.change_privilege
       end
     end
@@ -116,56 +116,56 @@ describe Chef::Daemon do
   describe "._change_privilege" do
 
     before do
-      Process.stub(:euid).and_return(0)
-      Process.stub(:egid).and_return(0)
+      allow(Process).to receive(:euid).and_return(0)
+      allow(Process).to receive(:egid).and_return(0)
 
-      Process::UID.stub(:change_privilege).and_return(nil)
-      Process::GID.stub(:change_privilege).and_return(nil)
+      allow(Process::UID).to receive(:change_privilege).and_return(nil)
+      allow(Process::GID).to receive(:change_privilege).and_return(nil)
 
       @pw_user = double("Struct::Passwd", :uid => 501)
       @pw_group = double("Struct::Group", :gid => 20)
 
-      Process.stub(:initgroups).and_return(true)
+      allow(Process).to receive(:initgroups).and_return(true)
 
-      Etc.stub(:getpwnam).and_return(@pw_user)
-      Etc.stub(:getgrnam).and_return(@pw_group)
+      allow(Etc).to receive(:getpwnam).and_return(@pw_user)
+      allow(Etc).to receive(:getgrnam).and_return(@pw_group)
     end
 
     describe "with sufficient privileges" do
       before do
-        Process.stub(:euid).and_return(0)
-        Process.stub(:egid).and_return(0)
+        allow(Process).to receive(:euid).and_return(0)
+        allow(Process).to receive(:egid).and_return(0)
       end
 
       it "should initialize the supplemental group list" do
-        Process.should_receive(:initgroups).with("aj", 20)
+        expect(Process).to receive(:initgroups).with("aj", 20)
         Chef::Daemon._change_privilege("aj")
       end
 
       it "should attempt to change the process GID" do
-        Process::GID.should_receive(:change_privilege).with(20).and_return(20)
+        expect(Process::GID).to receive(:change_privilege).with(20).and_return(20)
         Chef::Daemon._change_privilege("aj")
       end
 
       it "should attempt to change the process UID" do
-        Process::UID.should_receive(:change_privilege).with(501).and_return(501)
+        expect(Process::UID).to receive(:change_privilege).with(501).and_return(501)
         Chef::Daemon._change_privilege("aj")
       end
     end
 
     describe "with insufficient privileges" do
       before do
-        Process.stub(:euid).and_return(999)
-        Process.stub(:egid).and_return(999)
+        allow(Process).to receive(:euid).and_return(999)
+        allow(Process).to receive(:egid).and_return(999)
       end
 
       it "should log an appropriate error message and fail miserably" do
-        Process.stub(:initgroups).and_raise(Errno::EPERM)
+        allow(Process).to receive(:initgroups).and_raise(Errno::EPERM)
         error = "Operation not permitted"
         if RUBY_PLATFORM.match("solaris2") || RUBY_PLATFORM.match("aix")
           error = "Not owner"
         end
-        Chef::Application.should_receive(:fatal!).with("Permission denied when trying to change 999:999 to 501:20. #{error}")
+        expect(Chef::Application).to receive(:fatal!).with("Permission denied when trying to change 999:999 to 501:20. #{error}")
         Chef::Daemon._change_privilege("aj")
       end
     end
