@@ -25,8 +25,8 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
 
     @description = Chef::Formatters::ErrorDescription.new("Error Resolving Cookbooks for Run List:")
     @outputter_output = StringIO.new
-    @outputter = Chef::Formatters::Outputter.new(@outputter_output, STDERR)
-    # @outputter = Chef::Formatters::Outputter.new(STDOUT, STDERR)
+    @outputter = Chef::Formatters::IndentableOutputStream.new(@outputter_output, STDERR)
+    # @outputter = Chef::Formatters::IndentableOutputStream.new(STDOUT, STDERR)
   end
 
   describe "when explaining a 403 error" do
@@ -34,7 +34,7 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
 
       @response_body = %Q({"error": [{"message": "gtfo"}])
       @response = Net::HTTPForbidden.new("1.1", "403", "(response) forbidden")
-      @response.stub(:body).and_return(@response_body)
+      allow(@response).to receive(:body).and_return(@response_body)
       @exception = Net::HTTPServerException.new("(exception) forbidden", @response)
 
       @inspector = Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector.new(@expanded_run_list, @exception)
@@ -42,7 +42,7 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
     end
 
     it "prints a nice message" do
-      lambda { @description.display(@outputter) }.should_not raise_error
+      expect { @description.display(@outputter) }.not_to raise_error
     end
 
   end
@@ -55,7 +55,7 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
 
       @response_body = "{\"error\":[\"{\\\"non_existent_cookbooks\\\":[\\\"apache2\\\"],\\\"cookbooks_with_no_versions\\\":[\\\"users\\\"],\\\"message\\\":\\\"Run list contains invalid items: no such cookbook nope.\\\"}\"]}"
       @response = Net::HTTPPreconditionFailed.new("1.1", "412", "(response) unauthorized")
-      @response.stub(:body).and_return(@response_body)
+      allow(@response).to receive(:body).and_return(@response_body)
       @exception = Net::HTTPServerException.new("(exception) precondition failed", @response)
 
       @inspector = Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector.new(@expanded_run_list, @exception)
@@ -66,9 +66,9 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
       @description.display(@outputter)
       @outputter_output.rewind
       observed_output = @outputter_output.read
-      observed_output.should include("apache2")
-      observed_output.should include("users")
-      observed_output.should_not include("Run list contains invalid items: no such cookbook nope.")
+      expect(observed_output).to include("apache2")
+      expect(observed_output).to include("users")
+      expect(observed_output).not_to include("Run list contains invalid items: no such cookbook nope.")
     end
 
   end
@@ -83,7 +83,7 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
 
       @response_body = "{\"error\":[{\"non_existent_cookbooks\":[],\"cookbooks_with_no_versions\":[],\"message\":\"unable to solve dependencies in alotted time.\"}]}"
       @response = Net::HTTPPreconditionFailed.new("1.1", "412", "(response) unauthorized")
-      @response.stub(:body).and_return(@response_body)
+      allow(@response).to receive(:body).and_return(@response_body)
       @exception = Net::HTTPServerException.new("(exception) precondition failed", @response)
 
       @inspector = Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector.new(@expanded_run_list, @exception)
@@ -93,7 +93,7 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
     it "prints a pretty message" do
       @description.display(@outputter)
       @outputter_output.rewind
-      @outputter_output.read.should include("unable to solve dependencies in alotted time.")
+      expect(@outputter_output.read).to include("unable to solve dependencies in alotted time.")
     end
 
   end
@@ -106,7 +106,7 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
 
       @response_body = "{\"error\":[{\"non_existent_cookbooks\":[\"apache2\"],\"cookbooks_with_no_versions\":[\"users\"],\"message\":\"Run list contains invalid items: no such cookbook nope.\"}]}"
       @response = Net::HTTPPreconditionFailed.new("1.1", "412", "(response) unauthorized")
-      @response.stub(:body).and_return(@response_body)
+      allow(@response).to receive(:body).and_return(@response_body)
       @exception = Net::HTTPServerException.new("(exception) precondition failed", @response)
 
       @inspector = Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector.new(@expanded_run_list, @exception)
@@ -117,9 +117,9 @@ describe Chef::Formatters::ErrorInspectors::CookbookResolveErrorInspector do
       @description.display(@outputter)
       @outputter_output.rewind
       observed_output = @outputter_output.read
-      observed_output.should include("apache2")
-      observed_output.should include("users")
-      observed_output.should_not include("Run list contains invalid items: no such cookbook nope.")
+      expect(observed_output).to include("apache2")
+      expect(observed_output).to include("users")
+      expect(observed_output).not_to include("Run list contains invalid items: no such cookbook nope.")
     end
 
   end
