@@ -26,29 +26,29 @@ describe Chef::Knife::CookbookCreate do
     @knife.config = {}
     @knife.name_args = ["foobar"]
     @stdout = StringIO.new
-    @knife.stub(:stdout).and_return(@stdout)
+    allow(@knife).to receive(:stdout).and_return(@stdout)
   end
 
   describe "run" do
 
     # Fixes CHEF-2579
     it "should expand the path of the cookbook directory" do
-      File.should_receive(:expand_path).with("~/tmp/monkeypants")
+      expect(File).to receive(:expand_path).with("~/tmp/monkeypants")
       @knife.config = {:cookbook_path => "~/tmp/monkeypants"}
-      @knife.stub(:create_cookbook)
-      @knife.stub(:create_readme)
-      @knife.stub(:create_changelog)
-      @knife.stub(:create_metadata)
+      allow(@knife).to receive(:create_cookbook)
+      allow(@knife).to receive(:create_readme)
+      allow(@knife).to receive(:create_changelog)
+      allow(@knife).to receive(:create_metadata)
       @knife.run
     end
 
     it "should create a new cookbook with default values to copyright name, email, readme format and license if those are not supplied" do
       @dir = Dir.tmpdir
       @knife.config = {:cookbook_path => @dir}
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "YOUR_COMPANY_NAME", "none")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "YOUR_COMPANY_NAME", "YOUR_EMAIL", "none", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "YOUR_COMPANY_NAME", "none")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "YOUR_COMPANY_NAME", "YOUR_EMAIL", "none", "md")
       @knife.run
     end
 
@@ -59,10 +59,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_copyright => "Opscode, Inc"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "YOUR_EMAIL", "none", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "YOUR_EMAIL", "none", "md")
       @knife.run
     end
 
@@ -74,10 +74,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_email => "nuo@opscode.com"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "none", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "none", "md")
       @knife.run
     end
 
@@ -90,10 +90,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_license => "apachev2"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "apachev2")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "apachev2", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "apachev2")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "apachev2", "md")
       @knife.run
     end
 
@@ -106,10 +106,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_license => false
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "none", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "none", "md")
       @knife.run
     end
 
@@ -122,10 +122,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_license => "false"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "none", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "none")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "none", "md")
       @knife.run
     end
 
@@ -138,10 +138,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_license => "gplv2"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "gplv2")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "gplv2", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "gplv2")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "gplv2", "md")
       @knife.run
     end
 
@@ -154,10 +154,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_license => "gplv3"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "gplv3")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "gplv3", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "gplv3")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "gplv3", "md")
       @knife.run
     end
 
@@ -170,10 +170,10 @@ describe Chef::Knife::CookbookCreate do
         :cookbook_license => "mit"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "md")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "md")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "md")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "md")
       @knife.run
     end
 
@@ -187,10 +187,10 @@ describe Chef::Knife::CookbookCreate do
         :readme_format => "rdoc"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "rdoc")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "rdoc")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "rdoc")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "rdoc")
       @knife.run
     end
 
@@ -204,10 +204,10 @@ describe Chef::Knife::CookbookCreate do
         :readme_format => "mkd"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "mkd")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "mkd")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "mkd")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "mkd")
       @knife.run
     end
 
@@ -221,10 +221,10 @@ describe Chef::Knife::CookbookCreate do
         :readme_format => "txt"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "txt")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "txt")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "txt")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "txt")
       @knife.run
     end
 
@@ -238,10 +238,10 @@ describe Chef::Knife::CookbookCreate do
         :readme_format => "foo"
       }
       @knife.name_args=["foobar"]
-      @knife.should_receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
-      @knife.should_receive(:create_readme).with(@dir, @knife.name_args.first, "foo")
-      @knife.should_receive(:create_changelog).with(@dir, @knife.name_args.first)
-      @knife.should_receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "foo")
+      expect(@knife).to receive(:create_cookbook).with(@dir, @knife.name_args.first, "Opscode, Inc", "mit")
+      expect(@knife).to receive(:create_readme).with(@dir, @knife.name_args.first, "foo")
+      expect(@knife).to receive(:create_changelog).with(@dir, @knife.name_args.first)
+      expect(@knife).to receive(:create_metadata).with(@dir, @knife.name_args.first, "Opscode, Inc", "nuo@opscode.com", "mit", "foo")
       @knife.run
     end
 
@@ -252,7 +252,7 @@ describe Chef::Knife::CookbookCreate do
 
       it "should throw an argument error" do
         @dir = Dir.tmpdir
-        lambda{@knife.run}.should raise_error(ArgumentError)
+        expect{@knife.run}.to raise_error(ArgumentError)
       end
     end
 
