@@ -26,55 +26,55 @@ describe Chef::Knife::CookbookTest do
     Chef::Config[:node_name]  = "webmonkey.example.com"
     @knife = Chef::Knife::CookbookTest.new
     @knife.config[:cookbook_path] = File.join(CHEF_SPEC_DATA,'cookbooks')
-    @knife.cookbook_loader.stub(:cookbook_exists?).and_return(true)
+    allow(@knife.cookbook_loader).to receive(:cookbook_exists?).and_return(true)
     @cookbooks = []
     %w{tats central_market jimmy_johns pho}.each do |cookbook_name|
       @cookbooks << Chef::CookbookVersion.new(cookbook_name)
     end
     @stdout = StringIO.new
-    @knife.ui.stub(:stdout).and_return(@stdout)
+    allow(@knife.ui).to receive(:stdout).and_return(@stdout)
   end
 
   describe "run" do
     it "should test the cookbook" do
-      @knife.stub(:test_cookbook).and_return(true)
+      allow(@knife).to receive(:test_cookbook).and_return(true)
       @knife.name_args = ["italian"]
-      @knife.should_receive(:test_cookbook).with("italian")
+      expect(@knife).to receive(:test_cookbook).with("italian")
       @knife.run
     end
 
     it "should test multiple cookbooks when provided" do
-      @knife.stub(:test_cookbook).and_return(true)
+      allow(@knife).to receive(:test_cookbook).and_return(true)
       @knife.name_args = ["tats", "jimmy_johns"]
-      @knife.should_receive(:test_cookbook).with("tats")
-      @knife.should_receive(:test_cookbook).with("jimmy_johns")
-      @knife.should_not_receive(:test_cookbook).with("central_market")
-      @knife.should_not_receive(:test_cookbook).with("pho")
+      expect(@knife).to receive(:test_cookbook).with("tats")
+      expect(@knife).to receive(:test_cookbook).with("jimmy_johns")
+      expect(@knife).not_to receive(:test_cookbook).with("central_market")
+      expect(@knife).not_to receive(:test_cookbook).with("pho")
       @knife.run
     end
 
     it "should test both ruby and templates" do
       @knife.name_args = ["example"]
-      @knife.config[:cookbook_path].should_not be_empty
+      expect(@knife.config[:cookbook_path]).not_to be_empty
       Array(@knife.config[:cookbook_path]).reverse.each do |path|
-        @knife.should_receive(:test_ruby).with(an_instance_of(Chef::Cookbook::SyntaxCheck))
-        @knife.should_receive(:test_templates).with(an_instance_of(Chef::Cookbook::SyntaxCheck))
+        expect(@knife).to receive(:test_ruby).with(an_instance_of(Chef::Cookbook::SyntaxCheck))
+        expect(@knife).to receive(:test_templates).with(an_instance_of(Chef::Cookbook::SyntaxCheck))
       end
       @knife.run
     end
 
     describe "with -a or --all" do
       it "should test all of the cookbooks" do
-        @knife.stub(:test_cookbook).and_return(true)
+        allow(@knife).to receive(:test_cookbook).and_return(true)
         @knife.config[:all] = true
         @loader = {}
-        @loader.stub(:load_cookbooks).and_return(@loader)
+        allow(@loader).to receive(:load_cookbooks).and_return(@loader)
         @cookbooks.each do |cookbook|
           @loader[cookbook.name] = cookbook
         end
-        @knife.stub(:cookbook_loader).and_return(@loader)
+        allow(@knife).to receive(:cookbook_loader).and_return(@loader)
         @loader.each do |key, cookbook|
-          @knife.should_receive(:test_cookbook).with(cookbook.name)
+          expect(@knife).to receive(:test_cookbook).with(cookbook.name)
         end
         @knife.run
       end
