@@ -21,50 +21,50 @@ require 'spec_helper'
 describe Chef::Knife::EnvironmentDelete do
   before(:each) do
     @knife = Chef::Knife::EnvironmentDelete.new
-    @knife.stub(:msg).and_return true
-    @knife.stub(:output).and_return true
-    @knife.stub(:show_usage).and_return true
-    @knife.stub(:confirm).and_return true
+    allow(@knife).to receive(:msg).and_return true
+    allow(@knife).to receive(:output).and_return true
+    allow(@knife).to receive(:show_usage).and_return true
+    allow(@knife).to receive(:confirm).and_return true
     @knife.name_args = [ "production" ]
 
     @environment = Chef::Environment.new
     @environment.name("production")
     @environment.description("Please delete me")
-    @environment.stub(:destroy).and_return true
-    Chef::Environment.stub(:load).and_return @environment
+    allow(@environment).to receive(:destroy).and_return true
+    allow(Chef::Environment).to receive(:load).and_return @environment
   end
 
   it "should confirm that you want to delete" do
-    @knife.should_receive(:confirm)
+    expect(@knife).to receive(:confirm)
     @knife.run
   end
 
   it "should load the environment" do
-    Chef::Environment.should_receive(:load).with("production")
+    expect(Chef::Environment).to receive(:load).with("production")
     @knife.run
   end
 
   it "should delete the environment" do
-    @environment.should_receive(:destroy)
+    expect(@environment).to receive(:destroy)
     @knife.run
   end
 
   it "should not print the environment" do
-    @knife.should_not_receive(:output)
+    expect(@knife).not_to receive(:output)
     @knife.run
   end
 
   it "should show usage and exit when no environment name is provided" do
     @knife.name_args = []
-    @knife.ui.should_receive(:fatal)
-    @knife.should_receive(:show_usage)
-    lambda { @knife.run }.should raise_error(SystemExit)
+    expect(@knife.ui).to receive(:fatal)
+    expect(@knife).to receive(:show_usage)
+    expect { @knife.run }.to raise_error(SystemExit)
   end
 
   describe "with --print-after" do
     it "should pretty print the environment, formatted for display" do
       @knife.config[:print_after] = true
-      @knife.should_receive(:output).with(@environment)
+      expect(@knife).to receive(:output).with(@environment)
       @knife.run
     end
   end
