@@ -21,26 +21,26 @@ require 'spec_helper'
 describe Chef::Knife::EnvironmentEdit do
   before(:each) do
     @knife = Chef::Knife::EnvironmentEdit.new
-    @knife.ui.stub(:msg).and_return true
-    @knife.ui.stub(:output).and_return true
-    @knife.ui.stub(:show_usage).and_return true
+    allow(@knife.ui).to receive(:msg).and_return true
+    allow(@knife.ui).to receive(:output).and_return true
+    allow(@knife.ui).to receive(:show_usage).and_return true
     @knife.name_args = [ "production" ]
 
     @environment = Chef::Environment.new
     @environment.name("production")
     @environment.description("Please edit me")
-    @environment.stub(:save).and_return true
-    Chef::Environment.stub(:load).and_return @environment
-    @knife.ui.stub(:edit_data).and_return @environment
+    allow(@environment).to receive(:save).and_return true
+    allow(Chef::Environment).to receive(:load).and_return @environment
+    allow(@knife.ui).to receive(:edit_data).and_return @environment
   end
 
   it "should load the environment" do
-    Chef::Environment.should_receive(:load).with("production")
+    expect(Chef::Environment).to receive(:load).with("production")
     @knife.run
   end
 
   it "should let you edit the environment" do
-    @knife.ui.should_receive(:edit_data).with(@environment)
+    expect(@knife.ui).to receive(:edit_data).with(@environment)
     @knife.run
   end
 
@@ -48,31 +48,31 @@ describe Chef::Knife::EnvironmentEdit do
     pansy = Chef::Environment.new
 
     @environment.name("new_environment_name")
-    @knife.ui.should_receive(:edit_data).with(@environment).and_return(pansy)
-    pansy.should_receive(:save)
+    expect(@knife.ui).to receive(:edit_data).with(@environment).and_return(pansy)
+    expect(pansy).to receive(:save)
     @knife.run
   end
 
   it "should not save the unedited environment data" do
-    @environment.should_not_receive(:save)
+    expect(@environment).not_to receive(:save)
     @knife.run
   end
 
   it "should not print the environment" do
-    @knife.should_not_receive(:output)
+    expect(@knife).not_to receive(:output)
     @knife.run
   end
 
   it "shoud show usage and exit when no environment name is provided" do
     @knife.name_args = []
-    @knife.should_receive(:show_usage)
-    lambda { @knife.run }.should raise_error(SystemExit)
+    expect(@knife).to receive(:show_usage)
+    expect { @knife.run }.to raise_error(SystemExit)
   end
 
   describe "with --print-after" do
     it "should pretty print the environment, formatted for display" do
       @knife.config[:print_after] = true
-      @knife.ui.should_receive(:output).with(@environment)
+      expect(@knife.ui).to receive(:output).with(@environment)
       @knife.run
     end
   end
