@@ -23,23 +23,24 @@ Chef::Knife::EnvironmentFromFile.load_deps
 
 describe Chef::Knife::EnvironmentFromFile do
   before(:each) do
+    allow(Chef::Platform).to receive(:windows?) { false }
     @knife = Chef::Knife::EnvironmentFromFile.new
     @stdout = StringIO.new
-    @knife.ui.stub(:stdout).and_return(@stdout)
+    allow(@knife.ui).to receive(:stdout).and_return(@stdout)
     @knife.name_args = [ "spec.rb" ]
 
     @environment = Chef::Environment.new
     @environment.name("spec")
     @environment.description("runs the unit tests")
     @environment.cookbook_versions({"apt" => "= 1.2.3"})
-    @environment.stub(:save).and_return true
-    @knife.loader.stub(:load_from).and_return @environment
+    allow(@environment).to receive(:save).and_return true
+    allow(@knife.loader).to receive(:load_from).and_return @environment
   end
 
   describe "run" do
     it "loads the environment data from a file and saves it" do
-      @knife.loader.should_receive(:load_from).with('environments', 'spec.rb').and_return(@environment)
-      @environment.should_receive(:save)
+      expect(@knife.loader).to receive(:load_from).with('environments', 'spec.rb').and_return(@environment)
+      expect(@environment).to receive(:save)
       @knife.run
     end
 
@@ -47,41 +48,41 @@ describe Chef::Knife::EnvironmentFromFile do
       before(:each) do
         @env_apple = @environment.dup
         @env_apple.name("apple")
-        @knife.loader.stub(:load_from).with("apple.rb").and_return @env_apple
+        allow(@knife.loader).to receive(:load_from).with("apple.rb").and_return @env_apple
       end
 
       it "loads multiple environments if given" do
         @knife.name_args = [ "spec.rb", "apple.rb" ]
-        @environment.should_receive(:save).twice
+        expect(@environment).to receive(:save).twice
         @knife.run
       end
 
       it "loads all environments with -a" do
-        File.stub(:expand_path).with("./environments/*.{json,rb}").and_return("/tmp/environments")
-        Dir.stub(:glob).with("/tmp/environments").and_return(["spec.rb", "apple.rb"])
+        allow(File).to receive(:expand_path).with("./environments/").and_return("/tmp/environments")
+        allow(Dir).to receive(:glob).with("/tmp/environments/*.{json,rb}").and_return(["spec.rb", "apple.rb"])
         @knife.name_args = []
-        @knife.stub(:config).and_return({:all => true})
-        @environment.should_receive(:save).twice
+        allow(@knife).to receive(:config).and_return({:all => true})
+        expect(@environment).to receive(:save).twice
         @knife.run
       end
     end
 
     it "should not print the environment" do
-      @knife.should_not_receive(:output)
+      expect(@knife).not_to receive(:output)
       @knife.run
     end
 
     it "should show usage and exit if not filename is provided" do
       @knife.name_args = []
-      @knife.ui.should_receive(:fatal)
-      @knife.should_receive(:show_usage)
-      lambda { @knife.run }.should raise_error(SystemExit)
+      expect(@knife.ui).to receive(:fatal)
+      expect(@knife).to receive(:show_usage)
+      expect { @knife.run }.to raise_error(SystemExit)
     end
 
     describe "with --print-after" do
       it "should pretty print the environment, formatted for display" do
         @knife.config[:print_after] = true
-        @knife.should_receive(:output)
+        expect(@knife).to receive(:output)
         @knife.run
       end
     end
