@@ -26,66 +26,66 @@ describe Chef::Knife::Help do
   end
 
   it "should return a list of help topics" do
-    @knife.help_topics.should include("knife-status")
+    expect(@knife.help_topics).to include("knife-status")
   end
 
   it "should run man for you" do
     @knife.name_args = [ "shell" ]
-    @knife.should_receive(:exec).with(/^man \/.*\/shell.1$/)
+    expect(@knife).to receive(:exec).with(/^man \/.*\/shell.1$/)
     @knife.run
   end
 
   it "should suggest topics" do
     @knife.name_args = [ "list" ]
-    @knife.ui.stub(:msg)
-    @knife.ui.should_receive(:info).with("Available help topics are: ")
-    @knife.ui.should_receive(:msg).with(/knife/)
-    @knife.stub(:exec)
-    @knife.should_receive(:exit).with(1)
+    allow(@knife.ui).to receive(:msg)
+    expect(@knife.ui).to receive(:info).with("Available help topics are: ")
+    expect(@knife.ui).to receive(:msg).with(/knife/)
+    allow(@knife).to receive(:exec)
+    expect(@knife).to receive(:exit).with(1)
     @knife.run
   end
 
   describe "find_manpage_path" do
     it "should find the man page in the gem" do
-      @knife.find_manpage_path("shell").should =~ /distro\/common\/man\/man1\/chef-shell.1$/
+      expect(@knife.find_manpage_path("shell")).to match(/distro\/common\/man\/man1\/chef-shell.1$/)
     end
 
     it "should provide the man page name if not in the gem" do
-      @knife.find_manpage_path("foo").should == "foo"
+      expect(@knife.find_manpage_path("foo")).to eq("foo")
     end
   end
 
   describe "find_manpages_for_query" do
     it "should error if it does not find a match" do
-      @knife.ui.stub(:error)
-      @knife.ui.stub(:info)
-      @knife.ui.stub(:msg)
-      @knife.should_receive(:exit).with(1)
-      @knife.ui.should_receive(:error).with("No help found for 'chickens'")
-      @knife.ui.should_receive(:msg).with(/knife/)
+      allow(@knife.ui).to receive(:error)
+      allow(@knife.ui).to receive(:info)
+      allow(@knife.ui).to receive(:msg)
+      expect(@knife).to receive(:exit).with(1)
+      expect(@knife.ui).to receive(:error).with("No help found for 'chickens'")
+      expect(@knife.ui).to receive(:msg).with(/knife/)
       @knife.find_manpages_for_query("chickens")
     end
   end
 
   describe "print_help_topics" do
     it "should print the known help topics" do
-      @knife.ui.stub(:msg)
-      @knife.ui.stub(:info)
-      @knife.ui.should_receive(:msg).with(/knife/)
+      allow(@knife.ui).to receive(:msg)
+      allow(@knife.ui).to receive(:info)
+      expect(@knife.ui).to receive(:msg).with(/knife/)
       @knife.print_help_topics
     end
 
     it "should shorten topics prefixed by knife-" do
-      @knife.ui.stub(:msg)
-      @knife.ui.stub(:info)
-      @knife.ui.should_receive(:msg).with(/node/)
+      allow(@knife.ui).to receive(:msg)
+      allow(@knife.ui).to receive(:info)
+      expect(@knife.ui).to receive(:msg).with(/node/)
       @knife.print_help_topics
     end
 
     it "should not leave topics prefixed by knife-" do
-      @knife.ui.stub(:msg)
-      @knife.ui.stub(:info)
-      @knife.ui.should_not_receive(:msg).with(/knife-node/)
+      allow(@knife.ui).to receive(:msg)
+      allow(@knife.ui).to receive(:info)
+      expect(@knife.ui).not_to receive(:msg).with(/knife-node/)
       @knife.print_help_topics
     end
   end
