@@ -24,30 +24,30 @@ describe Chef::Knife::UserReregister do
     @knife = Chef::Knife::UserReregister.new
     @knife.name_args = [ 'a_user' ]
     @user_mock = double('user_mock', :private_key => "private_key")
-    Chef::User.stub(:load).and_return(@user_mock)
+    allow(Chef::User).to receive(:load).and_return(@user_mock)
     @stdout = StringIO.new
-    @knife.ui.stub(:stdout).and_return(@stdout)
+    allow(@knife.ui).to receive(:stdout).and_return(@stdout)
   end
 
   it 'prints usage and exits when a user name is not provided' do
     @knife.name_args = []
-    @knife.should_receive(:show_usage)
-    @knife.ui.should_receive(:fatal)
-    lambda { @knife.run }.should raise_error(SystemExit)
+    expect(@knife).to receive(:show_usage)
+    expect(@knife.ui).to receive(:fatal)
+    expect { @knife.run }.to raise_error(SystemExit)
   end
 
   it 'reregisters the user and prints the key' do
-    @user_mock.should_receive(:reregister).and_return(@user_mock)
+    expect(@user_mock).to receive(:reregister).and_return(@user_mock)
     @knife.run
-    @stdout.string.should match( /private_key/ )
+    expect(@stdout.string).to match( /private_key/ )
   end
 
   it 'writes the private key to a file when --file is specified' do
-    @user_mock.should_receive(:reregister).and_return(@user_mock)
+    expect(@user_mock).to receive(:reregister).and_return(@user_mock)
     @knife.config[:file] = '/tmp/a_file'
     filehandle = StringIO.new
-    File.should_receive(:open).with('/tmp/a_file', 'w').and_yield(filehandle)
+    expect(File).to receive(:open).with('/tmp/a_file', 'w').and_yield(filehandle)
     @knife.run
-    filehandle.string.should == "private_key"
+    expect(filehandle.string).to eq("private_key")
   end
 end
