@@ -33,54 +33,54 @@ describe Chef::Mixin::PathSanity do
       Chef::Config[:enforce_path_sanity] = true
       @ruby_bindir = '/some/ruby/bin'
       @gem_bindir = '/some/gem/bin'
-      Gem.stub(:bindir).and_return(@gem_bindir)
-      RbConfig::CONFIG.stub(:[]).with('bindir').and_return(@ruby_bindir)
-      Chef::Platform.stub(:windows?).and_return(false)
+      allow(Gem).to receive(:bindir).and_return(@gem_bindir)
+      allow(RbConfig::CONFIG).to receive(:[]).with('bindir').and_return(@ruby_bindir)
+      allow(Chef::Platform).to receive(:windows?).and_return(false)
     end
 
     it "adds all useful PATHs even if environment is an empty hash" do
       env={}
       @sanity.enforce_path_sanity(env)
-      env["PATH"].should == "#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
+      expect(env["PATH"]).to eq("#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin")
     end
 
     it "adds all useful PATHs that are not yet in PATH to PATH" do
       env = {"PATH" => ""}
       @sanity.enforce_path_sanity(env)
-      env["PATH"].should == "#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
+      expect(env["PATH"]).to eq("#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin")
     end
 
     it "does not re-add paths that already exist in PATH" do
       env = {"PATH" => "/usr/bin:/sbin:/bin"}
       @sanity.enforce_path_sanity(env)
-      env["PATH"].should == "/usr/bin:/sbin:/bin:#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin"
+      expect(env["PATH"]).to eq("/usr/bin:/sbin:/bin:#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin")
     end
 
     it "adds the current executing Ruby's bindir and Gem bindir to the PATH" do
       env = {"PATH" => ""}
       @sanity.enforce_path_sanity(env)
-      env["PATH"].should == "#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
+      expect(env["PATH"]).to eq("#{@ruby_bindir}:#{@gem_bindir}:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin")
     end
 
     it "does not create entries for Ruby/Gem bindirs if they exist in SANE_PATH or PATH" do
       ruby_bindir = '/usr/bin'
       gem_bindir = '/yo/gabba/gabba'
-      Gem.stub(:bindir).and_return(gem_bindir)
-      RbConfig::CONFIG.stub(:[]).with('bindir').and_return(ruby_bindir)
+      allow(Gem).to receive(:bindir).and_return(gem_bindir)
+      allow(RbConfig::CONFIG).to receive(:[]).with('bindir').and_return(ruby_bindir)
       env = {"PATH" => gem_bindir}
       @sanity.enforce_path_sanity(env)
-      env["PATH"].should == "/yo/gabba/gabba:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
+      expect(env["PATH"]).to eq("/yo/gabba/gabba:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin")
     end
 
     it "builds a valid windows path" do
       ruby_bindir = 'C:\ruby\bin'
       gem_bindir = 'C:\gems\bin'
-      Gem.stub(:bindir).and_return(gem_bindir)
-      RbConfig::CONFIG.stub(:[]).with('bindir').and_return(ruby_bindir)
-      Chef::Platform.stub(:windows?).and_return(true)
+      allow(Gem).to receive(:bindir).and_return(gem_bindir)
+      allow(RbConfig::CONFIG).to receive(:[]).with('bindir').and_return(ruby_bindir)
+      allow(Chef::Platform).to receive(:windows?).and_return(true)
       env = {"PATH" => 'C:\Windows\system32;C:\mr\softie'}
       @sanity.enforce_path_sanity(env)
-      env["PATH"].should == "C:\\Windows\\system32;C:\\mr\\softie;#{ruby_bindir};#{gem_bindir}"
+      expect(env["PATH"]).to eq("C:\\Windows\\system32;C:\\mr\\softie;#{ruby_bindir};#{gem_bindir}")
     end
   end
 end
