@@ -37,7 +37,7 @@ describe Chef::Provider::CookbookFile do
 
   let(:provider) do
     provider = described_class.new(resource, run_context)
-    provider.stub(:content).and_return(content)
+    allow(provider).to receive(:content).and_return(content)
     provider
   end
 
