@@ -21,6 +21,7 @@ require 'spec_helper'
 describe Chef::Provider::Deploy::Revision do
 
   before do
+    allow(Chef::Platform).to receive(:windows?) { false }
     @temp_dir = Dir.mktmpdir
     Chef::Config[:file_cache_path] = @temp_dir
     @resource = Chef::Resource::Deploy.new("/my/deploy/dir")
@@ -31,7 +32,7 @@ describe Chef::Provider::Deploy::Revision do
     @provider = Chef::Provider::Deploy::Revision.new(@resource, @run_context)
     @provider.load_current_resource
     @runner = double("runnah")
-    Chef::Runner.stub(:new).and_return(@runner)
+    allow(Chef::Runner).to receive(:new).and_return(@runner)
     @expected_release_dir = "/my/deploy/dir/releases/8a3195bf3efa246f743c5dfa83683201880f935c"
   end
 
@@ -42,41 +43,41 @@ describe Chef::Provider::Deploy::Revision do
 
 
   it "uses the resolved revision from the SCM as the release slug" do
-    @provider.scm_provider.stub(:revision_slug).and_return("uglySlugly")
-    @provider.send(:release_slug).should == "uglySlugly"
+    allow(@provider.scm_provider).to receive(:revision_slug).and_return("uglySlugly")
+    expect(@provider.send(:release_slug)).to eq("uglySlugly")
   end
 
   it "deploys to a dir named after the revision" do
-    @provider.release_path.should == @expected_release_dir
+    expect(@provider.release_path).to eq(@expected_release_dir)
   end
 
   it "stores the release dir in the file cache in the cleanup step" do
-    FileUtils.stub(:mkdir_p)
-    FileUtils.stub(:cp_r)
+    allow(FileUtils).to receive(:mkdir_p)
+    allow(FileUtils).to receive(:cp_r)
     @provider.cleanup!
-    @provider.stub(:release_slug).and_return("73219b87e977d9c7ba1aa57e9ad1d88fa91a0ec2")
+    allow(@provider).to receive(:release_slug).and_return("73219b87e977d9c7ba1aa57e9ad1d88fa91a0ec2")
     @provider.load_current_resource
     @provider.cleanup!
     second_release = "/my/deploy/dir/releases/73219b87e977d9c7ba1aa57e9ad1d88fa91a0ec2"
 
-    @provider.all_releases.should == [@expected_release_dir,second_release]
+    expect(@provider.all_releases).to eq([@expected_release_dir,second_release])
   end
 
   it "removes a release from the file cache when it's used again in another release and append it to the end" do
-    FileUtils.stub(:mkdir_p)
-    FileUtils.stub(:cp_r)
+    allow(FileUtils).to receive(:mkdir_p)
+    allow(FileUtils).to receive(:cp_r)
     @provider.cleanup!
-    @provider.stub(:release_slug).and_return("73219b87e977d9c7ba1aa57e9ad1d88fa91a0ec2")
+    allow(@provider).to receive(:release_slug).and_return("73219b87e977d9c7ba1aa57e9ad1d88fa91a0ec2")
     @provider.load_current_resource
     @provider.cleanup!
     second_release = "/my/deploy/dir/releases/73219b87e977d9c7ba1aa57e9ad1d88fa91a0ec2"
-    @provider.all_releases.should == [@expected_release_dir,second_release]
+    expect(@provider.all_releases).to eq([@expected_release_dir,second_release])
     @provider.cleanup!
 
-    @provider.stub(:release_slug).and_return("8a3195bf3efa246f743c5dfa83683201880f935c")
+    allow(@provider).to receive(:release_slug).and_return("8a3195bf3efa246f743c5dfa83683201880f935c")
     @provider.load_current_resource
     @provider.cleanup!
-    @provider.all_releases.should == [second_release, @expected_release_dir]
+    expect(@provider.all_releases).to eq([second_release, @expected_release_dir])
   end
 
   it "removes a release from the file cache when it's deleted by :cleanup!" do
@@ -86,25 +87,25 @@ describe Chef::Provider::Deploy::Revision do
     release_paths.each do |release_path|
       @provider.send(:release_created, release_path)
     end
-    @provider.all_releases.should == release_paths
+    expect(@provider.all_releases).to eq(release_paths)
 
-    FileUtils.stub(:rm_rf)
+    allow(FileUtils).to receive(:rm_rf)
     @provider.cleanup!
 
     expected_release_paths = (%w{second third fourth fifth} << @resource.revision).map do |release_name|
        "/my/deploy/dir/releases/#{release_name}"
     end
 
-    @provider.all_releases.should == expected_release_paths
+    expect(@provider.all_releases).to eq(expected_release_paths)
   end
 
   it "regenerates the file cache if it's not available" do
     oldest = "/my/deploy/dir/releases/oldest"
     latest = "/my/deploy/dir/releases/latest"
-    Dir.should_receive(:glob).with("/my/deploy/dir/releases/*").and_return([latest, oldest])
-    ::File.should_receive(:ctime).with(oldest).and_return(Time.now - 10)
-    ::File.should_receive(:ctime).with(latest).and_return(Time.now - 1)
-    @provider.all_releases.should == [oldest, latest]
+    expect(Dir).to receive(:glob).with("/my/deploy/dir/releases/*").and_return([latest, oldest])
+    expect(::File).to receive(:ctime).with(oldest).and_return(Time.now - 10)
+    expect(::File).to receive(:ctime).with(latest).and_return(Time.now - 1)
+    expect(@provider.all_releases).to eq([oldest, latest])
   end
 
 end
