@@ -27,69 +27,66 @@ describe Chef::Provider::Group::Dscl do
     @current_resource = Chef::Resource::Group.new("aj")
     @provider = Chef::Provider::Group::Dscl.new(@new_resource, @run_context)
     @provider.current_resource = @current_resource
-    @status = double("Process::Status", :exitstatus => 0)
-    @pid = 2342
-    @stdin = StringIO.new
-    @stdout = StringIO.new("\n")
-    @stderr = StringIO.new("")
-    @provider.stub(:popen4).and_yield(@pid,@stdin,@stdout,@stderr).and_return(@status)
+
+    @status = double(:stdout => "\n", :stderr => "", :exitstatus => 0)
+    allow(@provider).to receive(:shell_out).and_return(@status)
   end
 
-  it "should run popen4 with the supplied array of arguments appended to the dscl command" do
-    @provider.should_receive(:popen4).with("dscl . -cmd /Path arg1 arg2")
+  it "should run shell_out with the supplied array of arguments appended to the dscl command" do
+    expect(@provider).to receive(:shell_out).with("dscl . -cmd /Path arg1 arg2")
     @provider.dscl("cmd", "/Path", "arg1", "arg2")
   end
 
   it "should return an array of four elements - cmd, status, stdout, stderr" do
     dscl_retval = @provider.dscl("cmd /Path args")
-    dscl_retval.should be_a_kind_of(Array)
-    dscl_retval.should == ["dscl . -cmd /Path args",@status,"\n",""]
+    expect(dscl_retval).to be_a_kind_of(Array)
+    expect(dscl_retval).to eq(["dscl . -cmd /Path args",@status,"\n",""])
   end
 
   describe "safe_dscl" do
     before do
       @node = Chef::Node.new
       @provider = Chef::Provider::Group::Dscl.new(@node, @new_resource)
-      @provider.stub(:dscl).and_return(["cmd", @status, "stdout", "stderr"])
+      allow(@provider).to receive(:dscl).and_return(["cmd", @status, "stdout", "stderr"])
     end
 
     it "should run dscl with the supplied cmd /Path args" do
-      @provider.should_receive(:dscl).with("cmd /Path args")
+      expect(@provider).to receive(:dscl).with("cmd /Path args")
       @provider.safe_dscl("cmd /Path args")
     end
 
     describe "with the dscl command returning a non zero exit status for a delete" do
       before do
         @status = double("Process::Status", :exitstatus => 1)
-        @provider.stub(:dscl).and_return(["cmd", @status, "stdout", "stderr"])
+        allow(@provider).to receive(:dscl).and_return(["cmd", @status, "stdout", "stderr"])
       end
 
       it "should return an empty string of standard output for a delete" do
         safe_dscl_retval = @provider.safe_dscl("delete /Path args")
-        safe_dscl_retval.should be_a_kind_of(String)
-        safe_dscl_retval.should == ""
+        expect(safe_dscl_retval).to be_a_kind_of(String)
+        expect(safe_dscl_retval).to eq("")
       end
 
       it "should raise an exception for any other command" do
-        lambda { @provider.safe_dscl("cmd /Path arguments") }.should raise_error(Chef::Exceptions::Group)
+        expect { @provider.safe_dscl("cmd /Path arguments") }.to raise_error(Chef::Exceptions::Group)
       end
     end
 
     describe "with the dscl command returning no such key" do
       before do
-        @provider.stub(:dscl).and_return(["cmd", @status, "No such key: ", "stderr"])
+        allow(@provider).to receive(:dscl).and_return(["cmd", @status, "No such key: ", "stderr"])
       end
 
       it "should raise an exception" do
-        lambda { @provider.safe_dscl("cmd /Path arguments") }.should raise_error(Chef::Exceptions::Group)
+        expect { @provider.safe_dscl("cmd /Path arguments") }.to raise_error(Chef::Exceptions::Group)
       end
     end
 
     describe "with the dscl command returning a zero exit status" do
       it "should return the third array element, the string of standard output" do
         safe_dscl_retval = @provider.safe_dscl("cmd /Path args")
-        safe_dscl_retval.should be_a_kind_of(String)
-        safe_dscl_retval.should == "stdout"
+        expect(safe_dscl_retval).to be_a_kind_of(String)
+        expect(safe_dscl_retval).to eq("stdout")
       end
     end
   end
@@ -98,21 +95,21 @@ describe Chef::Provider::Group::Dscl do
     before do
       @node = Chef::Node.new
       @provider = Chef::Provider::Group::Dscl.new(@node, @new_resource)
-      @provider.stub(:safe_dscl).and_return("\naj      200\njt      201\n")
+      allow(@provider).to receive(:safe_dscl).and_return("\naj      200\njt      201\n")
     end
 
     it "should run safe_dscl with list /Groups gid" do
-      @provider.should_receive(:safe_dscl).with("list /Groups gid")
+      expect(@provider).to receive(:safe_dscl).with("list /Groups gid")
       @provider.get_free_gid
     end
 
     it "should return the first unused gid number on or above 200" do
-      @provider.get_free_gid.should equal(202)
+      expect(@provider.get_free_gid).to equal(202)
     end
 
     it "should raise an exception when the search limit is exhausted" do
       search_limit = 1
-      lambda { @provider.get_free_gid(search_limit) }.should raise_error(RuntimeError)
+      expect { @provider.get_free_gid(search_limit) }.to raise_error(RuntimeError)
     end
   end
 
@@ -120,41 +117,41 @@ describe Chef::Provider::Group::Dscl do
     before do
       @node = Chef::Node.new
       @provider = Chef::Provider::Group::Dscl.new(@node, @new_resource)
-      @provider.stub(:safe_dscl).and_return("\naj      500\n")
+      allow(@provider).to receive(:safe_dscl).and_return("\naj      500\n")
     end
 
     it "should run safe_dscl with list /Groups gid" do
-      @provider.should_receive(:safe_dscl).with("list /Groups gid")
+      expect(@provider).to receive(:safe_dscl).with("list /Groups gid")
       @provider.gid_used?(500)
     end
 
     it "should return true for a used gid number" do
-      @provider.gid_used?(500).should be_true
+      expect(@provider.gid_used?(500)).to be_truthy
     end
 
     it "should return false for an unused gid number" do
-      @provider.gid_used?(501).should be_false
+      expect(@provider.gid_used?(501)).to be_falsey
     end
 
     it "should return false if not given any valid gid number" do
-      @provider.gid_used?(nil).should be_false
+      expect(@provider.gid_used?(nil)).to be_falsey
     end
   end
 
   describe "set_gid" do
     describe "with the new resource and a gid number which is already in use" do
       before do
-        @provider.stub(:gid_used?).and_return(true)
+        allow(@provider).to receive(:gid_used?).and_return(true)
       end
 
       it "should raise an exception if the new resources gid is already in use" do
-        lambda { @provider.set_gid }.should raise_error(Chef::Exceptions::Group)
+        expect { @provider.set_gid }.to raise_error(Chef::Exceptions::Group)
       end
     end
 
     describe "with no gid number for the new resources" do
       it "should run get_free_gid and return a valid, unused gid number" do
-        @provider.should_receive(:get_free_gid).and_return(501)
+        expect(@provider).to receive(:get_free_gid).and_return(501)
         @provider.set_gid
       end
     end
@@ -162,20 +159,20 @@ describe Chef::Provider::Group::Dscl do
     describe "with blank gid number for the new resources" do
       before do
         @new_resource.instance_variable_set(:@gid, nil)
-        @new_resource.stub(:safe_dscl)
+        allow(@new_resource).to receive(:safe_dscl)
       end
 
       it "should run get_free_gid and return a valid, unused gid number" do
-        @provider.should_receive(:get_free_gid).and_return(501)
+        expect(@provider).to receive(:get_free_gid).and_return(501)
         @provider.set_gid
       end
     end
 
     describe "with a valid gid number which is not already in use" do
       it "should run safe_dscl with create /Groups/group PrimaryGroupID gid" do
-        @provider.stub(:get_free_gid).and_return(50)
-        @provider.should_receive(:safe_dscl).with("list /Groups gid")
-        @provider.should_receive(:safe_dscl).with("create /Groups/aj PrimaryGroupID 50").and_return(true)
+        allow(@provider).to receive(:get_free_gid).and_return(50)
+        expect(@provider).to receive(:safe_dscl).with("list /Groups gid")
+        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj PrimaryGroupID 50").and_return(true)
         @provider.set_gid
       end
     end
@@ -185,19 +182,19 @@ describe Chef::Provider::Group::Dscl do
 
     describe "with existing members in the current resource and append set to false in the new resource" do
       before do
-        @new_resource.stub(:members).and_return([])
-        @new_resource.stub(:append).and_return(false)
-        @current_resource.stub(:members).and_return(["all", "your", "base"])
+        allow(@new_resource).to receive(:members).and_return([])
+        allow(@new_resource).to receive(:append).and_return(false)
+        allow(@current_resource).to receive(:members).and_return(["all", "your", "base"])
       end
 
       it "should log an appropriate message" do
-        Chef::Log.should_receive(:debug).with("group[aj] removing group members all your base")
+        expect(Chef::Log).to receive(:debug).with("group[aj] removing group members all your base")
         @provider.set_members
       end
 
       it "should run safe_dscl with create /Groups/group GroupMembership to clear the Group's UID list" do
-        @provider.should_receive(:safe_dscl).with("create /Groups/aj GroupMembers ''").and_return(true)
-        @provider.should_receive(:safe_dscl).with("create /Groups/aj GroupMembership ''").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembers ''").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembership ''").and_return(true)
         @provider.set_members
       end
     end
@@ -209,14 +206,14 @@ describe Chef::Provider::Group::Dscl do
       end
 
       it "should log an appropriate debug message" do
-        Chef::Log.should_receive(:debug).with("group[aj] setting group members all, your, base")
+        expect(Chef::Log).to receive(:debug).with("group[aj] setting group members all, your, base")
         @provider.set_members
       end
 
       it "should run safe_dscl with append /Groups/group GroupMembership and group members all, your, base" do
-        @provider.should_receive(:safe_dscl).with("create /Groups/aj GroupMembers ''").and_return(true)
-        @provider.should_receive(:safe_dscl).with("append /Groups/aj GroupMembership all your base").and_return(true)
-        @provider.should_receive(:safe_dscl).with("create /Groups/aj GroupMembership ''").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembers ''").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("append /Groups/aj GroupMembership all your base").and_return(true)
+        expect(@provider).to receive(:safe_dscl).with("create /Groups/aj GroupMembership ''").and_return(true)
         @provider.set_members
       end
     end
@@ -228,7 +225,7 @@ describe Chef::Provider::Group::Dscl do
       end
 
       it "should not call safe_dscl" do
-        @provider.should_not_receive(:safe_dscl)
+        expect(@provider).not_to receive(:safe_dscl)
         @provider.set_members
       end
     end
@@ -240,24 +237,25 @@ describe Chef::Provider::Group::Dscl do
       @provider.load_current_resource
       @provider.define_resource_requirements
     end
-    it "raises an error if the required binary /usr/bin/dscl doesn't exist" do
-      File.should_receive(:exists?).with("/usr/bin/dscl").and_return(false)
 
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Group)
+    it "raises an error if the required binary /usr/bin/dscl doesn't exist" do
+      expect(File).to receive(:exists?).with("/usr/bin/dscl").and_return(false)
+
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Group)
     end
 
     it "doesn't raise an error if /usr/bin/dscl exists" do
-      File.stub(:exists?).and_return(true)
-      lambda { @provider.process_resource_requirements }.should_not raise_error
+      allow(File).to receive(:exists?).and_return(true)
+      expect { @provider.process_resource_requirements }.not_to raise_error
     end
   end
 
   describe "when creating the group" do
     it "creates the group, password field, gid, and sets group membership" do
-      @provider.should_receive(:set_gid).and_return(true)
-      @provider.should_receive(:set_members).and_return(true)
-      @provider.should_receive(:safe_dscl).with("create /Groups/aj Password '*'")
-      @provider.should_receive(:safe_dscl).with("create /Groups/aj")
+      expect(@provider).to receive(:set_gid).and_return(true)
+      expect(@provider).to receive(:set_members).and_return(true)
+      expect(@provider).to receive(:safe_dscl).with("create /Groups/aj Password '*'")
+      expect(@provider).to receive(:safe_dscl).with("create /Groups/aj")
       @provider.create_group
     end
   end
@@ -266,31 +264,68 @@ describe Chef::Provider::Group::Dscl do
     it "should manage the group_name if it changed and the new resources group_name is not null" do
       @current_resource.group_name("oldval")
       @new_resource.group_name("newname")
-      @provider.should_receive(:set_members).and_return(true)
-      @provider.should_receive(:safe_dscl).with("create /Groups/newname")
-      @provider.should_receive(:safe_dscl).with("create /Groups/newname Password '*'")
+      expect(@provider).to receive(:set_members).and_return(true)
+      expect(@provider).to receive(:safe_dscl).with("create /Groups/newname")
+      expect(@provider).to receive(:safe_dscl).with("create /Groups/newname Password '*'")
       @provider.manage_group
     end
 
     it "should manage the gid if it changed and the new resources gid is not null" do
       @current_resource.gid(23)
       @new_resource.gid(42)
-      @provider.should_receive(:set_gid)
+      expect(@provider).to receive(:set_gid)
       @provider.manage_group
     end
 
     it "should manage the members if it changed and the new resources members is not null" do
       @current_resource.members(%{charlie root})
       @new_resource.members(%{crab revenge})
-      @provider.should_receive(:set_members)
+      expect(@provider).to receive(:set_members)
       @provider.manage_group
     end
   end
 
   describe "remove_group" do
     it "should run safe_dscl with delete /Groups/group and with the new resources group name" do
-      @provider.should_receive(:safe_dscl).with("delete /Groups/aj").and_return(true)
+      expect(@provider).to receive(:safe_dscl).with("delete /Groups/aj").and_return(true)
       @provider.remove_group
     end
   end
 end
+
+describe 'Test DSCL loading' do
+  before do
+    @node = Chef::Node.new
+    @events = Chef::EventDispatch::Dispatcher.new
+    @run_context = Chef::RunContext.new(@node, {}, @events)
+    @new_resource = Chef::Resource::Group.new("group name aj")
+    @new_resource.group_name("aj")
+    @provider = Chef::Provider::Group::Dscl.new(@new_resource, @run_context)
+    @output = <<-EOF
+AppleMetaNodeLocation: /Local/Default
+Comment:
+ Test Group
+GeneratedUID: AAAAAAAA-AAAA-AAAA-AAAA-AAAAAAAAAAAA
+NestedGroups: AAAAAAAA-AAAA-AAAA-AAAA-AAAAAAAAAAAB
+Password: *
+PrimaryGroupID: 999
+RealName:
+ TestGroup
+RecordName: com.apple.aj
+RecordType: dsRecTypeStandard:Groups
+GroupMembership: waka bar
+EOF
+    allow(@provider).to receive(:safe_dscl).with("read /Groups/aj").and_return(@output)
+    @current_resource = @provider.load_current_resource
+
+  end
+
+  it 'should parse gid properly' do
+    allow(File).to receive(:exists?).and_return(true)
+    expect(@current_resource.gid).to eq("999")
+  end
+  it 'should parse members properly' do
+    allow(File).to receive(:exists?).and_return(true)
+    expect(@current_resource.members).to eq(['waka', 'bar'])
+  end
+end
