@@ -33,18 +33,18 @@ describe Chef::Provider::Group::Groupmod do
   describe "manage_group" do
     describe "when determining the current group state" do
       it "should raise an error if the required binary /usr/sbin/group doesn't exist" do
-        File.should_receive(:exists?).with("/usr/sbin/group").and_return(false)
-        lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Group)
+        expect(File).to receive(:exists?).with("/usr/sbin/group").and_return(false)
+        expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Group)
       end
       it "should raise an error if the required binary /usr/sbin/user doesn't exist" do
-        File.should_receive(:exists?).with("/usr/sbin/group").and_return(true)
-        File.should_receive(:exists?).with("/usr/sbin/user").and_return(false)
-        lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Group)
+        expect(File).to receive(:exists?).with("/usr/sbin/group").and_return(true)
+        expect(File).to receive(:exists?).with("/usr/sbin/user").and_return(false)
+        expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Group)
       end
 
       it "shouldn't raise an error if the required binaries exist" do
-        File.stub(:exists?).and_return(true)
-        lambda { @provider.load_current_resource }.should_not raise_error
+        allow(File).to receive(:exists?).and_return(true)
+        expect { @provider.load_current_resource }.not_to raise_error
       end
     end
 
@@ -61,10 +61,10 @@ describe Chef::Provider::Group::Groupmod do
         end
 
         it "logs a message and sets group's members to 'none', then removes existing group members" do
-          Chef::Log.should_receive(:debug).with("group[wheel] setting group members to: none")
-          @provider.should_receive(:shell_out!).with("group mod -n wheel_bak wheel")
-          @provider.should_receive(:shell_out!).with("group add -g '123' -o wheel")
-          @provider.should_receive(:shell_out!).with("group del wheel_bak")
+          expect(Chef::Log).to receive(:debug).with("group[wheel] setting group members to: none")
+          expect(@provider).to receive(:shell_out!).with("group mod -n wheel_bak wheel")
+          expect(@provider).to receive(:shell_out!).with("group add -g '123' -o wheel")
+          expect(@provider).to receive(:shell_out!).with("group del wheel_bak")
           @provider.manage_group
         end
       end
@@ -76,8 +76,8 @@ describe Chef::Provider::Group::Groupmod do
         end
 
         it "logs a message and does not modify group membership" do
-          Chef::Log.should_receive(:debug).with("group[wheel] not changing group members, the group has no members to add")
-          @provider.should_not_receive(:shell_out!)
+          expect(Chef::Log).to receive(:debug).with("group[wheel] not changing group members, the group has no members to add")
+          expect(@provider).not_to receive(:shell_out!)
           @provider.manage_group
         end
       end
@@ -89,11 +89,11 @@ describe Chef::Provider::Group::Groupmod do
         end
 
         it "updates group membership correctly" do
-          Chef::Log.stub(:debug)
-          @provider.should_receive(:shell_out!).with("group mod -n wheel_bak wheel")
-          @provider.should_receive(:shell_out!).with("user mod -G wheel lobster")
-          @provider.should_receive(:shell_out!).with("group add -g '123' -o wheel")
-          @provider.should_receive(:shell_out!).with("group del wheel_bak")
+          allow(Chef::Log).to receive(:debug)
+          expect(@provider).to receive(:shell_out!).with("group mod -n wheel_bak wheel")
+          expect(@provider).to receive(:shell_out!).with("user mod -G wheel lobster")
+          expect(@provider).to receive(:shell_out!).with("group add -g '123' -o wheel")
+          expect(@provider).to receive(:shell_out!).with("group del wheel_bak")
           @provider.manage_group
         end
       end
@@ -108,10 +108,10 @@ describe Chef::Provider::Group::Groupmod do
       end
 
       it "should run a group add command and some user mod commands" do
-        @provider.should_receive(:shell_out!).with("group add -g '123' wheel")
-        @provider.should_receive(:shell_out!).with("user mod -G wheel lobster")
-        @provider.should_receive(:shell_out!).with("user mod -G wheel rage")
-        @provider.should_receive(:shell_out!).with("user mod -G wheel fist")
+        expect(@provider).to receive(:shell_out!).with("group add -g '123' wheel")
+        expect(@provider).to receive(:shell_out!).with("user mod -G wheel lobster")
+        expect(@provider).to receive(:shell_out!).with("user mod -G wheel rage")
+        expect(@provider).to receive(:shell_out!).with("user mod -G wheel fist")
         @provider.create_group
       end
     end
@@ -125,7 +125,7 @@ describe Chef::Provider::Group::Groupmod do
       end
 
       it "should run a group del command" do
-        @provider.should_receive(:shell_out!).with("group del wheel")
+        expect(@provider).to receive(:shell_out!).with("group del wheel")
         @provider.remove_group
       end
     end
