@@ -35,7 +35,7 @@ describe Chef::Provider::HttpRequest do
   describe "load_current_resource" do
 
     it "should set up a Chef::REST client, with no authentication" do
-      Chef::HTTP::Simple.should_receive(:new).with(@new_resource.url)
+      expect(Chef::HTTP::Simple).to receive(:new).with(@new_resource.url)
       @provider.load_current_resource
     end
   end
@@ -44,7 +44,7 @@ describe Chef::Provider::HttpRequest do
     before(:each) do
       # run_action(x) forces load_current_resource to run;
       # that would overwrite our supplied mock Chef::Rest # object
-      @provider.stub(:load_current_resource).and_return(true)
+      allow(@provider).to receive(:load_current_resource).and_return(true)
       @http = double("Chef::REST")
       @provider.http = @http
     end
@@ -53,53 +53,53 @@ describe Chef::Provider::HttpRequest do
 
       it "should inflate a message block at runtime" do
         @new_resource.message { "return" }
-        @http.should_receive(:get).with("http://www.opscode.com/?message=return", {})
+        expect(@http).to receive(:get).with("http://www.opscode.com/", {})
         @provider.run_action(:get)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should run a GET request" do
-        @http.should_receive(:get).with("http://www.opscode.com/?message=is cool", {})
+        expect(@http).to receive(:get).with("http://www.opscode.com/", {})
         @provider.run_action(:get)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
     end
 
     describe "action_put" do
       it "should run a PUT request with the message as the payload" do
-        @http.should_receive(:put).with("http://www.opscode.com/", @new_resource.message, {})
+        expect(@http).to receive(:put).with("http://www.opscode.com/", @new_resource.message, {})
         @provider.run_action(:put)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should inflate a message block at runtime" do
-        @new_resource.stub(:message).and_return(lambda { "return" })
-        @http.should_receive(:put).with("http://www.opscode.com/", "return", {})
+        allow(@new_resource).to receive(:message).and_return(lambda { "return" })
+        expect(@http).to receive(:put).with("http://www.opscode.com/", "return", {})
         @provider.run_action(:put)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
     end
 
     describe "action_post" do
       it "should run a PUT request with the message as the payload" do
-        @http.should_receive(:post).with("http://www.opscode.com/", @new_resource.message, {})
+        expect(@http).to receive(:post).with("http://www.opscode.com/", @new_resource.message, {})
         @provider.run_action(:post)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should inflate a message block at runtime" do
         @new_resource.message { "return" }
-        @http.should_receive(:post).with("http://www.opscode.com/", "return", {})
+        expect(@http).to receive(:post).with("http://www.opscode.com/", "return", {})
         @provider.run_action(:post)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
     end
 
     describe "action_delete" do
       it "should run a DELETE request" do
-        @http.should_receive(:delete).with("http://www.opscode.com/", {})
+        expect(@http).to receive(:delete).with("http://www.opscode.com/", {})
         @provider.run_action(:delete)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
     end
 
@@ -112,46 +112,46 @@ describe Chef::Provider::HttpRequest do
 
       it "should inflate a message block at runtime" do
         @new_resource.message { "return" }
-        @http.should_receive(:head).with("http://www.opscode.com/?message=return", {}).and_return(nil)
+        expect(@http).to receive(:head).with("http://www.opscode.com/", {}).and_return(nil)
         @provider.run_action(:head)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should run a HEAD request" do
-        @http.should_receive(:head).with("http://www.opscode.com/?message=is cool", {}).and_return(nil)
+        expect(@http).to receive(:head).with("http://www.opscode.com/", {}).and_return(nil)
         @provider.run_action(:head)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should update a HEAD request with empty string response body (CHEF-4762)" do
-        @http.should_receive(:head).with("http://www.opscode.com/?message=is cool", {}).and_return("")
+        expect(@http).to receive(:head).with("http://www.opscode.com/", {}).and_return("")
         @provider.run_action(:head)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should update a HEAD request with nil response body (CHEF-4762)" do
-        @http.should_receive(:head).with("http://www.opscode.com/?message=is cool", {}).and_return(nil)
+        expect(@http).to receive(:head).with("http://www.opscode.com/", {}).and_return(nil)
         @provider.run_action(:head)
-        @new_resource.should be_updated
+        expect(@new_resource).to be_updated
       end
 
       it "should not update a HEAD request if a not modified response (CHEF-4762)" do
         if_modified_since = File.mtime(__FILE__).httpdate
         @new_resource.headers "If-Modified-Since" => if_modified_since
-        @http.should_receive(:head).with("http://www.opscode.com/?message=is cool", {"If-Modified-Since" => if_modified_since}).and_return(false)
+        expect(@http).to receive(:head).with("http://www.opscode.com/", {"If-Modified-Since" => if_modified_since}).and_return(false)
         @provider.run_action(:head)
-        @new_resource.should_not be_updated
+        expect(@new_resource).not_to be_updated
       end
 
       it "should run a HEAD request with If-Modified-Since header" do
         @new_resource.headers "If-Modified-Since" => File.mtime(__FILE__).httpdate
-        @http.should_receive(:head).with("http://www.opscode.com/?message=is cool", @new_resource.headers)
+        expect(@http).to receive(:head).with("http://www.opscode.com/", @new_resource.headers)
         @provider.run_action(:head)
       end
 
       it "doesn't call converge_by if HEAD does not return modified" do
-        @http.should_receive(:head).and_return(false)
-        @provider.should_not_receive(:converge_by)
+        expect(@http).to receive(:head).and_return(false)
+        expect(@provider).not_to receive(:converge_by)
         @provider.run_action(:head)
       end
     end
