@@ -32,22 +32,22 @@ describe Chef::Provider::Mdadm do
 
   describe "when determining the current metadevice status" do
     it "should set the current resources mount point to the new resources mount point" do
-      @provider.stub(:shell_out!).and_return(OpenStruct.new(:status => 0))
+      allow(@provider).to receive(:shell_out!).and_return(OpenStruct.new(:status => 0))
       @provider.load_current_resource
-      @provider.current_resource.name.should == '/dev/md1'
-      @provider.current_resource.raid_device.should == '/dev/md1'
+      expect(@provider.current_resource.name).to eq('/dev/md1')
+      expect(@provider.current_resource.raid_device).to eq('/dev/md1')
     end
 
     it "determines that the metadevice exists when mdadm exit code is zero" do
-      @provider.stub(:shell_out!).with("mdadm --detail --test /dev/md1", :returns => [0,4]).and_return(OpenStruct.new(:status => 0))
+      allow(@provider).to receive(:shell_out!).with("mdadm --detail --test /dev/md1", :returns => [0,4]).and_return(OpenStruct.new(:status => 0))
       @provider.load_current_resource
-      @provider.current_resource.exists.should be_true
+      expect(@provider.current_resource.exists).to be_truthy
     end
 
     it "determines that the metadevice does not exist when mdadm exit code is 4" do
-      @provider.stub(:shell_out!).with("mdadm --detail --test /dev/md1", :returns => [0,4]).and_return(OpenStruct.new(:status => 4))
+      allow(@provider).to receive(:shell_out!).with("mdadm --detail --test /dev/md1", :returns => [0,4]).and_return(OpenStruct.new(:status => 4))
       @provider.load_current_resource
-      @provider.current_resource.exists.should be_false
+      expect(@provider.current_resource.exists).to be_falsey
     end
   end
 
@@ -55,7 +55,7 @@ describe Chef::Provider::Mdadm do
     before(:each) do
       @current_resource = Chef::Resource::Mdadm.new('/dev/md1')
       @new_resource.level 5
-      @provider.stub(:load_current_resource).and_return(true)
+      allow(@provider).to receive(:load_current_resource).and_return(true)
       @provider.current_resource = @current_resource
     end
 
@@ -63,7 +63,7 @@ describe Chef::Provider::Mdadm do
       it "should create the raid device if it doesnt exist" do
         @current_resource.exists(false)
         expected_command = "yes | mdadm --create /dev/md1 --level 5 --chunk=16 --metadata=0.90 --raid-devices 3 /dev/sdz1 /dev/sdz2 /dev/sdz3"
-        @provider.should_receive(:shell_out!).with(expected_command)
+        expect(@provider).to receive(:shell_out!).with(expected_command)
         @provider.run_action(:create)
       end
 
@@ -71,25 +71,25 @@ describe Chef::Provider::Mdadm do
         @current_resource.exists(false)
         @new_resource.bitmap('grow')
         expected_command = "yes | mdadm --create /dev/md1 --level 5 --chunk=16 --metadata=0.90 --bitmap=grow --raid-devices 3 /dev/sdz1 /dev/sdz2 /dev/sdz3"
-        @provider.should_receive(:shell_out!).with(expected_command)
+        expect(@provider).to receive(:shell_out!).with(expected_command)
         @provider.run_action(:create)
-        @new_resource.should be_updated_by_last_action
+        expect(@new_resource).to be_updated_by_last_action
       end
 
       it "should not specify a chunksize if raid level 1" do
         @current_resource.exists(false)
         @new_resource.level 1
         expected_command = "yes | mdadm --create /dev/md1 --level 1 --metadata=0.90 --raid-devices 3 /dev/sdz1 /dev/sdz2 /dev/sdz3"
-        @provider.should_receive(:shell_out!).with(expected_command)
+        expect(@provider).to receive(:shell_out!).with(expected_command)
         @provider.run_action(:create)
-        @new_resource.should be_updated_by_last_action
+        expect(@new_resource).to be_updated_by_last_action
       end
 
       it "should not create the raid device if it does exist" do
         @current_resource.exists(true)
-        @provider.should_not_receive(:shell_out!)
+        expect(@provider).not_to receive(:shell_out!)
         @provider.run_action(:create)
-        @new_resource.should_not be_updated_by_last_action
+        expect(@new_resource).not_to be_updated_by_last_action
       end
     end
 
@@ -97,16 +97,16 @@ describe Chef::Provider::Mdadm do
       it "should assemble the raid device if it doesnt exist" do
         @current_resource.exists(false)
         expected_mdadm_cmd = "yes | mdadm --assemble /dev/md1 /dev/sdz1 /dev/sdz2 /dev/sdz3"
-        @provider.should_receive(:shell_out!).with(expected_mdadm_cmd)
+        expect(@provider).to receive(:shell_out!).with(expected_mdadm_cmd)
         @provider.run_action(:assemble)
-        @new_resource.should be_updated_by_last_action
+        expect(@new_resource).to be_updated_by_last_action
       end
 
         it "should not assemble the raid device if it doesnt exist" do
         @current_resource.exists(true)
-        @provider.should_not_receive(:shell_out!)
+        expect(@provider).not_to receive(:shell_out!)
         @provider.run_action(:assemble)
-        @new_resource.should_not be_updated_by_last_action
+        expect(@new_resource).not_to be_updated_by_last_action
       end
     end
 
@@ -115,16 +115,16 @@ describe Chef::Provider::Mdadm do
       it "should stop the raid device if it exists" do
         @current_resource.exists(true)
         expected_mdadm_cmd = "yes | mdadm --stop /dev/md1"
-        @provider.should_receive(:shell_out!).with(expected_mdadm_cmd)
+        expect(@provider).to receive(:shell_out!).with(expected_mdadm_cmd)
         @provider.run_action(:stop)
-        @new_resource.should be_updated_by_last_action
+        expect(@new_resource).to be_updated_by_last_action
       end
 
       it "should not attempt to stop the raid device if it does not exist" do
         @current_resource.exists(false)
-        @provider.should_not_receive(:shell_out!)
+        expect(@provider).not_to receive(:shell_out!)
         @provider.run_action(:stop)
-        @new_resource.should_not be_updated_by_last_action
+        expect(@new_resource).not_to be_updated_by_last_action
       end
     end
   end
