@@ -60,18 +60,18 @@ ENABLED
 
     @provider = Chef::Provider::Mount::Aix.new(@new_resource, @run_context)
 
-    ::File.stub(:exists?).with("/dev/sdz1").and_return true
-    ::File.stub(:exists?).with("/tmp/foo").and_return true
+    allow(::File).to receive(:exists?).with("/dev/sdz1").and_return true
+    allow(::File).to receive(:exists?).with("/tmp/foo").and_return true
   end
 
   def stub_mounted(provider, mounted_output)
     response = double("Mixlib::ShellOut command", :exitstatus => 0, :stdout => mounted_output, :stderr => "")
-    provider.should_receive(:shell_out!).with("mount").and_return(response)
+    expect(provider).to receive(:shell_out!).with("mount").and_return(response)
   end
 
   def stub_enabled(provider, enabled_output)
     response = double("Mixlib::ShellOut command", :exitstatus => 0, :stdout => enabled_output, :stderr => "")
-    provider.should_receive(:shell_out).with("lsfs -c #{@new_resource.mount_point}").and_return(response)
+    expect(provider).to receive(:shell_out).with("lsfs -c #{@new_resource.mount_point}").and_return(response)
   end
 
   def stub_mounted_enabled(provider, mounted_output, enabled_output)
@@ -84,7 +84,7 @@ ENABLED
       stub_mounted_enabled(@provider, @mounted_output, "")
       @provider.load_current_resource
 
-      expect(@provider.current_resource.mounted).to be_true
+      expect(@provider.current_resource.mounted).to be_truthy
     end
 
     it "should set current_resource.mounted to false if device is not mounted" do
@@ -92,7 +92,7 @@ ENABLED
 
       @provider.load_current_resource
 
-      expect(@provider.current_resource.mounted).to be_false
+      expect(@provider.current_resource.mounted).to be_falsey
     end
 
     it "should set current_resource.mounted to false if the mount point is used for another device" do
@@ -100,7 +100,7 @@ ENABLED
 
       @provider.load_current_resource
 
-      expect(@provider.current_resource.mounted).to be_false
+      expect(@provider.current_resource.mounted).to be_falsey
     end
   end
 
@@ -110,8 +110,8 @@ ENABLED
 
     @provider.load_current_resource
 
-    expect(@provider.current_resource.enabled).to be_true
-    expect(@provider.current_resource.mounted).to be_true
+    expect(@provider.current_resource.enabled).to be_truthy
+    expect(@provider.current_resource.mounted).to be_truthy
     expect(@provider.current_resource.mount_point).to eql(@new_resource.mount_point)
     expect(@provider.current_resource.fstype).to eql("jfs2")
     expect(@provider.current_resource.options).to eql(['rw'])
@@ -121,7 +121,7 @@ ENABLED
     it "should mount resource if it is not mounted" do
       stub_mounted_enabled(@provider, @unmounted_output, "")
 
-      @provider.should_receive(:shell_out!).with("mount -v #{@new_resource.fstype} #{@new_resource.device} #{@new_resource.mount_point}")
+      expect(@provider).to receive(:shell_out!).with("mount -v #{@new_resource.fstype} #{@new_resource.device} #{@new_resource.mount_point}")
 
       @provider.run_action(:mount)
     end
@@ -129,7 +129,7 @@ ENABLED
     it "should not mount resource if it is already mounted" do
       stub_mounted_enabled(@provider, @mounted_output, "")
 
-      @provider.should_not_receive(:mount_fs)
+      expect(@provider).not_to receive(:mount_fs)
 
       @provider.run_action(:mount)
     end
@@ -139,7 +139,7 @@ ENABLED
     it "should umount resource if it is already mounted" do
       stub_mounted_enabled(@provider, @mounted_output, "")
 
-      @provider.should_receive(:shell_out!).with("umount #{@new_resource.mount_point}")
+      expect(@provider).to receive(:shell_out!).with("umount #{@new_resource.mount_point}")
 
       @provider.run_action(:umount)
     end
@@ -147,7 +147,7 @@ ENABLED
     it "should not umount resource if it is not mounted" do
       stub_mounted_enabled(@provider, @unmounted_output, "")
 
-      @provider.should_not_receive(:umount_fs)
+      expect(@provider).not_to receive(:umount_fs)
 
       @provider.run_action(:umount)
     end
@@ -158,7 +158,7 @@ ENABLED
       @new_resource.supports({:remount => true})
       stub_mounted_enabled(@provider, @mounted_output, "")
 
-      @provider.should_receive(:shell_out!).with("mount -o remount #{@new_resource.device} #{@new_resource.mount_point}")
+      expect(@provider).to receive(:shell_out!).with("mount -o remount #{@new_resource.device} #{@new_resource.mount_point}")
 
       @provider.run_action(:remount)
     end
@@ -168,7 +168,7 @@ ENABLED
       @new_resource.options("nodev,rw")
       stub_mounted_enabled(@provider, @mounted_output, "")
 
-      @provider.should_receive(:shell_out!).with("mount -o remount,nodev,rw #{@new_resource.device} #{@new_resource.mount_point}")
+      expect(@provider).to receive(:shell_out!).with("mount -o remount,nodev,rw #{@new_resource.device} #{@new_resource.mount_point}")
 
       @provider.run_action(:remount)
     end
@@ -179,18 +179,18 @@ ENABLED
       @new_resource.options("nodev,rw")
       stub_mounted_enabled(@provider, @mounted_output, "")
       filesystems = StringIO.new
-      ::File.stub(:open).with("/etc/filesystems", "a").and_yield(filesystems)
+      allow(::File).to receive(:open).with("/etc/filesystems", "a").and_yield(filesystems)
 
       @provider.run_action(:enable)
 
-      filesystems.string.should match(%r{^/tmp/foo:\n\tdev\t\t= /dev/sdz1\n\tvfs\t\t= jfs2\n\tmount\t\t= false\n\toptions\t\t= nodev,rw\n$})
+      expect(filesystems.string).to match(%r{^/tmp/foo:\n\tdev\t\t= /dev/sdz1\n\tvfs\t\t= jfs2\n\tmount\t\t= false\n\toptions\t\t= nodev,rw\n$})
     end
 
     it "should not enable mount if it is mounted and already enabled and mount options are unchanged" do
       stub_mounted_enabled(@provider, @mounted_output, @enabled_output)
       @new_resource.options "rw"
 
-      @provider.should_not_receive(:enable_fs)
+      expect(@provider).not_to receive(:enable_fs)
 
       @provider.run_action(:enable)
     end
@@ -200,7 +200,7 @@ ENABLED
     it "should disable mount if it is mounted and enabled" do
       stub_mounted_enabled(@provider, @mounted_output, @enabled_output)
 
-      ::File.stub(:open).with("/etc/filesystems", "r").and_return(<<-ETCFILESYSTEMS)
+      allow(::File).to receive(:open).with("/etc/filesystems", "r").and_return(<<-ETCFILESYSTEMS)
 /tmp/foo:
   dev   = /dev/sdz1
   vfs   = jfs2
@@ -219,17 +219,17 @@ ENABLED
 ETCFILESYSTEMS
 
       filesystems = StringIO.new
-      ::File.stub(:open).with("/etc/filesystems", "w").and_yield(filesystems)
+      allow(::File).to receive(:open).with("/etc/filesystems", "w").and_yield(filesystems)
 
       @provider.run_action(:disable)
 
-      filesystems.string.should match(%r{^/tmp/abc:\s+dev\s+= /dev/sdz2\s+vfs\s+= jfs2\s+mount\s+= true\s+options\s+= rw\n$})
+      expect(filesystems.string).to match(%r{^/tmp/abc:\s+dev\s+= /dev/sdz2\s+vfs\s+= jfs2\s+mount\s+= true\s+options\s+= rw\n$})
     end
 
     it "should not disable mount if it is not mounted" do
       stub_mounted_enabled(@provider, @unmounted_output, "")
 
-      @provider.should_not_receive(:disable_fs)
+      expect(@provider).not_to receive(:disable_fs)
 
       @provider.run_action(:disable)
     end
