@@ -40,12 +40,12 @@ describe Chef::Provider::Mount::Windows do
     @new_resource = Chef::Resource::Mount.new("X:")
     @new_resource.device GUID
     @current_resource = Chef::Resource::Mount.new("X:")
-    Chef::Resource::Mount.stub(:new).and_return(@current_resource)
+    allow(Chef::Resource::Mount).to receive(:new).and_return(@current_resource)
 
     @net_use = double("Chef::Util::Windows::NetUse")
-    Chef::Util::Windows::NetUse.stub(:new).and_return(@net_use)
+    allow(Chef::Util::Windows::NetUse).to receive(:new).and_return(@net_use)
     @vol = double("Chef::Util::Windows::Volume")
-    Chef::Util::Windows::Volume.stub(:new).and_return(@vol)
+    allow(Chef::Util::Windows::Volume).to receive(:new).and_return(@vol)
 
     @provider = Chef::Provider::Mount::Windows.new(@new_resource, @run_context)
     @provider.current_resource = @current_resource
@@ -53,26 +53,26 @@ describe Chef::Provider::Mount::Windows do
 
   describe "when loading the current resource" do
     it "should set mounted true if the mount point is found" do
-      @vol.stub(:device).and_return(@new_resource.device)
-      @current_resource.should_receive(:mounted).with(true)
+      allow(@vol).to receive(:device).and_return(@new_resource.device)
+      expect(@current_resource).to receive(:mounted).with(true)
       @provider.load_current_resource
     end
 
     it "should set mounted false if the mount point is not found" do
-      @vol.stub(:device).and_raise(ArgumentError)
-      @current_resource.should_receive(:mounted).with(false)
+      allow(@vol).to receive(:device).and_raise(ArgumentError)
+      expect(@current_resource).to receive(:mounted).with(false)
       @provider.load_current_resource
     end
 
     describe "with a local device" do
       before do
         @new_resource.device GUID
-        @vol.stub(:device).and_return(@new_resource.device)
-        @net_use.stub(:device).and_raise(ArgumentError)
+        allow(@vol).to receive(:device).and_return(@new_resource.device)
+        allow(@net_use).to receive(:device).and_raise(ArgumentError)
       end
 
       it "should determine the device is a volume GUID" do
-        @provider.should_receive(:is_volume).with(@new_resource.device).and_return(true)
+        expect(@provider).to receive(:is_volume).with(@new_resource.device).and_return(true)
         @provider.load_current_resource
       end
     end
@@ -80,12 +80,12 @@ describe Chef::Provider::Mount::Windows do
     describe "with a remote device" do
       before do
         @new_resource.device REMOTE
-        @net_use.stub(:device).and_return(@new_resource.device)
-        @vol.stub(:device).and_raise(ArgumentError)
+        allow(@net_use).to receive(:device).and_return(@new_resource.device)
+        allow(@vol).to receive(:device).and_raise(ArgumentError)
       end
 
       it "should determine the device is remote" do
-        @provider.should_receive(:is_volume).with(@new_resource.device).and_return(false)
+        expect(@provider).to receive(:is_volume).with(@new_resource.device).and_return(false)
         @provider.load_current_resource
       end
     end
@@ -93,13 +93,13 @@ describe Chef::Provider::Mount::Windows do
     describe "when mounting a file system" do
       before do
         @new_resource.device GUID
-        @vol.stub(:add)
-        @vol.stub(:device).and_raise(ArgumentError)
+        allow(@vol).to receive(:add)
+        allow(@vol).to receive(:device).and_raise(ArgumentError)
         @provider.load_current_resource
       end
 
       it "should mount the filesystem if it is not mounted" do
-        @vol.should_receive(:add).with(:remote => @new_resource.device,
+        expect(@vol).to receive(:add).with(:remote => @new_resource.device,
                                        :username => @new_resource.username,
                                        :domainname => @new_resource.domain,
                                        :password => @new_resource.password)
@@ -107,8 +107,8 @@ describe Chef::Provider::Mount::Windows do
       end
 
       it "should not mount the filesystem if it is mounted" do
-        @vol.should_not_receive(:add)
-        @current_resource.stub(:mounted).and_return(true)
+        expect(@vol).not_to receive(:add)
+        allow(@current_resource).to receive(:mounted).and_return(true)
         @provider.mount_fs
       end
     end
@@ -116,20 +116,20 @@ describe Chef::Provider::Mount::Windows do
     describe "when unmounting a file system" do
       before do
         @new_resource.device GUID
-        @vol.stub(:delete)
-        @vol.stub(:device).and_raise(ArgumentError)
+        allow(@vol).to receive(:delete)
+        allow(@vol).to receive(:device).and_raise(ArgumentError)
         @provider.load_current_resource
       end
 
       it "should umount the filesystem if it is mounted" do
-        @current_resource.stub(:mounted).and_return(true)
-        @vol.should_receive(:delete)
+        allow(@current_resource).to receive(:mounted).and_return(true)
+        expect(@vol).to receive(:delete)
         @provider.umount_fs
       end
 
       it "should not umount the filesystem if it is not mounted" do
-        @current_resource.stub(:mounted).and_return(false)
-        @vol.should_not_receive(:delete)
+        allow(@current_resource).to receive(:mounted).and_return(false)
+        expect(@vol).not_to receive(:delete)
         @provider.umount_fs
       end
     end
