@@ -28,7 +28,7 @@ describe Chef::Provider::Package::Aix do
     @new_resource.source("/tmp/samba.base")
 
     @provider = Chef::Provider::Package::Aix.new(@new_resource, @run_context)
-    ::File.stub(:exists?).and_return(true)
+    allow(::File).to receive(:exists?).and_return(true)
   end
 
   describe "assessing the current package status" do
@@ -36,136 +36,125 @@ describe Chef::Provider::Package::Aix do
      @bffinfo ="/usr/lib/objrepos:samba.base:3.3.12.0::COMMITTED:I:Samba for AIX:
  /etc/objrepos:samba.base:3.3.12.0::COMMITTED:I:Samba for AIX:"
 
-      @status = double("Status", :exitstatus => 0)
+      @status = double("Status", :stdout => "", :exitstatus => 0)
     end
 
     it "should create a current resource with the name of new_resource" do
-      @provider.stub(:popen4).and_return(@status)
+      allow(@provider).to receive(:shell_out).and_return(@status)
       @provider.load_current_resource
-      @provider.current_resource.name.should == "samba.base"
+      expect(@provider.current_resource.name).to eq("samba.base")
     end
 
     it "should set the current resource bff package name to the new resource bff package name" do
-      @provider.stub(:popen4).and_return(@status)
+      allow(@provider).to receive(:shell_out).and_return(@status)
       @provider.load_current_resource
-      @provider.current_resource.package_name.should == "samba.base"
+      expect(@provider.current_resource.package_name).to eq("samba.base")
     end
 
     it "should raise an exception if a source is supplied but not found" do
-      @provider.stub(:popen4).and_return(@status)
-      ::File.stub(:exists?).and_return(false)
-      @provider.define_resource_requirements
+      allow(@provider).to receive(:shell_out).and_return(@status)
+      allow(::File).to receive(:exists?).and_return(false)
       @provider.load_current_resource
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Package)
+      @provider.define_resource_requirements
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Package)
     end
 
-
     it "should get the source package version from lslpp if provided" do
-      @stdout = StringIO.new(@bffinfo)
-      @stdin, @stderr = StringIO.new, StringIO.new
-      @provider.should_receive(:popen4).with("installp -L -d /tmp/samba.base").and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
-      @provider.should_receive(:popen4).with("lslpp -lcq samba.base").and_return(@status)
+      status = double("Status", :stdout => @bffinfo, :exitstatus => 0)
+      expect(@provider).to receive(:shell_out).with("installp -L -d /tmp/samba.base").and_return(status)
+      expect(@provider).to receive(:shell_out).with("lslpp -lcq samba.base").and_return(@status)
       @provider.load_current_resource
 
-      @provider.current_resource.package_name.should == "samba.base"
-      @new_resource.version.should == "3.3.12.0"
+      expect(@provider.current_resource.package_name).to eq("samba.base")
+      expect(@new_resource.version).to eq("3.3.12.0")
     end
 
     it "should return the current version installed if found by lslpp" do
+      status = double("Status", :stdout => @bffinfo, :exitstatus => 0)
       @stdout = StringIO.new(@bffinfo)
       @stdin, @stderr = StringIO.new, StringIO.new
-      @provider.should_receive(:popen4).with("installp -L -d /tmp/samba.base").and_return(@status)
-      @provider.should_receive(:popen4).with("lslpp -lcq samba.base").and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+      expect(@provider).to receive(:shell_out).with("installp -L -d /tmp/samba.base").and_return(@status)
+      expect(@provider).to receive(:shell_out).with("lslpp -lcq samba.base").and_return(status)
       @provider.load_current_resource
-      @provider.current_resource.version.should == "3.3.12.0"
+      expect(@provider.current_resource.version).to eq("3.3.12.0")
     end
 
     it "should raise an exception if the source is not set but we are installing" do
+      status = double("Status", :stdout => "", :exitstatus => 1, :format_for_exception => "")
       @new_resource = Chef::Resource::Package.new("samba.base")
       @provider = Chef::Provider::Package::Aix.new(@new_resource, @run_context)
-      @provider.stub(:popen4).and_return(@status)
-      lambda { @provider.run_action(:install) }.should raise_error(Chef::Exceptions::Package)
+      allow(@provider).to receive(:shell_out).and_return(status)
+      expect { @provider.run_action(:install) }.to raise_error(Chef::Exceptions::Package)
     end
 
     it "should raise an exception if installp/lslpp fails to run" do
-      @status = double("Status", :exitstatus => -1)
-      @provider.stub(:popen4).and_return(@status)
-      lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Package)
+      status = double(:stdout => "", :exitstatus => -1, :format_for_exception => "")
+      allow(@provider).to receive(:shell_out).and_return(status)
+      expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Package)
     end
 
     it "should return a current resource with a nil version if the package is not found" do
-      @stdout = StringIO.new
-      @provider.should_receive(:popen4).with("installp -L -d /tmp/samba.base").and_return(@status)
-      @provider.should_receive(:popen4).with("lslpp -lcq samba.base").and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+      status = double(:stdout => "", :exitstatus => 0)
+      expect(@provider).to receive(:shell_out).with("installp -L -d /tmp/samba.base").and_return(status)
+      expect(@provider).to receive(:shell_out).with("lslpp -lcq samba.base").and_return(status)
       @provider.load_current_resource
-      @provider.current_resource.version.should be_nil
+      expect(@provider.current_resource.version).to be_nil
     end
   end
 
   describe "candidate_version" do
     it "should return the candidate_version variable if already setup" do
       @provider.candidate_version = "3.3.12.0"
-      @provider.should_not_receive(:popen4)
+      expect(@provider).not_to receive(:shell_out )
       @provider.candidate_version
     end
 
     it "should lookup the candidate_version if the variable is not already set" do
-      @status = double("Status", :exitstatus => 0)
-      @provider.should_receive(:popen4).and_return(@status)
+      status = double(:stdout => "", :exitstatus => 0)
+      expect(@provider).to receive(:shell_out).and_return(status)
       @provider.candidate_version
     end
 
     it "should throw and exception if the exitstatus is not 0" do
-      @status = double("Status", :exitstatus => 1)
-      @provider.stub(:popen4).and_return(@status)
-      lambda { @provider.candidate_version }.should raise_error(Chef::Exceptions::Package)
+      @status = double(:stdout => "", :exitstatus => 1, :format_for_exception => "")
+      allow(@provider).to receive(:shell_out).and_return(@status)
+      expect { @provider.candidate_version }.to raise_error(Chef::Exceptions::Package)
     end
 
   end
 
   describe "install and upgrade" do
     it "should run installp -aYF -d with the package source to install" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "installp -aYF -d /tmp/samba.base samba.base"
-      })
+      expect(@provider).to receive(:shell_out!).with("installp -aYF -d /tmp/samba.base samba.base")
       @provider.install_package("samba.base", "3.3.12.0")
     end
 
     it "should run  when the package is a path to install" do
       @new_resource = Chef::Resource::Package.new("/tmp/samba.base")
       @provider = Chef::Provider::Package::Aix.new(@new_resource, @run_context)
-      @new_resource.source.should == "/tmp/samba.base"
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "installp -aYF -d /tmp/samba.base /tmp/samba.base"
-      })
+      expect(@new_resource.source).to eq("/tmp/samba.base")
+      expect(@provider).to receive(:shell_out!).with("installp -aYF -d /tmp/samba.base /tmp/samba.base")
       @provider.install_package("/tmp/samba.base", "3.3.12.0")
     end
 
     it "should run installp with -eLogfile option." do
-      @new_resource.stub(:options).and_return("-e/tmp/installp.log")
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "installp -aYF  -e/tmp/installp.log -d /tmp/samba.base samba.base"
-      })
+      allow(@new_resource).to receive(:options).and_return("-e/tmp/installp.log")
+      expect(@provider).to receive(:shell_out!).with("installp -aYF  -e/tmp/installp.log -d /tmp/samba.base samba.base")
       @provider.install_package("samba.base", "3.3.12.0")
     end
   end
 
   describe "remove" do
     it "should run installp -u samba.base to remove the package" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "installp -u samba.base"
-      })
+      expect(@provider).to receive(:shell_out!).with("installp -u samba.base")
       @provider.remove_package("samba.base", "3.3.12.0")
     end
 
     it "should run installp -u -e/tmp/installp.log  with options -e/tmp/installp.log" do
-      @new_resource.stub(:options).and_return("-e/tmp/installp.log")
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "installp -u  -e/tmp/installp.log samba.base"
-      })
+      allow(@new_resource).to receive(:options).and_return("-e/tmp/installp.log")
+      expect(@provider).to receive(:shell_out!).with("installp -u  -e/tmp/installp.log samba.base")
       @provider.remove_package("samba.base", "3.3.12.0")
     end
 
   end
 end
-
