@@ -28,37 +28,34 @@ describe Chef::Provider::Package::Dpkg do
 
     @provider = Chef::Provider::Package::Dpkg.new(@new_resource, @run_context)
 
-    @stdin = StringIO.new
-    @stdout = StringIO.new
-    @status = double("Status", :exitstatus => 0)
-    @stderr = StringIO.new
-    @pid = double("PID")
-    @provider.stub(:popen4).and_return(@status)
+    @status = double(:stdout => "", :exitstatus => 0)
+    allow(@provider).to receive(:shell_out).and_return(@status)
 
-    ::File.stub(:exists?).and_return(true)
+    allow(::File).to receive(:exists?).and_return(true)
   end
 
   describe "when loading the current resource state" do
 
     it "should create a current resource with the name of the new_resource" do
       @provider.load_current_resource
-      @provider.current_resource.package_name.should == "wget"
+      expect(@provider.current_resource.package_name).to eq("wget")
     end
 
     it "should raise an exception if a source is supplied but not found" do
       @provider.load_current_resource
       @provider.define_resource_requirements
-      ::File.stub(:exists?).and_return(false)
-      lambda { @provider.run_action(:install) }.should raise_error(Chef::Exceptions::Package)
+      allow(::File).to receive(:exists?).and_return(false)
+      expect { @provider.run_action(:install) }.to raise_error(Chef::Exceptions::Package)
     end
 
     describe 'gets the source package version from dpkg-deb' do
       def check_version(version)
-        @stdout = StringIO.new("wget\t#{version}")
-        @provider.stub(:popen4).with("dpkg-deb -W #{@new_resource.source}").and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+        @status = double(:stdout => "wget\t#{version}", :exitstatus => 0)
+        allow(@provider).to receive(:shell_out).with("dpkg-deb -W #{@new_resource.source}").and_return(@status)
         @provider.load_current_resource
-        @provider.current_resource.package_name.should == "wget"
-        @new_resource.version.should == version
+        expect(@provider.current_resource.package_name).to eq("wget")
+        expect(@new_resource.version).to eq(version)
+        expect(@provider.candidate_version).to eq(version)
       end
 
       it 'if short version provided' do
@@ -79,22 +76,23 @@ describe Chef::Provider::Package::Dpkg do
     end
 
     it "gets the source package name from dpkg-deb correctly when the package name has `-', `+' or `.' characters" do
-      @stdout = StringIO.new("f.o.o-pkg++2\t1.11.4-1ubuntu1")
-      @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+      stdout = "f.o.o-pkg++2\t1.11.4-1ubuntu1"
+      status = double(:stdout => stdout, :exitstatus => 1)
+      allow(@provider).to receive(:shell_out).and_return(status)
       @provider.load_current_resource
-      @provider.current_resource.package_name.should == "f.o.o-pkg++2"
+      expect(@provider.current_resource.package_name).to eq("f.o.o-pkg++2")
     end
 
     it "should raise an exception if the source is not set but we are installing" do
       @new_resource = Chef::Resource::Package.new("wget")
       @provider.new_resource = @new_resource
-      @provider.define_resource_requirements
       @provider.load_current_resource
-      lambda { @provider.run_action(:install)}.should raise_error(Chef::Exceptions::Package)
+      @provider.define_resource_requirements
+      expect { @provider.run_action(:install)}.to raise_error(Chef::Exceptions::Package)
     end
 
     it "should return the current version installed if found by dpkg" do
-      @stdout = StringIO.new(<<-DPKG_S)
+      stdout = <<-DPKG_S
 Package: wget
 Status: install ok installed
 Priority: important
@@ -107,112 +105,89 @@ Config-Version: 1.11.4-1ubuntu1
 Depends: libc6 (>= 2.8~20080505), libssl0.9.8 (>= 0.9.8f-5)
 Conflicts: wget-ssl
 DPKG_S
-      @provider.stub(:popen4).with("dpkg -s wget").and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+      status = double(:stdout => stdout, :exitstatus => 1)
+      allow(@provider).to receive(:shell_out).with("dpkg -s wget").and_return(status)
 
       @provider.load_current_resource
-      @provider.current_resource.version.should == "1.11.4-1ubuntu1"
+      expect(@provider.current_resource.version).to eq("1.11.4-1ubuntu1")
     end
 
     it "should raise an exception if dpkg fails to run" do
-      @status = double("Status", :exitstatus => -1)
-      @provider.stub(:popen4).and_return(@status)
-      lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Package)
+      status = double(:stdout => "", :exitstatus => -1)
+      allow(@provider).to receive(:shell_out).and_return(status)
+      expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Package)
     end
   end
 
   describe Chef::Provider::Package::Dpkg, "install and upgrade" do
     it "should run dpkg -i with the package source" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -i /tmp/wget_1.11.4-1ubuntu1_amd64.deb",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -i /tmp/wget_1.11.4-1ubuntu1_amd64.deb"
+      )
       @provider.install_package("wget", "1.11.4-1ubuntu1")
     end
 
     it "should run dpkg -i if the package is a path and the source is nil" do
       @new_resource = Chef::Resource::Package.new("/tmp/wget_1.11.4-1ubuntu1_amd64.deb")
       @provider = Chef::Provider::Package::Dpkg.new(@new_resource, @run_context)
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -i /tmp/wget_1.11.4-1ubuntu1_amd64.deb",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -i /tmp/wget_1.11.4-1ubuntu1_amd64.deb"
+      )
       @provider.install_package("/tmp/wget_1.11.4-1ubuntu1_amd64.deb", "1.11.4-1ubuntu1")
     end
 
     it "should run dpkg -i if the package is a path and the source is nil for an upgrade" do
       @new_resource = Chef::Resource::Package.new("/tmp/wget_1.11.4-1ubuntu1_amd64.deb")
       @provider = Chef::Provider::Package::Dpkg.new(@new_resource, @run_context)
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -i /tmp/wget_1.11.4-1ubuntu1_amd64.deb",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -i /tmp/wget_1.11.4-1ubuntu1_amd64.deb"
+      )
       @provider.upgrade_package("/tmp/wget_1.11.4-1ubuntu1_amd64.deb", "1.11.4-1ubuntu1")
     end
 
     it "should run dpkg -i with the package source and options if specified" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -i --force-yes /tmp/wget_1.11.4-1ubuntu1_amd64.deb",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
-      @new_resource.stub(:options).and_return("--force-yes")
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -i --force-yes /tmp/wget_1.11.4-1ubuntu1_amd64.deb"
+      )
+      allow(@new_resource).to receive(:options).and_return("--force-yes")
 
       @provider.install_package("wget", "1.11.4-1ubuntu1")
     end
     it "should upgrade by running install_package" do
-      @provider.should_receive(:install_package).with("wget", "1.11.4-1ubuntu1")
+      expect(@provider).to receive(:install_package).with("wget", "1.11.4-1ubuntu1")
       @provider.upgrade_package("wget", "1.11.4-1ubuntu1")
     end
   end
 
   describe Chef::Provider::Package::Dpkg, "remove and purge" do
     it "should run dpkg -r to remove the package" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -r wget",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -r wget"
+      )
       @provider.remove_package("wget", "1.11.4-1ubuntu1")
     end
 
     it "should run dpkg -r to remove the package with options if specified" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -r --force-yes wget",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
-      @new_resource.stub(:options).and_return("--force-yes")
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -r --force-yes wget"
+      )
+      allow(@new_resource).to receive(:options).and_return("--force-yes")
 
       @provider.remove_package("wget", "1.11.4-1ubuntu1")
     end
 
     it "should run dpkg -P to purge the package" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -P wget",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -P wget"
+      )
       @provider.purge_package("wget", "1.11.4-1ubuntu1")
     end
 
     it "should run dpkg -P to purge the package with options if specified" do
-      @provider.should_receive(:run_command_with_systems_locale).with({
-        :command => "dpkg -P --force-yes wget",
-        :environment => {
-          "DEBIAN_FRONTEND" => "noninteractive"
-        }
-      })
-      @new_resource.stub(:options).and_return("--force-yes")
+      expect(@provider).to receive(:run_noninteractive).with(
+        "dpkg -P --force-yes wget"
+      )
+      allow(@new_resource).to receive(:options).and_return("--force-yes")
 
       @provider.purge_package("wget", "1.11.4-1ubuntu1")
     end
