@@ -27,73 +27,73 @@ describe Chef::Provider::Package::Portage, "load_current_resource" do
     @current_resource = Chef::Resource::Package.new("dev-util/git")
 
     @provider = Chef::Provider::Package::Portage.new(@new_resource, @run_context)
-    Chef::Resource::Package.stub(:new).and_return(@current_resource)
+    allow(Chef::Resource::Package).to receive(:new).and_return(@current_resource)
   end
 
   describe "when determining the current state of the package" do
 
     it "should create a current resource with the name of new_resource" do
-      ::Dir.stub(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0"])
-      Chef::Resource::Package.should_receive(:new).and_return(@current_resource)
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0"])
+      expect(Chef::Resource::Package).to receive(:new).and_return(@current_resource)
       @provider.load_current_resource
     end
 
     it "should set the current resource package name to the new resource package name" do
-      ::Dir.stub(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0"])
-      @current_resource.should_receive(:package_name).with(@new_resource.package_name)
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0"])
+      expect(@current_resource).to receive(:package_name).with(@new_resource.package_name)
       @provider.load_current_resource
     end
 
     it "should return a current resource with the correct version if the package is found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-foobar-0.9", "/var/db/pkg/dev-util/git-1.0.0"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-foobar-0.9", "/var/db/pkg/dev-util/git-1.0.0"])
       @provider.load_current_resource
-      @provider.current_resource.version.should == "1.0.0"
+      expect(@provider.current_resource.version).to eq("1.0.0")
     end
 
     it "should return a current resource with the correct version if the package is found with revision" do
-      ::Dir.stub(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0-r1"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0-r1"])
       @provider.load_current_resource
-      @provider.current_resource.version.should == "1.0.0-r1"
+      expect(@provider.current_resource.version).to eq("1.0.0-r1")
     end
 
     it "should return a current resource with a nil version if the package is not found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/notgit-1.0.0"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/notgit-1.0.0"])
       @provider.load_current_resource
-      @provider.current_resource.version.should be_nil
+      expect(@provider.current_resource.version).to be_nil
     end
 
     it "should return a package name match from /var/db/pkg/* if a category isn't specified and a match is found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/git-foobar-0.9", "/var/db/pkg/dev-util/git-1.0.0"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/git-foobar-0.9", "/var/db/pkg/dev-util/git-1.0.0"])
       @provider = Chef::Provider::Package::Portage.new(@new_resource_without_category, @run_context)
       @provider.load_current_resource
-      @provider.current_resource.version.should == "1.0.0"
+      expect(@provider.current_resource.version).to eq("1.0.0")
     end
 
     it "should return a current resource with a nil version if a category isn't specified and a name match from /var/db/pkg/* is not found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/notgit-1.0.0"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/notgit-1.0.0"])
       @provider = Chef::Provider::Package::Portage.new(@new_resource_without_category, @run_context)
       @provider.load_current_resource
-      @provider.current_resource.version.should be_nil
+      expect(@provider.current_resource.version).to be_nil
     end
 
     it "should throw an exception if a category isn't specified and multiple packages are found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0", "/var/db/pkg/funny-words/git-1.0.0"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0", "/var/db/pkg/funny-words/git-1.0.0"])
       @provider = Chef::Provider::Package::Portage.new(@new_resource_without_category, @run_context)
-      lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Package)
+      expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Package)
     end
 
     it "should return a current resource with a nil version if a category is specified and multiple packages are found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0", "/var/db/pkg/funny-words/git-1.0.0"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/dev-util/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0", "/var/db/pkg/funny-words/git-1.0.0"])
       @provider = Chef::Provider::Package::Portage.new(@new_resource, @run_context)
       @provider.load_current_resource
-      @provider.current_resource.version.should be_nil
+      expect(@provider.current_resource.version).to be_nil
     end
 
     it "should return a current resource with a nil version if a category is not specified and multiple packages from the same category are found" do
-      ::Dir.stub(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0", "/var/db/pkg/dev-util/git-1.0.1"])
+      allow(::Dir).to receive(:[]).with("/var/db/pkg/*/git-*").and_return(["/var/db/pkg/dev-util/git-1.0.0", "/var/db/pkg/dev-util/git-1.0.1"])
       @provider = Chef::Provider::Package::Portage.new(@new_resource_without_category, @run_context)
       @provider.load_current_resource
-      @provider.current_resource.version.should be_nil
+      expect(@provider.current_resource.version).to be_nil
     end
   end
 
@@ -102,14 +102,14 @@ describe Chef::Provider::Package::Portage, "load_current_resource" do
     describe Chef::Provider::Package::Portage, "candidate_version" do
       it "should return the candidate_version variable if already set" do
         @provider.candidate_version = "1.0.0"
-        @provider.should_not_receive(:popen4)
+        expect(@provider).not_to receive(:shell_out)
         @provider.candidate_version
       end
 
       it "should throw an exception if the exitstatus is not 0" do
-        @status = double("Status", :exitstatus => 1)
-        @provider.stub(:popen4).and_return(@status)
-        lambda { @provider.candidate_version }.should raise_error(Chef::Exceptions::Package)
+        status = double(:stdout => "", :exitstatus => 1)
+        allow(@provider).to receive(:shell_out).and_return(status)
+        expect { @provider.candidate_version }.to raise_error(Chef::Exceptions::Package)
       end
 
       it "should find the candidate_version if a category is specifed and there are no duplicates" do
@@ -143,9 +143,9 @@ Searching...
       License:       GPL-2
 EOF
 
-        @status = double("Status", :exitstatus => 0)
-        @provider.should_receive(:popen4).and_yield(nil, nil, StringIO.new(output), nil).and_return(@status)
-        @provider.candidate_version.should == "1.6.0.6"
+        status = double(:stdout => output, :exitstatus => 0)
+        expect(@provider).to receive(:shell_out).and_return(status)
+        expect(@provider.candidate_version).to eq("1.6.0.6")
       end
 
       it "should find the candidate_version if a category is not specifed and there are no duplicates" do
@@ -179,10 +179,10 @@ Searching...
       License:       GPL-2
 EOF
 
-        @status = double("Status", :exitstatus => 0)
+        status = double(:stdout => output, :exitstatus => 0)
         @provider = Chef::Provider::Package::Portage.new(@new_resource_without_category, @run_context)
-        @provider.should_receive(:popen4).and_yield(nil, nil, StringIO.new(output), nil).and_return(@status)
-        @provider.candidate_version.should == "1.6.0.6"
+        expect(@provider).to receive(:shell_out).and_return(status)
+        expect(@provider.candidate_version).to eq("1.6.0.6")
       end
 
       it "should throw an exception if a category is not specified and there are duplicates" do
@@ -224,10 +224,10 @@ Searching...
       License:       GPL-2
 EOF
 
-        @status = double("Status", :exitstatus => 0)
+        status = double(:stdout => output, :exitstatus => 0)
         @provider = Chef::Provider::Package::Portage.new(@new_resource_without_category, @run_context)
-        @provider.should_receive(:popen4).and_yield(nil, nil, StringIO.new(output), nil).and_return(@status)
-        lambda { @provider.candidate_version }.should raise_error(Chef::Exceptions::Package)
+        expect(@provider).to receive(:shell_out).and_return(status)
+        expect { @provider.candidate_version }.to raise_error(Chef::Exceptions::Package)
       end
 
       it "should find the candidate_version if a category is specifed and there are category duplicates" do
@@ -269,33 +269,27 @@ Searching...
       License:       GPL-2
 EOF
 
-        @status = double("Status", :exitstatus => 0)
+        status = double(:stdout => output, :exitstatus => 0)
         @provider = Chef::Provider::Package::Portage.new(@new_resource, @run_context)
-        @provider.should_receive(:popen4).and_yield(nil, nil, StringIO.new(output), nil).and_return(@status)
-        @provider.candidate_version.should == "1.6.0.6"
+        expect(@provider).to receive(:shell_out).and_return(status)
+        expect(@provider.candidate_version).to eq("1.6.0.6")
       end
     end
 
     describe Chef::Provider::Package::Portage, "install_package" do
       it "should install a normally versioned package using portage" do
-        @provider.should_receive(:run_command_with_systems_locale).with({
-          :command => "emerge -g --color n --nospinner --quiet =dev-util/git-1.0.0"
-        })
+        expect(@provider).to receive(:shell_out!).with("emerge -g --color n --nospinner --quiet =dev-util/git-1.0.0")
         @provider.install_package("dev-util/git", "1.0.0")
       end
 
       it "should install a tilde versioned package using portage" do
-        @provider.should_receive(:run_command_with_systems_locale).with({
-          :command => "emerge -g --color n --nospinner --quiet ~dev-util/git-1.0.0"
-        })
+        expect(@provider).to receive(:shell_out!).with("emerge -g --color n --nospinner --quiet ~dev-util/git-1.0.0")
         @provider.install_package("dev-util/git", "~1.0.0")
       end
 
       it "should add options to the emerge command when specified" do
-        @provider.should_receive(:run_command_with_systems_locale).with({
-          :command => "emerge -g --color n --nospinner --quiet --oneshot =dev-util/git-1.0.0"
-        })
-        @new_resource.stub(:options).and_return("--oneshot")
+        expect(@provider).to receive(:shell_out!).with("emerge -g --color n --nospinner --quiet --oneshot =dev-util/git-1.0.0")
+        allow(@new_resource).to receive(:options).and_return("--oneshot")
 
         @provider.install_package("dev-util/git", "1.0.0")
       end
@@ -303,16 +297,12 @@ EOF
 
     describe Chef::Provider::Package::Portage, "remove_package" do
       it "should un-emerge the package with no version specified" do
-        @provider.should_receive(:run_command_with_systems_locale).with({
-          :command => "emerge --unmerge --color n --nospinner --quiet dev-util/git"
-        })
+        expect(@provider).to receive(:shell_out!).with("emerge --unmerge --color n --nospinner --quiet dev-util/git")
         @provider.remove_package("dev-util/git", nil)
       end
 
       it "should un-emerge the package with a version specified" do
-        @provider.should_receive(:run_command_with_systems_locale).with({
-          :command => "emerge --unmerge --color n --nospinner --quiet =dev-util/git-1.0.0"
-        })
+        expect(@provider).to receive(:shell_out!).with("emerge --unmerge --color n --nospinner --quiet =dev-util/git-1.0.0")
         @provider.remove_package("dev-util/git", "1.0.0")
       end
     end
