@@ -31,7 +31,7 @@ describe Chef::Provider::Package::SmartOS, "load_current_resource" do
 
 	  @status = double("Status", :exitstatus => 0)
 		@provider = Chef::Provider::Package::SmartOS.new(@new_resource, @run_context)
-		Chef::Resource::Package.stub(:new).and_return(@current_resource)
+		allow(Chef::Resource::Package).to receive(:new).and_return(@current_resource)
 		@stdin = StringIO.new
 		@stdout = "varnish-2.1.5nb2\n"
 		@stderr = StringIO.new
@@ -42,28 +42,28 @@ describe Chef::Provider::Package::SmartOS, "load_current_resource" do
 	describe "when loading current resource" do
 
     it "should create a current resource with the name of the new_resource" do
-			@provider.should_receive(:shell_out!).and_return(@shell_out)
-			Chef::Resource::Package.should_receive(:new).and_return(@current_resource)
+			expect(@provider).to receive(:shell_out!).and_return(@shell_out)
+			expect(Chef::Resource::Package).to receive(:new).and_return(@current_resource)
 			@provider.load_current_resource
     end
 
 		it "should set the current resource package name" do
-			@provider.should_receive(:shell_out!).and_return(@shell_out)
-			@current_resource.should_receive(:package_name).with(@new_resource.package_name)
+			expect(@provider).to receive(:shell_out!).and_return(@shell_out)
+			expect(@current_resource).to receive(:package_name).with(@new_resource.package_name)
 			@provider.load_current_resource
 		end
 
 		it "should set the installed version if it is installed" do
-		  @provider.should_receive(:shell_out!).and_return(@shell_out)
+		  expect(@provider).to receive(:shell_out!).and_return(@shell_out)
 			@provider.load_current_resource
-			@current_resource.version.should == "2.1.5nb2"
+			expect(@current_resource.version).to eq("2.1.5nb2")
 	  end
 
 		it "should set the installed version to nil if it's not installed" do
 			out = OpenStruct.new(:stdout => nil)
-			@provider.should_receive(:shell_out!).and_return(out)
+			expect(@provider).to receive(:shell_out!).and_return(out)
 			@provider.load_current_resource
-			@current_resource.version.should == nil
+			expect(@current_resource.version).to eq(nil)
 		end
 
 
@@ -72,18 +72,18 @@ describe Chef::Provider::Package::SmartOS, "load_current_resource" do
   describe "candidate_version" do
     it "should return the candidate_version variable if already setup" do
       @provider.candidate_version = "2.1.1"
-      @provider.should_not_receive(:shell_out!)
+      expect(@provider).not_to receive(:shell_out!)
       @provider.candidate_version
     end
 
     it "should lookup the candidate_version if the variable is not already set" do
       search = double()
-      search.should_receive(:each_line).
+      expect(search).to receive(:each_line).
         and_yield("something-varnish-1.1.1  something varnish like\n").
         and_yield("varnish-2.3.4 actual varnish\n")
       @shell_out = double('shell_out!', :stdout => search)
-      @provider.should_receive(:shell_out!).with('/opt/local/bin/pkgin se varnish', :env => nil, :returns => [0,1]).and_return(@shell_out)
-      @provider.candidate_version.should == "2.3.4"
+      expect(@provider).to receive(:shell_out!).with('/opt/local/bin/pkgin se varnish', :env => nil, :returns => [0,1]).and_return(@shell_out)
+      expect(@provider.candidate_version).to eq("2.3.4")
     end
   end
 
@@ -91,8 +91,8 @@ describe Chef::Provider::Package::SmartOS, "load_current_resource" do
 
 		it "run pkgin and install the package" do
 			out = OpenStruct.new(:stdout => nil)
-      @provider.should_receive(:shell_out!).with("/opt/local/sbin/pkg_info -E \"varnish*\"", {:env => nil, :returns=>[0,1]}).and_return(@shell_out)
-      @provider.should_receive(:shell_out!).with("/opt/local/bin/pkgin -y install varnish-2.1.5nb2", {:env=>nil}).and_return(out)
+      expect(@provider).to receive(:shell_out!).with("/opt/local/sbin/pkg_info -E \"varnish*\"", {:env => nil, :returns=>[0,1]}).and_return(@shell_out)
+      expect(@provider).to receive(:shell_out!).with("/opt/local/bin/pkgin -y install varnish-2.1.5nb2", {:env=>nil}).and_return(out)
       @provider.load_current_resource
       @provider.install_package("varnish", "2.1.5nb2")
 		end
