@@ -20,7 +20,6 @@
 require 'spec_helper'
 require 'ostruct'
 
-
 # most of this code has been ripped from init_service_spec.rb
 # and is only slightly modified to match "arch" needs.
 
@@ -36,60 +35,57 @@ describe Chef::Provider::Service::Arch, "load_current_resource" do
     @new_resource.pattern("chef")
     @new_resource.supports({:status => false})
 
-
     @provider = Chef::Provider::Service::Arch.new(@new_resource, @run_context)
 
-    ::File.stub(:exists?).with("/etc/rc.conf").and_return(true)
-    ::File.stub(:read).with("/etc/rc.conf").and_return("DAEMONS=(network apache sshd)")
+    allow(::File).to receive(:exists?).with("/etc/rc.conf").and_return(true)
+    allow(::File).to receive(:read).with("/etc/rc.conf").and_return("DAEMONS=(network apache sshd)")
   end
 
   describe "when first created" do
     it "should set the current resources service name to the new resources service name" do
-      @provider.stub(:shell_out).and_return(OpenStruct.new(:exitstatus => 0, :stdout => ""))
+      allow(@provider).to receive(:shell_out).and_return(OpenStruct.new(:exitstatus => 0, :stdout => ""))
       @provider.load_current_resource
-      @provider.current_resource.service_name.should == 'chef'
+      expect(@provider.current_resource.service_name).to eq('chef')
     end
   end
 
-
   describe "when the service supports status" do
     before do
       @new_resource.supports({:status => true})
     end
 
     it "should run '/etc/rc.d/service_name status'" do
-      @provider.should_receive(:shell_out).with("/etc/rc.d/chef status").and_return(OpenStruct.new(:exitstatus => 0))
+      expect(@provider).to receive(:shell_out).with("/etc/rc.d/chef status").and_return(OpenStruct.new(:exitstatus => 0))
       @provider.load_current_resource
     end
 
     it "should set running to true if the status command returns 0" do
-      @provider.stub(:shell_out).with("/etc/rc.d/chef status").and_return(OpenStruct.new(:exitstatus => 0))
+      allow(@provider).to receive(:shell_out).with("/etc/rc.d/chef status").and_return(OpenStruct.new(:exitstatus => 0))
       @provider.load_current_resource
-      @provider.current_resource.running.should be_true
+      expect(@provider.current_resource.running).to be_truthy
     end
 
     it "should set running to false if the status command returns anything except 0" do
-      @provider.stub(:shell_out).with("/etc/rc.d/chef status").and_return(OpenStruct.new(:exitstatus => 1))
+      allow(@provider).to receive(:shell_out).with("/etc/rc.d/chef status").and_return(OpenStruct.new(:exitstatus => 1))
       @provider.load_current_resource
-      @provider.current_resource.running.should be_false
+      expect(@provider.current_resource.running).to be_falsey
     end
 
     it "should set running to false if the status command raises" do
-      @provider.stub(:shell_out).with("/etc/rc.d/chef status").and_raise(Mixlib::ShellOut::ShellCommandFailed)
+      allow(@provider).to receive(:shell_out).with("/etc/rc.d/chef status").and_raise(Mixlib::ShellOut::ShellCommandFailed)
       @provider.load_current_resource
-      @provider.current_resource.running.should be_false
+      expect(@provider.current_resource.running).to be_falsey
     end
 
   end
 
-
   describe "when a status command has been specified" do
     before do
       @new_resource.status_command("/etc/rc.d/chefhasmonkeypants status")
     end
 
     it "should run the services status command if one has been specified" do
-      @provider.should_receive(:shell_out).with("/etc/rc.d/chefhasmonkeypants status").and_return(OpenStruct.new(:exitstatus => 0))
+      expect(@provider).to receive(:shell_out).with("/etc/rc.d/chefhasmonkeypants status").and_return(OpenStruct.new(:exitstatus => 0))
       @provider.load_current_resource
     end
 
@@ -99,25 +95,24 @@ describe Chef::Provider::Service::Arch, "load_current_resource" do
     @node.automatic_attrs[:command] = {:ps => nil}
     @provider.define_resource_requirements
     @provider.action = :start
-    lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+    expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
   end
 
   it "should raise error if the node has an empty ps attribute and no other means to get status" do
     @node.automatic_attrs[:command] = {:ps => ""}
     @provider.define_resource_requirements
     @provider.action = :start
-    lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+    expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
   end
 
-
   it "should fail if file /etc/rc.conf does not exist" do
-    ::File.stub(:exists?).with("/etc/rc.conf").and_return(false)
-    lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Service)
+    allow(::File).to receive(:exists?).with("/etc/rc.conf").and_return(false)
+    expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Service)
   end
 
   it "should fail if file /etc/rc.conf does not contain DAEMONS array" do
-    ::File.stub(:read).with("/etc/rc.conf").and_return("")
-    lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::Service)
+    allow(::File).to receive(:read).with("/etc/rc.conf").and_return("")
+    expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::Service)
   end
 
   describe "when discovering service status with ps" do
@@ -128,7 +123,7 @@ aj        7903  5016  0 21:26 pts/5    00:00:00 /bin/bash
 aj        8119  6041  0 21:34 pts/3    00:00:03 vi init_service_spec.rb
 DEFAULT_PS
       @status = double("Status", :exitstatus => 0, :stdout => @stdout)
-      @provider.stub(:shell_out!).and_return(@status)
+      allow(@provider).to receive(:shell_out!).and_return(@status)
 
       @node.automatic_attrs[:command] = {:ps => "ps -ef"}
     end
@@ -138,29 +133,29 @@ DEFAULT_PS
 aj        7842  5057  0 21:26 pts/2    00:00:06 chef
 aj        7842  5057  0 21:26 pts/2    00:00:06 poos
 RUNNING_PS
-      @status.stub(:stdout).and_return(@stdout)
+      allow(@status).to receive(:stdout).and_return(@stdout)
       @provider.load_current_resource
-      @provider.current_resource.running.should be_true
+      expect(@provider.current_resource.running).to be_truthy
     end
 
     it "determines the service is not running when it does not appear in ps" do
-      @provider.stub(:shell_out!).and_return(@status)
+      allow(@provider).to receive(:shell_out!).and_return(@status)
       @provider.load_current_resource
-      @provider.current_resource.running.should be_false
+      expect(@provider.current_resource.running).to be_falsey
     end
 
     it "should raise an exception if ps fails" do
-      @provider.stub(:shell_out!).and_raise(Mixlib::ShellOut::ShellCommandFailed)
+      allow(@provider).to receive(:shell_out!).and_raise(Mixlib::ShellOut::ShellCommandFailed)
       @provider.load_current_resource
       @provider.action = :start
       @provider.define_resource_requirements
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
     end
   end
 
   it "should return existing entries in DAEMONS array" do
-    ::File.stub(:read).with("/etc/rc.conf").and_return("DAEMONS=(network !apache ssh)")
-    @provider.daemons.should == ['network', '!apache', 'ssh']
+    allow(::File).to receive(:read).with("/etc/rc.conf").and_return("DAEMONS=(network !apache ssh)")
+    expect(@provider.daemons).to eq(['network', '!apache', 'ssh'])
   end
 
   context "when the current service status is known" do
@@ -184,8 +179,8 @@ RUNNING_PS
       # end
 
       it "should add chef to DAEMONS array" do
-        ::File.stub(:read).with("/etc/rc.conf").and_return("DAEMONS=(network)")
-        @provider.should_receive(:update_daemons).with(['network', 'chef'])
+        allow(::File).to receive(:read).with("/etc/rc.conf").and_return("DAEMONS=(network)")
+        expect(@provider).to receive(:update_daemons).with(['network', 'chef'])
         @provider.enable_service()
       end
     end
@@ -205,13 +200,12 @@ RUNNING_PS
       # end
 
       it "should remove chef from DAEMONS array" do
-        ::File.stub(:read).with("/etc/rc.conf").and_return("DAEMONS=(network chef)")
-        @provider.should_receive(:update_daemons).with(['network', '!chef'])
+        allow(::File).to receive(:read).with("/etc/rc.conf").and_return("DAEMONS=(network chef)")
+        expect(@provider).to receive(:update_daemons).with(['network', '!chef'])
         @provider.disable_service()
       end
     end
 
-
     describe Chef::Provider::Service::Arch, "start_service" do
       # before(:each) do
       #   @new_resource = double("Chef::Resource::Service",
@@ -227,13 +221,13 @@ RUNNING_PS
       # end
 
       it "should call the start command if one is specified" do
-        @new_resource.stub(:start_command).and_return("/etc/rc.d/chef startyousillysally")
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/chef startyousillysally")
+        allow(@new_resource).to receive(:start_command).and_return("/etc/rc.d/chef startyousillysally")
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/chef startyousillysally")
         @provider.start_service()
       end
 
       it "should call '/etc/rc.d/service_name start' if no start command is specified" do
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/#{@new_resource.service_name} start")
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/#{@new_resource.service_name} start")
         @provider.start_service()
       end
     end
@@ -253,13 +247,13 @@ RUNNING_PS
       # end
 
       it "should call the stop command if one is specified" do
-        @new_resource.stub(:stop_command).and_return("/etc/rc.d/chef itoldyoutostop")
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/chef itoldyoutostop")
+        allow(@new_resource).to receive(:stop_command).and_return("/etc/rc.d/chef itoldyoutostop")
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/chef itoldyoutostop")
         @provider.stop_service()
       end
 
       it "should call '/etc/rc.d/service_name stop' if no stop command is specified" do
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/#{@new_resource.service_name} stop")
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/#{@new_resource.service_name} stop")
         @provider.stop_service()
       end
     end
@@ -280,21 +274,21 @@ RUNNING_PS
       # end
 
       it "should call 'restart' on the service_name if the resource supports it" do
-        @new_resource.stub(:supports).and_return({:restart => true})
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/#{@new_resource.service_name} restart")
+        allow(@new_resource).to receive(:supports).and_return({:restart => true})
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/#{@new_resource.service_name} restart")
         @provider.restart_service()
       end
 
       it "should call the restart_command if one has been specified" do
-        @new_resource.stub(:restart_command).and_return("/etc/rc.d/chef restartinafire")
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/#{@new_resource.service_name} restartinafire")
+        allow(@new_resource).to receive(:restart_command).and_return("/etc/rc.d/chef restartinafire")
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/#{@new_resource.service_name} restartinafire")
         @provider.restart_service()
       end
 
       it "should just call stop, then start when the resource doesn't support restart and no restart_command is specified" do
-        @provider.should_receive(:stop_service)
-        @provider.should_receive(:sleep).with(1)
-        @provider.should_receive(:start_service)
+        expect(@provider).to receive(:stop_service)
+        expect(@provider).to receive(:sleep).with(1)
+        expect(@provider).to receive(:start_service)
         @provider.restart_service()
       end
     end
@@ -315,14 +309,14 @@ RUNNING_PS
       # end
 
       it "should call 'reload' on the service if it supports it" do
-        @new_resource.stub(:supports).and_return({:reload => true})
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/#{@new_resource.service_name} reload")
+        allow(@new_resource).to receive(:supports).and_return({:reload => true})
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/#{@new_resource.service_name} reload")
         @provider.reload_service()
       end
 
       it "should should run the user specified reload command if one is specified and the service doesn't support reload" do
-        @new_resource.stub(:reload_command).and_return("/etc/rc.d/chef lollerpants")
-        @provider.should_receive(:shell_out!).with("/etc/rc.d/#{@new_resource.service_name} lollerpants")
+        allow(@new_resource).to receive(:reload_command).and_return("/etc/rc.d/chef lollerpants")
+        expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/rc.d/#{@new_resource.service_name} lollerpants")
         @provider.reload_service()
       end
     end
