@@ -29,72 +29,72 @@ describe Chef::Provider::Service::Gentoo do
     @current_resource = Chef::Resource::Service.new("chef")
 
     @provider = Chef::Provider::Service::Gentoo.new(@new_resource, @run_context)
-    Chef::Resource::Service.stub(:new).and_return(@current_resource)
+    allow(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
     @status = double("Status", :exitstatus => 0, :stdout => @stdout)
-    @provider.stub(:shell_out).and_return(@status)
-    File.stub(:exists?).with("/etc/init.d/chef").and_return(true)
-    File.stub(:exists?).with("/sbin/rc-update").and_return(true)
-    File.stub(:exists?).with("/etc/runlevels/default/chef").and_return(false)
-    File.stub(:readable?).with("/etc/runlevels/default/chef").and_return(false)
+    allow(@provider).to receive(:shell_out).and_return(@status)
+    allow(File).to receive(:exists?).with("/etc/init.d/chef").and_return(true)
+    allow(File).to receive(:exists?).with("/sbin/rc-update").and_return(true)
+    allow(File).to receive(:exists?).with("/etc/runlevels/default/chef").and_return(false)
+    allow(File).to receive(:readable?).with("/etc/runlevels/default/chef").and_return(false)
   end
  # new test: found_enabled state
   #
   describe "load_current_resource" do
     it "should raise Chef::Exceptions::Service if /sbin/rc-update does not exist" do
-      File.should_receive(:exists?).with("/sbin/rc-update").and_return(false)
+      expect(File).to receive(:exists?).with("/sbin/rc-update").and_return(false)
       @provider.define_resource_requirements
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
     end
 
     it "should track when service file is not found in /etc/runlevels" do
       @provider.load_current_resource
-      @provider.instance_variable_get("@found_script").should be_false
+      expect(@provider.instance_variable_get("@found_script")).to be_falsey
     end
 
     it "should track when service file is found in /etc/runlevels/**/" do
-      Dir.stub(:glob).with("/etc/runlevels/**/chef").and_return(["/etc/runlevels/default/chef"])
+      allow(Dir).to receive(:glob).with("/etc/runlevels/**/chef").and_return(["/etc/runlevels/default/chef"])
       @provider.load_current_resource
-      @provider.instance_variable_get("@found_script").should be_true
+      expect(@provider.instance_variable_get("@found_script")).to be_truthy
     end
 
     describe "when detecting the service enable state" do
       describe "and the glob returns a default service script file" do
         before do
-          Dir.stub(:glob).with("/etc/runlevels/**/chef").and_return(["/etc/runlevels/default/chef"])
+          allow(Dir).to receive(:glob).with("/etc/runlevels/**/chef").and_return(["/etc/runlevels/default/chef"])
         end
 
         describe "and the file exists and is readable" do
           before do
-            File.stub(:exists?).with("/etc/runlevels/default/chef").and_return(true)
-            File.stub(:readable?).with("/etc/runlevels/default/chef").and_return(true)
+            allow(File).to receive(:exists?).with("/etc/runlevels/default/chef").and_return(true)
+            allow(File).to receive(:readable?).with("/etc/runlevels/default/chef").and_return(true)
           end
           it "should set enabled to true" do
             @provider.load_current_resource
-            @current_resource.enabled.should be_true
+            expect(@current_resource.enabled).to be_truthy
           end
         end
 
         describe "and the file exists but is not readable" do
           before do
-            File.stub(:exists?).with("/etc/runlevels/default/chef").and_return(true)
-            File.stub(:readable?).with("/etc/runlevels/default/chef").and_return(false)
+            allow(File).to receive(:exists?).with("/etc/runlevels/default/chef").and_return(true)
+            allow(File).to receive(:readable?).with("/etc/runlevels/default/chef").and_return(false)
           end
 
           it "should set enabled to false" do
             @provider.load_current_resource
-            @current_resource.enabled.should be_false
+            expect(@current_resource.enabled).to be_falsey
           end
         end
 
         describe "and the file does not exist" do
           before do
-            File.stub(:exists?).with("/etc/runlevels/default/chef").and_return(false)
-            File.stub(:readable?).with("/etc/runlevels/default/chef").and_return("foobarbaz")
+            allow(File).to receive(:exists?).with("/etc/runlevels/default/chef").and_return(false)
+            allow(File).to receive(:readable?).with("/etc/runlevels/default/chef").and_return("foobarbaz")
           end
 
           it "should set enabled to false" do
             @provider.load_current_resource
-            @current_resource.enabled.should be_false
+            expect(@current_resource.enabled).to be_falsey
           end
 
         end
@@ -103,39 +103,39 @@ describe Chef::Provider::Service::Gentoo do
   end
 
     it "should return the current_resource" do
-      @provider.load_current_resource.should == @current_resource
+      expect(@provider.load_current_resource).to eq(@current_resource)
     end
 
     it "should support the status command automatically" do
       @provider.load_current_resource
-      @new_resource.supports[:status].should be_true
+      expect(@new_resource.supports[:status]).to be_truthy
     end
 
     it "should support the restart command automatically" do
       @provider.load_current_resource
-      @new_resource.supports[:restart].should be_true
+      expect(@new_resource.supports[:restart]).to be_truthy
     end
 
     it "should not support the reload command automatically" do
       @provider.load_current_resource
-      @new_resource.supports[:reload].should_not be_true
+      expect(@new_resource.supports[:reload]).not_to be_truthy
     end
 
   end
 
   describe "action_methods" do
-    before(:each) { @provider.stub(:load_current_resource).and_return(@current_resource) }
+    before(:each) { allow(@provider).to receive(:load_current_resource).and_return(@current_resource) }
 
     describe Chef::Provider::Service::Gentoo, "enable_service" do
       it "should call rc-update add *service* default" do
-        @provider.should_receive(:run_command).with({:command => "/sbin/rc-update add chef default"})
+        expect(@provider).to receive(:shell_out!).with("/sbin/rc-update add chef default")
         @provider.enable_service()
       end
     end
 
     describe Chef::Provider::Service::Gentoo, "disable_service" do
       it "should call rc-update del *service* default" do
-        @provider.should_receive(:run_command).with({:command => "/sbin/rc-update del chef default"})
+        expect(@provider).to receive(:shell_out!).with("/sbin/rc-update del chef default")
         @provider.disable_service()
       end
     end
