@@ -30,7 +30,7 @@ describe Chef::Provider::Service::Init, "load_current_resource" do
     @current_resource = Chef::Resource::Service.new("chef")
 
     @provider = Chef::Provider::Service::Init.new(@new_resource, @run_context)
-    Chef::Resource::Service.stub(:new).and_return(@current_resource)
+    allow(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
 
     @stdout = StringIO.new(<<-PS)
 aj        7842  5057  0 21:26 pts/2    00:00:06 vi init.rb
@@ -38,17 +38,17 @@ aj        7903  5016  0 21:26 pts/5    00:00:00 /bin/bash
 aj        8119  6041  0 21:34 pts/3    00:00:03 vi init_service_spec.rb
 PS
     @status = double("Status", :exitstatus => 0, :stdout => @stdout)
-    @provider.stub(:shell_out!).and_return(@status)
+    allow(@provider).to receive(:shell_out!).and_return(@status)
   end
 
   it "should create a current resource with the name of the new resource" do
     @provider.load_current_resource
-    @provider.current_resource.should equal(@current_resource)
+    expect(@provider.current_resource).to equal(@current_resource)
   end
 
   it "should set the current resources service name to the new resources service name" do
     @provider.load_current_resource
-    @current_resource.service_name.should == 'chef'
+    expect(@current_resource.service_name).to eq('chef')
   end
 
   describe "when the service supports status" do
@@ -57,37 +57,37 @@ PS
     end
 
     it "should run '/etc/init.d/service_name status'" do
-      @provider.should_receive(:shell_out).with("/etc/init.d/#{@current_resource.service_name} status").and_return(@status)
+      expect(@provider).to receive(:shell_out).with("/etc/init.d/#{@current_resource.service_name} status").and_return(@status)
       @provider.load_current_resource
     end
 
     it "should set running to true if the status command returns 0" do
-      @provider.stub(:shell_out).with("/etc/init.d/#{@current_resource.service_name} status").and_return(@status)
+      allow(@provider).to receive(:shell_out).with("/etc/init.d/#{@current_resource.service_name} status").and_return(@status)
       @provider.load_current_resource
-      @current_resource.running.should be_true
+      expect(@current_resource.running).to be_truthy
     end
 
     it "should set running to false if the status command returns anything except 0" do
-      @status.stub(:exitstatus).and_return(1)
-      @provider.stub(:shell_out).with("/etc/init.d/#{@current_resource.service_name} status").and_return(@status)
+      allow(@status).to receive(:exitstatus).and_return(1)
+      allow(@provider).to receive(:shell_out).with("/etc/init.d/#{@current_resource.service_name} status").and_return(@status)
       @provider.load_current_resource
-      @current_resource.running.should be_false
+      expect(@current_resource.running).to be_falsey
     end
 
     it "should set running to false if the status command raises" do
-      @provider.stub(:shell_out).and_raise(Mixlib::ShellOut::ShellCommandFailed)
+      allow(@provider).to receive(:shell_out).and_raise(Mixlib::ShellOut::ShellCommandFailed)
       @provider.load_current_resource
-      @current_resource.running.should be_false
+      expect(@current_resource.running).to be_falsey
     end
   end
 
   describe "when a status command has been specified" do
     before do
-      @new_resource.stub(:status_command).and_return("/etc/init.d/chefhasmonkeypants status")
+      allow(@new_resource).to receive(:status_command).and_return("/etc/init.d/chefhasmonkeypants status")
     end
 
     it "should run the services status command if one has been specified" do
-      @provider.should_receive(:shell_out).with("/etc/init.d/chefhasmonkeypants status").and_return(@status)
+      expect(@provider).to receive(:shell_out).with("/etc/init.d/chefhasmonkeypants status").and_return(@status)
       @provider.load_current_resource
     end
 
@@ -95,12 +95,12 @@ PS
 
   describe "when an init command has been specified" do
     before do
-      @new_resource.stub(:init_command).and_return("/opt/chef-server/service/erchef")
+      allow(@new_resource).to receive(:init_command).and_return("/opt/chef-server/service/erchef")
       @provider = Chef::Provider::Service::Init.new(@new_resource, @run_context)
     end
 
     it "should use the init_command if one has been specified" do
-      @provider.should_receive(:shell_out!).with("/opt/chef-server/service/erchef start")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/opt/chef-server/service/erchef start")
       @provider.start_service
     end
 
@@ -113,7 +113,7 @@ PS
       @provider.load_current_resource
       @provider.action = :start
       @provider.define_resource_requirements
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
     end
 
     it "should raise an error if the node has an empty ps attribute" do
@@ -121,15 +121,14 @@ PS
       @provider.load_current_resource
       @provider.action = :start
       @provider.define_resource_requirements
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
     end
 
   end
 
-
   describe "when we have a 'ps' attribute" do
     it "should shell_out! the node's ps command" do
-      @provider.should_receive(:shell_out!).and_return(@status)
+      expect(@provider).to receive(:shell_out!).and_return(@status)
       @provider.load_current_resource
     end
 
@@ -138,39 +137,39 @@ PS
 aj        7842  5057  0 21:26 pts/2    00:00:06 chef
 aj        7842  5057  0 21:26 pts/2    00:00:06 poos
 RUNNING_PS
-      @status.stub(:stdout).and_return(@stdout)
+      allow(@status).to receive(:stdout).and_return(@stdout)
       @provider.load_current_resource
-      @current_resource.running.should be_true
+      expect(@current_resource.running).to be_truthy
     end
 
     it "should set running to false if the regex doesn't match" do
-      @provider.stub(:shell_out!).and_return(@status)
+      allow(@provider).to receive(:shell_out!).and_return(@status)
       @provider.load_current_resource
-      @current_resource.running.should be_false
+      expect(@current_resource.running).to be_falsey
     end
 
     it "should raise an exception if ps fails" do
-      @provider.stub(:shell_out!).and_raise(Mixlib::ShellOut::ShellCommandFailed)
+      allow(@provider).to receive(:shell_out!).and_raise(Mixlib::ShellOut::ShellCommandFailed)
       @provider.load_current_resource
       @provider.action = :start
       @provider.define_resource_requirements
-      lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+      expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
     end
   end
 
   it "should return the current resource" do
-    @provider.load_current_resource.should eql(@current_resource)
+    expect(@provider.load_current_resource).to eql(@current_resource)
   end
 
   describe "when starting the service" do
     it "should call the start command if one is specified" do
       @new_resource.start_command("/etc/init.d/chef startyousillysally")
-      @provider.should_receive(:shell_out!).with("/etc/init.d/chef startyousillysally")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/chef startyousillysally")
       @provider.start_service()
     end
 
     it "should call '/etc/init.d/service_name start' if no start command is specified" do
-      @provider.should_receive(:shell_out!).with("/etc/init.d/#{@new_resource.service_name} start")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/#{@new_resource.service_name} start")
       @provider.start_service()
     end
   end
@@ -178,12 +177,12 @@ RUNNING_PS
   describe Chef::Provider::Service::Init, "stop_service" do
     it "should call the stop command if one is specified" do
       @new_resource.stop_command("/etc/init.d/chef itoldyoutostop")
-      @provider.should_receive(:shell_out!).with("/etc/init.d/chef itoldyoutostop")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/chef itoldyoutostop")
       @provider.stop_service()
     end
 
     it "should call '/etc/init.d/service_name stop' if no stop command is specified" do
-      @provider.should_receive(:shell_out!).with("/etc/init.d/#{@new_resource.service_name} stop")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/#{@new_resource.service_name} stop")
       @provider.stop_service()
     end
   end
@@ -191,20 +190,20 @@ RUNNING_PS
   describe "when restarting a service" do
     it "should call 'restart' on the service_name if the resource supports it" do
       @new_resource.supports({:restart => true})
-      @provider.should_receive(:shell_out!).with("/etc/init.d/#{@new_resource.service_name} restart")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/#{@new_resource.service_name} restart")
       @provider.restart_service()
     end
 
     it "should call the restart_command if one has been specified" do
       @new_resource.restart_command("/etc/init.d/chef restartinafire")
-      @provider.should_receive(:shell_out!).with("/etc/init.d/#{@new_resource.service_name} restartinafire")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/#{@new_resource.service_name} restartinafire")
       @provider.restart_service()
     end
 
     it "should just call stop, then start when the resource doesn't support restart and no restart_command is specified" do
-      @provider.should_receive(:stop_service)
-      @provider.should_receive(:sleep).with(1)
-      @provider.should_receive(:start_service)
+      expect(@provider).to receive(:stop_service)
+      expect(@provider).to receive(:sleep).with(1)
+      expect(@provider).to receive(:start_service)
       @provider.restart_service()
     end
   end
@@ -212,13 +211,13 @@ RUNNING_PS
   describe "when reloading a service" do
     it "should call 'reload' on the service if it supports it" do
       @new_resource.supports({:reload => true})
-      @provider.should_receive(:shell_out!).with("/etc/init.d/chef reload")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/chef reload")
       @provider.reload_service()
     end
 
     it "should should run the user specified reload command if one is specified and the service doesn't support reload" do
       @new_resource.reload_command("/etc/init.d/chef lollerpants")
-      @provider.should_receive(:shell_out!).with("/etc/init.d/chef lollerpants")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/chef lollerpants")
       @provider.reload_service()
     end
   end
@@ -226,10 +225,11 @@ RUNNING_PS
   describe "when a custom command has been specified" do
     before do
       @new_resource.start_command("/etc/init.d/chef startyousillysally")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/etc/init.d/chef startyousillysally")
     end
 
     it "should still pass all why run assertions" do
-      lambda { @provider.run_action(:start) }.should_not raise_error
+      expect { @provider.run_action(:start) }.not_to raise_error
     end
   end
 end
