@@ -30,29 +30,29 @@ describe Chef::Provider::Service::Insserv do
 
     @provider = Chef::Provider::Service::Insserv.new(@new_resource, @run_context)
     @status = double("Process::Status mock", :exitstatus => 0, :stdout => "")
-    @provider.stub(:shell_out!).and_return(@status)
+    allow(@provider).to receive(:shell_out!).and_return(@status)
   end
 
   describe "load_current_resource" do
     describe "when startup links exist" do
       before do
-        Dir.stub(:glob).with("/etc/rc**/S*initgrediant").and_return(["/etc/rc5.d/S18initgrediant", "/etc/rc2.d/S18initgrediant", "/etc/rc4.d/S18initgrediant", "/etc/rc3.d/S18initgrediant"])
+        allow(Dir).to receive(:glob).with("/etc/rc**/S*initgrediant").and_return(["/etc/rc5.d/S18initgrediant", "/etc/rc2.d/S18initgrediant", "/etc/rc4.d/S18initgrediant", "/etc/rc3.d/S18initgrediant"])
       end
 
       it "sets the current enabled status to true" do
         @provider.load_current_resource
-        @provider.current_resource.enabled.should be_true
+        expect(@provider.current_resource.enabled).to be_truthy
       end
     end
 
     describe "when startup links do not exist" do
       before do
-        Dir.stub(:glob).with("/etc/rc**/S*initgrediant").and_return([])
+        allow(Dir).to receive(:glob).with("/etc/rc**/S*initgrediant").and_return([])
       end
 
       it "sets the current enabled status to false" do
         @provider.load_current_resource
-        @provider.current_resource.enabled.should be_false
+        expect(@provider.current_resource.enabled).to be_falsey
       end
     end
 
@@ -60,17 +60,16 @@ describe Chef::Provider::Service::Insserv do
 
   describe "enable_service" do
     it "should call insserv and create the default links" do
-      @provider.should_receive(:run_command).with({:command=>"/sbin/insserv -r -f #{@new_resource.service_name}"})
-      @provider.should_receive(:run_command).with({:command=>"/sbin/insserv -d -f #{@new_resource.service_name}"})
+      expect(@provider).to receive(:shell_out!).with("/sbin/insserv -r -f #{@new_resource.service_name}")
+      expect(@provider).to receive(:shell_out!).with("/sbin/insserv -d -f #{@new_resource.service_name}")
       @provider.enable_service
     end
   end
 
   describe "disable_service" do
     it "should call insserv and remove the links" do
-      @provider.should_receive(:run_command).with({:command=>"/sbin/insserv -r -f #{@new_resource.service_name}"})
+      expect(@provider).to receive(:shell_out!).with("/sbin/insserv -r -f #{@new_resource.service_name}")
       @provider.disable_service
     end
   end
 end
-
