@@ -21,22 +21,22 @@ require 'ostruct'
 
 shared_examples_for "define_resource_requirements_common" do
   it "should raise an error if /sbin/chkconfig does not exist" do
-    File.stub(:exists?).with("/sbin/chkconfig").and_return(false)
-    @provider.stub(:shell_out).with("/sbin/service chef status").and_raise(Errno::ENOENT)
-    @provider.stub(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_raise(Errno::ENOENT)
+    allow(File).to receive(:exists?).with("/sbin/chkconfig").and_return(false)
+    allow(@provider).to receive(:shell_out).with("/sbin/service chef status").and_raise(Errno::ENOENT)
+    allow(@provider).to receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_raise(Errno::ENOENT)
     @provider.load_current_resource
     @provider.define_resource_requirements
-    lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+    expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
   end
 
   it "should not raise an error if the service exists but is not added to any runlevels" do
     status = double("Status", :exitstatus => 0, :stdout => "" , :stderr => "")
-    @provider.should_receive(:shell_out).with("/sbin/service chef status").and_return(status)
+    expect(@provider).to receive(:shell_out).with("/sbin/service chef status").and_return(status)
     chkconfig = double("Chkconfig", :exitstatus => 0, :stdout => "", :stderr => "service chef supports chkconfig, but is not referenced in any runlevel (run 'chkconfig --add chef')")
-    @provider.should_receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
+    expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
     @provider.load_current_resource
     @provider.define_resource_requirements
-    lambda { @provider.process_resource_requirements }.should_not raise_error
+    expect { @provider.process_resource_requirements }.not_to raise_error
   end
 end
 
@@ -54,8 +54,8 @@ describe "Chef::Provider::Service::Redhat" do
 
     @provider = Chef::Provider::Service::Redhat.new(@new_resource, @run_context)
     @provider.action = :start
-    Chef::Resource::Service.stub(:new).and_return(@current_resource)
-    File.stub(:exists?).with("/sbin/chkconfig").and_return(true)
+    allow(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
+    allow(File).to receive(:exists?).with("/sbin/chkconfig").and_return(true)
   end
 
   describe "while not in why run mode" do
@@ -66,22 +66,22 @@ describe "Chef::Provider::Service::Redhat" do
     describe "load current resource" do
       it "sets the current enabled status to true if the service is enabled for any run level" do
         status = double("Status", :exitstatus => 0, :stdout => "" , :stderr => "")
-        @provider.should_receive(:shell_out).with("/sbin/service chef status").and_return(status)
+        expect(@provider).to receive(:shell_out).with("/sbin/service chef status").and_return(status)
         chkconfig = double("Chkconfig", :exitstatus => 0, :stdout => "chef    0:off   1:off   2:off   3:off   4:off   5:on  6:off", :stderr => "")
-        @provider.should_receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
-        @provider.instance_variable_get("@service_missing").should be_false
+        expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
+        expect(@provider.instance_variable_get("@service_missing")).to be_falsey
         @provider.load_current_resource
-        @current_resource.enabled.should be_true
+        expect(@current_resource.enabled).to be_truthy
       end
 
       it "sets the current enabled status to false if the regex does not match" do
         status = double("Status", :exitstatus => 0, :stdout => "" , :stderr => "")
-        @provider.should_receive(:shell_out).with("/sbin/service chef status").and_return(status)
+        expect(@provider).to receive(:shell_out).with("/sbin/service chef status").and_return(status)
         chkconfig = double("Chkconfig", :exitstatus => 0, :stdout => "chef    0:off   1:off   2:off   3:off   4:off   5:off   6:off", :stderr => "")
-        @provider.should_receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
-        @provider.instance_variable_get("@service_missing").should be_false
-        @provider.load_current_resource.should eql(@current_resource)
-        @current_resource.enabled.should be_false
+        expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
+        expect(@provider.instance_variable_get("@service_missing")).to be_falsey
+        expect(@provider.load_current_resource).to eql(@current_resource)
+        expect(@current_resource.enabled).to be_falsey
       end
     end
 
@@ -91,9 +91,9 @@ describe "Chef::Provider::Service::Redhat" do
       context "when the service does not exist" do
         before do
           status = double("Status", :exitstatus => 1, :stdout => "", :stderr => "chef: unrecognized service")
-          @provider.should_receive(:shell_out).with("/sbin/service chef status").and_return(status)
+          expect(@provider).to receive(:shell_out).with("/sbin/service chef status").and_return(status)
           chkconfig = double("Chkconfig", :existatus=> 1, :stdout => "", :stderr => "error reading information on service chef: No such file or directory")
-          @provider.should_receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
+          expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
           @provider.load_current_resource
           @provider.define_resource_requirements
         end
@@ -101,14 +101,14 @@ describe "Chef::Provider::Service::Redhat" do
         [ "start", "reload", "restart", "enable" ].each do |action|
           it "should raise an error when the action is #{action}" do
             @provider.action = action
-            lambda { @provider.process_resource_requirements }.should raise_error(Chef::Exceptions::Service)
+            expect { @provider.process_resource_requirements }.to raise_error(Chef::Exceptions::Service)
           end
         end
 
         [ "stop", "disable" ].each do |action|
           it "should not raise an error when the action is #{action}" do
             @provider.action = action
-            lambda { @provider.process_resource_requirements }.should_not raise_error
+            expect { @provider.process_resource_requirements }.not_to raise_error
           end
         end
       end
@@ -129,26 +129,26 @@ describe "Chef::Provider::Service::Redhat" do
 
       it "should not raise an error if the service does not exist" do
         status = double("Status", :exitstatus => 1, :stdout => "", :stderr => "chef: unrecognized service")
-        @provider.should_receive(:shell_out).with("/sbin/service chef status").and_return(status)
+        expect(@provider).to receive(:shell_out).with("/sbin/service chef status").and_return(status)
         chkconfig = double("Chkconfig", :existatus=> 1, :stdout => "", :stderr => "error reading information on service chef: No such file or directory")
-        @provider.should_receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
+        expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig --list chef", :returns => [0,1]).and_return(chkconfig)
         @provider.load_current_resource
         @provider.define_resource_requirements
-        lambda { @provider.process_resource_requirements }.should_not raise_error
+        expect { @provider.process_resource_requirements }.not_to raise_error
       end
     end
   end
 
   describe "enable_service" do
     it "should call chkconfig to add 'service_name'" do
-      @provider.should_receive(:shell_out!).with("/sbin/chkconfig #{@new_resource.service_name} on")
+      expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig #{@new_resource.service_name} on")
       @provider.enable_service
     end
   end
 
   describe "disable_service" do
     it "should call chkconfig to del 'service_name'" do
-      @provider.should_receive(:shell_out!).with("/sbin/chkconfig #{@new_resource.service_name} off")
+      expect(@provider).to receive(:shell_out!).with("/sbin/chkconfig #{@new_resource.service_name} off")
       @provider.disable_service
     end
   end
