@@ -41,22 +41,22 @@ describe Chef::Provider::Service::Upstart do
       @node.automatic_attrs[:platform_version] = '9.04'
       #Chef::Platform.stub(:find_platform_and_version).and_return([ "ubuntu", "9.04" ])
       @provider = Chef::Provider::Service::Upstart.new(@new_resource, @run_context)
-      @provider.instance_variable_get(:@upstart_job_dir).should == "/etc/event.d"
-      @provider.instance_variable_get(:@upstart_conf_suffix).should == ""
+      expect(@provider.instance_variable_get(:@upstart_job_dir)).to eq("/etc/event.d")
+      expect(@provider.instance_variable_get(:@upstart_conf_suffix)).to eq("")
     end
 
     it "should return /etc/init as the upstart job directory when running on Ubuntu 9.10" do
       @node.automatic_attrs[:platform_version] = '9.10'
       @provider = Chef::Provider::Service::Upstart.new(@new_resource, @run_context)
-      @provider.instance_variable_get(:@upstart_job_dir).should == "/etc/init"
-      @provider.instance_variable_get(:@upstart_conf_suffix).should == ".conf"
+      expect(@provider.instance_variable_get(:@upstart_job_dir)).to eq("/etc/init")
+      expect(@provider.instance_variable_get(:@upstart_conf_suffix)).to eq(".conf")
     end
 
     it "should return /etc/init as the upstart job directory by default" do
       @node.automatic_attrs[:platform_version] = '9000'
       @provider = Chef::Provider::Service::Upstart.new(@new_resource, @run_context)
-      @provider.instance_variable_get(:@upstart_job_dir).should == "/etc/init"
-      @provider.instance_variable_get(:@upstart_conf_suffix).should == ".conf"
+      expect(@provider.instance_variable_get(:@upstart_job_dir)).to eq("/etc/init")
+      expect(@provider.instance_variable_get(:@upstart_conf_suffix)).to eq(".conf")
     end
   end
 
@@ -65,31 +65,38 @@ describe Chef::Provider::Service::Upstart do
       @node.automatic_attrs[:command] = {:ps => "ps -ax"}
 
       @current_resource = Chef::Resource::Service.new("rsyslog")
-      Chef::Resource::Service.stub(:new).and_return(@current_resource)
+      allow(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
 
       @status = double("Status", :exitstatus => 0)
-      @provider.stub(:popen4).and_return(@status)
+      allow(@provider).to receive(:popen4).and_return(@status)
       @stdin = StringIO.new
       @stdout = StringIO.new
       @stderr = StringIO.new
       @pid = double("PID")
 
-      ::File.stub(:exists?).and_return(true)
-      ::File.stub(:open).and_return(true)
+      allow(::File).to receive(:exists?).and_return(true)
+      allow(::File).to receive(:open).and_return(true)
     end
 
     it "should create a current resource with the name of the new resource" do
-      Chef::Resource::Service.should_receive(:new).and_return(@current_resource)
+      expect(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
       @provider.load_current_resource
     end
 
     it "should set the current resources service name to the new resources service name" do
-      @current_resource.should_receive(:service_name).with(@new_resource.service_name)
+      expect(@current_resource).to receive(:service_name).with(@new_resource.service_name)
       @provider.load_current_resource
     end
 
+    it "should not change the service name when parameters are specified" do
+      @new_resource.parameters({ "OSD_ID" => "2" })
+      @provider = Chef::Provider::Service::Upstart.new(@new_resource, @run_context)
+      @provider.current_resource = @current_resource
+      expect(@new_resource.service_name).to eq(@current_resource.service_name)
+    end
+
     it "should run '/sbin/status rsyslog'" do
-      @provider.should_receive(:popen4).with("/sbin/status rsyslog").and_return(@status)
+      expect(@provider).to receive(:popen4).with("/sbin/status rsyslog").and_return(@status)
       @provider.load_current_resource
     end
 
@@ -99,128 +106,126 @@ describe Chef::Provider::Service::Upstart do
 
       it "should set running to true if the status command returns 0" do
         @stdout = StringIO.new("rsyslog start/running")
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
         @provider.load_current_resource
-        @current_resource.running.should be_true
+        expect(@current_resource.running).to be_truthy
       end
 
       it "should set running to false if the status command returns anything except 0" do
         @stdout = StringIO.new("rsyslog stop/waiting")
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
         @provider.load_current_resource
-        @current_resource.running.should be_false
+        expect(@current_resource.running).to be_falsey
       end
     end
 
     describe "when the status command uses the old format" do
       it "should set running to true if the status command returns 0" do
         @stdout = StringIO.new("rsyslog (start) running, process 32225")
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
         @provider.load_current_resource
-        @current_resource.running.should be_true
+        expect(@current_resource.running).to be_truthy
       end
 
       it "should set running to false if the status command returns anything except 0" do
         @stdout = StringIO.new("rsyslog (stop) waiting")
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
         @provider.load_current_resource
-        @current_resource.running.should be_false
+        expect(@current_resource.running).to be_falsey
       end
     end
 
     it "should set running to false if it catches a Chef::Exceptions::Exec" do
-      @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_raise(Chef::Exceptions::Exec)
-      @current_resource.should_receive(:running).with(false)
+      allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_raise(Chef::Exceptions::Exec)
+      expect(@current_resource).to receive(:running).with(false)
       @provider.load_current_resource
     end
 
     it "should set enabled to true when it finds 'starts on'" do
       @lines = double("start on filesystem", :gets => "start on filesystem")
-      ::File.stub(:open).and_yield(@lines)
-      @current_resource.should_receive(:running).with(false)
+      allow(::File).to receive(:open).and_yield(@lines)
+      expect(@current_resource).to receive(:running).with(false)
       @provider.load_current_resource
     end
 
     it "should set enabled to false when it finds '#starts on'" do
       @lines = double("start on filesystem", :gets => "#start on filesystem")
-      ::File.stub(:open).and_yield(@lines)
-      @current_resource.should_receive(:running).with(false)
+      allow(::File).to receive(:open).and_yield(@lines)
+      expect(@current_resource).to receive(:running).with(false)
       @provider.load_current_resource
     end
 
     it "should assume disable when no job configuration file is found" do
-      ::File.stub(:exists?).and_return(false)
-      @current_resource.should_receive(:running).with(false)
+      allow(::File).to receive(:exists?).and_return(false)
+      expect(@current_resource).to receive(:running).with(false)
       @provider.load_current_resource
     end
 
-
     it "should track state when the upstart configuration file fails to load" do
-      File.should_receive(:exists?).and_return false
+      expect(File).to receive(:exists?).and_return false
       @provider.load_current_resource
-      @provider.instance_variable_get("@config_file_found").should == false
+      expect(@provider.instance_variable_get("@config_file_found")).to eq(false)
     end
 
     describe "when a status command has been specified" do
       before do
-        @new_resource.stub(:status_command).and_return("/bin/chefhasmonkeypants status")
+        allow(@new_resource).to receive(:status_command).and_return("/bin/chefhasmonkeypants status")
       end
 
       it "should run the services status command if one has been specified" do
-        @provider.stub(:run_command_with_systems_locale).with({:command => "/bin/chefhasmonkeypants status"}).and_return(0)
-        @current_resource.should_receive(:running).with(true)
+        allow(@provider).to receive(:shell_out!).with("/bin/chefhasmonkeypants status").and_return(0)
+        expect(@current_resource).to receive(:running).with(true)
         @provider.load_current_resource
       end
 
       it "should track state when the user-provided status command fails" do
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_raise(Chef::Exceptions::Exec)
+        allow(@provider).to receive(:shell_out!).and_raise(Errno::ENOENT)
         @provider.load_current_resource
-        @provider.instance_variable_get("@command_success").should == false
+        expect(@provider.instance_variable_get("@command_success")).to eq(false)
       end
 
       it "should set running to false if it catches a Chef::Exceptions::Exec when using a status command" do
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_raise(Chef::Exceptions::Exec)
-        @current_resource.should_receive(:running).with(false)
+        allow(@provider).to receive(:shell_out!).and_raise(Errno::ENOENT)
+        expect(@current_resource).to receive(:running).with(false)
         @provider.load_current_resource
       end
     end
 
     it "should track state when we fail to obtain service status via upstart_state" do
-      @provider.should_receive(:upstart_state).and_raise Chef::Exceptions::Exec
+      expect(@provider).to receive(:upstart_state).and_raise Chef::Exceptions::Exec
       @provider.load_current_resource
-      @provider.instance_variable_get("@command_success").should == false
+      expect(@provider.instance_variable_get("@command_success")).to eq(false)
     end
 
     it "should return the current resource" do
-      @provider.load_current_resource.should eql(@current_resource)
+      expect(@provider.load_current_resource).to eql(@current_resource)
     end
 
-
   end
 
   describe "enable and disable service" do
     before(:each) do
       @current_resource = Chef::Resource::Service.new('rsyslog')
-      Chef::Resource::Service.stub(:new).and_return(@current_resource)
+      allow(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
       @provider.current_resource = @current_resource
-      Chef::Util::FileEdit.stub(:new)
+      allow(Chef::Util::FileEdit).to receive(:new)
     end
 
     it "should enable the service if it is not enabled" do
       @file = Object.new
-      Chef::Util::FileEdit.stub(:new).and_return(@file)
-      @current_resource.stub(:enabled).and_return(false)
-      @file.should_receive(:search_file_replace)
-      @file.should_receive(:write_file)
+      allow(Chef::Util::FileEdit).to receive(:new).and_return(@file)
+      allow(@current_resource).to receive(:enabled).and_return(false)
+      expect(@file).to receive(:search_file_replace)
+      expect(@file).to receive(:write_file)
       @provider.enable_service()
     end
 
     it "should disable the service if it is enabled" do
       @file = Object.new
-      Chef::Util::FileEdit.stub(:new).and_return(@file)
-      @current_resource.stub(:enabled).and_return(true)
-      @file.should_receive(:search_file_replace)
-      @file.should_receive(:write_file)
+      allow(Chef::Util::FileEdit).to receive(:new).and_return(@file)
+      allow(@current_resource).to receive(:enabled).and_return(true)
+      expect(@file).to receive(:search_file_replace)
+      expect(@file).to receive(:write_file)
       @provider.disable_service()
     end
 
@@ -230,24 +235,24 @@ describe Chef::Provider::Service::Upstart do
     before(:each) do
       @current_resource = Chef::Resource::Service.new('rsyslog')
 
-      Chef::Resource::Service.stub(:new).and_return(@current_resource)
+      allow(Chef::Resource::Service).to receive(:new).and_return(@current_resource)
       @provider.current_resource = @current_resource
     end
 
     it "should call the start command if one is specified" do
-      @new_resource.stub(:start_command).and_return("/sbin/rsyslog startyousillysally")
-      @provider.should_receive(:shell_out!).with("/sbin/rsyslog startyousillysally")
+      allow(@new_resource).to receive(:start_command).and_return("/sbin/rsyslog startyousillysally")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/rsyslog startyousillysally")
       @provider.start_service()
     end
 
     it "should call '/sbin/start service_name' if no start command is specified" do
-      @provider.should_receive(:run_command_with_systems_locale).with({:command => "/sbin/start #{@new_resource.service_name}"}).and_return(0)
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/start #{@new_resource.service_name}").and_return(0)
       @provider.start_service()
     end
 
     it "should not call '/sbin/start service_name' if it is already running" do
-      @current_resource.stub(:running).and_return(true)
-      @provider.should_not_receive(:run_command_with_systems_locale).with({:command => "/sbin/start #{@new_resource.service_name}"})
+      allow(@current_resource).to receive(:running).and_return(true)
+      expect(@provider).not_to receive(:shell_out_with_systems_locale!)
       @provider.start_service()
     end
 
@@ -256,58 +261,58 @@ describe Chef::Provider::Service::Upstart do
       @new_resource.parameters({ "OSD_ID" => "2" })
       @provider = Chef::Provider::Service::Upstart.new(@new_resource, @run_context)
       @provider.current_resource = @current_resource
-      @provider.should_receive(:run_command_with_systems_locale).with({:command => "/sbin/start rsyslog OSD_ID=2"}).and_return(0)
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/start rsyslog OSD_ID=2").and_return(0)
       @provider.start_service()
     end
 
     it "should call the restart command if one is specified" do
-      @current_resource.stub(:running).and_return(true)
-      @new_resource.stub(:restart_command).and_return("/sbin/rsyslog restartyousillysally")
-      @provider.should_receive(:shell_out!).with("/sbin/rsyslog restartyousillysally")
+      allow(@current_resource).to receive(:running).and_return(true)
+      allow(@new_resource).to receive(:restart_command).and_return("/sbin/rsyslog restartyousillysally")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/rsyslog restartyousillysally")
       @provider.restart_service()
     end
 
     it "should call '/sbin/restart service_name' if no restart command is specified" do
-      @current_resource.stub(:running).and_return(true)
-      @provider.should_receive(:run_command_with_systems_locale).with({:command => "/sbin/restart #{@new_resource.service_name}"}).and_return(0)
+      allow(@current_resource).to receive(:running).and_return(true)
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/restart #{@new_resource.service_name}").and_return(0)
       @provider.restart_service()
     end
 
     it "should call '/sbin/start service_name' if restart_service is called for a stopped service" do
-      @current_resource.stub(:running).and_return(false)
-      @provider.should_receive(:run_command_with_systems_locale).with({:command => "/sbin/start #{@new_resource.service_name}"}).and_return(0)
+      allow(@current_resource).to receive(:running).and_return(false)
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/start #{@new_resource.service_name}").and_return(0)
       @provider.restart_service()
     end
 
     it "should call the reload command if one is specified" do
-      @current_resource.stub(:running).and_return(true)
-      @new_resource.stub(:reload_command).and_return("/sbin/rsyslog reloadyousillysally")
-      @provider.should_receive(:shell_out!).with("/sbin/rsyslog reloadyousillysally")
+      allow(@current_resource).to receive(:running).and_return(true)
+      allow(@new_resource).to receive(:reload_command).and_return("/sbin/rsyslog reloadyousillysally")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/rsyslog reloadyousillysally")
       @provider.reload_service()
     end
 
     it "should call '/sbin/reload service_name' if no reload command is specified" do
-      @current_resource.stub(:running).and_return(true)
-      @provider.should_receive(:run_command_with_systems_locale).with({:command => "/sbin/reload #{@new_resource.service_name}"}).and_return(0)
+      allow(@current_resource).to receive(:running).and_return(true)
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/reload #{@new_resource.service_name}").and_return(0)
       @provider.reload_service()
     end
 
     it "should call the stop command if one is specified" do
-      @current_resource.stub(:running).and_return(true)
-      @new_resource.stub(:stop_command).and_return("/sbin/rsyslog stopyousillysally")
-      @provider.should_receive(:shell_out!).with("/sbin/rsyslog stopyousillysally")
+      allow(@current_resource).to receive(:running).and_return(true)
+      allow(@new_resource).to receive(:stop_command).and_return("/sbin/rsyslog stopyousillysally")
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/rsyslog stopyousillysally")
       @provider.stop_service()
     end
 
     it "should call '/sbin/stop service_name' if no stop command is specified" do
-      @current_resource.stub(:running).and_return(true)
-      @provider.should_receive(:run_command_with_systems_locale).with({:command => "/sbin/stop #{@new_resource.service_name}"}).and_return(0)
+      allow(@current_resource).to receive(:running).and_return(true)
+      expect(@provider).to receive(:shell_out_with_systems_locale!).with("/sbin/stop #{@new_resource.service_name}").and_return(0)
       @provider.stop_service()
     end
 
     it "should not call '/sbin/stop service_name' if it is already stopped" do
-      @current_resource.stub(:running).and_return(false)
-      @provider.should_not_receive(:run_command_with_systems_locale).with({:command => "/sbin/stop #{@new_resource.service_name}"})
+      allow(@current_resource).to receive(:running).and_return(false)
+      expect(@provider).not_to receive(:shell_out_with_systems_locale!).with("/sbin/stop #{@new_resource.service_name}")
       @provider.stop_service()
     end
   end
