@@ -39,7 +39,7 @@ describe Chef::Provider::Template do
 
   let(:provider) do
     provider = described_class.new(resource, run_context)
-    provider.stub(:content).and_return(content)
+    allow(provider).to receive(:content).and_return(content)
     provider
   end
 
@@ -51,7 +51,7 @@ describe Chef::Provider::Template do
 
   let(:content) do
     content = double('Chef::Provider::File::Content::Template', :template_location => "/foo/bar/baz")
-    File.stub(:exists?).with("/foo/bar/baz").and_return(true)
+    allow(File).to receive(:exists?).with("/foo/bar/baz").and_return(true)
     content
   end
 
@@ -73,15 +73,15 @@ describe Chef::Provider::Template do
 
     let(:provider) do
       provider = described_class.new(resource, run_context)
-      provider.stub(:content).and_return(content)
+      allow(provider).to receive(:content).and_return(content)
       provider
     end
 
     it "stops executing when the local template source can't be found" do
       setup_normal_file
-      content.stub(:template_location).and_return("/baz/bar/foo")
-      File.stub(:exists?).with("/baz/bar/foo").and_return(false)
-      lambda { provider.run_action(:create) }.should raise_error Chef::Mixin::WhyRun::ResourceRequirements::Assertion::AssertionFailure
+      allow(content).to receive(:template_location).and_return("/baz/bar/foo")
+      allow(File).to receive(:exists?).with("/baz/bar/foo").and_return(false)
+      expect { provider.run_action(:create) }.to raise_error Chef::Mixin::WhyRun::ResourceRequirements::Assertion::AssertionFailure
     end
 
   end
