@@ -56,64 +56,64 @@ describe Chef::Provider::User::Pw do
     }
     field_list.each do |attribute, option|
       it "should check for differences in #{attribute} between the new and current resources" do
-        @current_resource.should_receive(attribute)
-        @new_resource.should_receive(attribute)
+        expect(@current_resource).to receive(attribute)
+        expect(@new_resource).to receive(attribute)
         @provider.set_options
       end
 
       it "should set the option for #{attribute} if the new resources #{attribute} is not null" do
-        @new_resource.stub(attribute).and_return("hola")
-        @provider.set_options.should eql(" #{@new_resource.username} #{option} '#{@new_resource.send(attribute)}' -m")
+        allow(@new_resource).to receive(attribute).and_return("hola")
+        expect(@provider.set_options).to eql(" #{@new_resource.username} #{option} '#{@new_resource.send(attribute)}' -m")
       end
 
       it "should set the option for #{attribute} if the new resources #{attribute} is not null, without homedir management" do
-        @new_resource.stub(:supports).and_return({:manage_home => false})
-        @new_resource.stub(attribute).and_return("hola")
-        @provider.set_options.should eql(" #{@new_resource.username} #{option} '#{@new_resource.send(attribute)}'")
+        allow(@new_resource).to receive(:supports).and_return({:manage_home => false})
+        allow(@new_resource).to receive(attribute).and_return("hola")
+        expect(@provider.set_options).to eql(" #{@new_resource.username} #{option} '#{@new_resource.send(attribute)}'")
       end
     end
 
     it "should combine all the possible options" do
       match_string = " adam"
       field_list.sort{ |a,b| a[0] <=> b[0] }.each do |attribute, option|
-        @new_resource.stub(attribute).and_return("hola")
+        allow(@new_resource).to receive(attribute).and_return("hola")
         match_string << " #{option} 'hola'"
       end
       match_string << " -m"
-      @provider.set_options.should eql(match_string)
+      expect(@provider.set_options).to eql(match_string)
     end
   end
 
   describe "create_user" do
     before(:each) do
-      @provider.stub(:run_command).and_return(true)
-      @provider.stub(:modify_password).and_return(true)
+      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:modify_password).and_return(true)
     end
 
     it "should run pw useradd with the return of set_options" do
-      @provider.should_receive(:run_command).with({ :command => "pw useradd adam -m" }).and_return(true)
+      expect(@provider).to receive(:run_command).with({ :command => "pw useradd adam -m" }).and_return(true)
       @provider.create_user
     end
 
     it "should modify the password" do
-      @provider.should_receive(:modify_password).and_return(true)
+      expect(@provider).to receive(:modify_password).and_return(true)
       @provider.create_user
     end
   end
 
   describe "manage_user" do
     before(:each) do
-      @provider.stub(:run_command).and_return(true)
-      @provider.stub(:modify_password).and_return(true)
+      allow(@provider).to receive(:run_command).and_return(true)
+      allow(@provider).to receive(:modify_password).and_return(true)
     end
 
     it "should run pw usermod with the return of set_options" do
-      @provider.should_receive(:run_command).with({ :command => "pw usermod adam -m" }).and_return(true)
+      expect(@provider).to receive(:run_command).with({ :command => "pw usermod adam -m" }).and_return(true)
       @provider.manage_user
     end
 
     it "should modify the password" do
-      @provider.should_receive(:modify_password).and_return(true)
+      expect(@provider).to receive(:modify_password).and_return(true)
       @provider.create_user
     end
   end
@@ -121,38 +121,38 @@ describe Chef::Provider::User::Pw do
   describe "remove_user" do
     it "should run pw userdel with the new resources user name" do
       @new_resource.supports :manage_home => false
-      @provider.should_receive(:run_command).with({ :command => "pw userdel #{@new_resource.username}" }).and_return(true)
+      expect(@provider).to receive(:run_command).with({ :command => "pw userdel #{@new_resource.username}" }).and_return(true)
       @provider.remove_user
     end
 
     it "should run pw userdel with the new resources user name and -r if manage_home is true" do
-      @provider.should_receive(:run_command).with({ :command => "pw userdel #{@new_resource.username} -r"}).and_return(true)
+      expect(@provider).to receive(:run_command).with({ :command => "pw userdel #{@new_resource.username} -r"}).and_return(true)
       @provider.remove_user
     end
   end
 
   describe "determining if the user is locked" do
     it "should return true if user is locked" do
-      @current_resource.stub(:password).and_return("*LOCKED*abracadabra")
-      @provider.check_lock.should eql(true)
+      allow(@current_resource).to receive(:password).and_return("*LOCKED*abracadabra")
+      expect(@provider.check_lock).to eql(true)
     end
 
     it "should return false if user is not locked" do
-      @current_resource.stub(:password).and_return("abracadabra")
-      @provider.check_lock.should eql(false)
+      allow(@current_resource).to receive(:password).and_return("abracadabra")
+      expect(@provider.check_lock).to eql(false)
     end
   end
 
   describe "when locking the user" do
     it "should run pw lock with the new resources username" do
-      @provider.should_receive(:run_command).with({ :command => "pw lock #{@new_resource.username}"})
+      expect(@provider).to receive(:run_command).with({ :command => "pw lock #{@new_resource.username}"})
       @provider.lock_user
     end
   end
 
   describe "when unlocking the user" do
     it "should run pw unlock with the new resources username" do
-      @provider.should_receive(:run_command).with({ :command => "pw unlock #{@new_resource.username}"})
+      expect(@provider).to receive(:run_command).with({ :command => "pw unlock #{@new_resource.username}"})
       @provider.unlock_user
     end
   end
@@ -160,59 +160,76 @@ describe Chef::Provider::User::Pw do
   describe "when modifying the password" do
     before(:each) do
       @status = double("Status", :exitstatus => 0)
-      @provider.stub(:popen4).and_return(@status)
+      allow(@provider).to receive(:popen4).and_return(@status)
       @pid, @stdin, @stdout, @stderr = nil, nil, nil, nil
     end
 
-    it "should check for differences in password between the new and current resources" do
-      @current_resource.should_receive(:password)
-      @new_resource.should_receive(:password)
-      @provider.modify_password
+    describe "and the new password has not been specified" do
+      before(:each) do
+        allow(@new_resource).to receive(:password).and_return(nil)
+      end
+
+      it "logs an appropriate message" do
+        expect(Chef::Log).to receive(:debug).with("user[adam] no change needed to password")
+        @provider.modify_password
+      end
+    end
+
+    describe "and the new password has been specified" do
+      before(:each) do
+        allow(@new_resource).to receive(:password).and_return("abracadabra")
+      end
+
+      it "should check for differences in password between the new and current resources" do
+        expect(@current_resource).to receive(:password)
+        expect(@new_resource).to receive(:password)
+        @provider.modify_password
+      end
     end
 
     describe "and the passwords are identical" do
       before(:each) do
-        @new_resource.stub(:password).and_return("abracadabra")
-        @current_resource.stub(:password).and_return("abracadabra")
+        allow(@new_resource).to receive(:password).and_return("abracadabra")
+        allow(@current_resource).to receive(:password).and_return("abracadabra")
       end
 
       it "logs an appropriate message" do
-        Chef::Log.should_receive(:debug).with("user[adam] no change needed to password")
+        expect(Chef::Log).to receive(:debug).with("user[adam] no change needed to password")
         @provider.modify_password
       end
     end
 
     describe "and the passwords are different" do
       before(:each) do
-        @new_resource.stub(:password).and_return("abracadabra")
-        @current_resource.stub(:password).and_return("sesame")
+        allow(@new_resource).to receive(:password).and_return("abracadabra")
+        allow(@current_resource).to receive(:password).and_return("sesame")
       end
 
       it "should log an appropriate message" do
-        Chef::Log.should_receive(:debug).with("user[adam] updating password")
+        expect(Chef::Log).to receive(:debug).with("user[adam] updating password")
         @provider.modify_password
       end
 
       it "should run pw usermod with the username and the option -H 0" do
-        @provider.should_receive(:popen4).with("pw usermod adam -H 0", :waitlast => true).and_return(@status)
+        expect(@provider).to receive(:popen4).with("pw usermod adam -H 0", :waitlast => true).and_return(@status)
         @provider.modify_password
       end
 
       it "should send the new password to the stdin of pw usermod" do
         @stdin = StringIO.new
-        @provider.stub(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
+        allow(@provider).to receive(:popen4).and_yield(@pid, @stdin, @stdout, @stderr).and_return(@status)
         @provider.modify_password
-        @stdin.string.should == "abracadabra\n"
+        expect(@stdin.string).to eq("abracadabra\n")
       end
 
       it "should raise an exception if pw usermod fails" do
-        @status.should_receive(:exitstatus).and_return(1)
-        lambda { @provider.modify_password }.should raise_error(Chef::Exceptions::User)
+        expect(@status).to receive(:exitstatus).and_return(1)
+        expect { @provider.modify_password }.to raise_error(Chef::Exceptions::User)
       end
 
       it "should not raise an exception if pw usermod succeeds" do
-        @status.should_receive(:exitstatus).and_return(0)
-        lambda { @provider.modify_password }.should_not raise_error
+        expect(@status).to receive(:exitstatus).and_return(0)
+        expect { @provider.modify_password }.not_to raise_error
       end
     end
   end
@@ -223,13 +240,13 @@ describe Chef::Provider::User::Pw do
     end
 
     it "should raise an error if the required binary /usr/sbin/pw doesn't exist" do
-      File.should_receive(:exists?).with("/usr/sbin/pw").and_return(false)
-      lambda { @provider.load_current_resource }.should raise_error(Chef::Exceptions::User)
+      expect(File).to receive(:exists?).with("/usr/sbin/pw").and_return(false)
+      expect { @provider.load_current_resource }.to raise_error(Chef::Exceptions::User)
     end
 
     it "shouldn't raise an error if /usr/sbin/pw exists" do
-      File.stub(:exists?).and_return(true)
-      lambda { @provider.load_current_resource }.should_not raise_error
+      allow(File).to receive(:exists?).and_return(true)
+      expect { @provider.load_current_resource }.not_to raise_error
     end
   end
 end
