@@ -27,7 +27,7 @@ describe Chef::Provider::User::Solaris do
     p.current_resource = @current_resource
 
     # Prevent the useradd-based provider tests from trying to write /etc/shadow
-    p.stub(:write_shadow_file)
+    allow(p).to receive(:write_shadow_file)
     p
   end
 
@@ -51,28 +51,28 @@ describe Chef::Provider::User::Solaris do
 
       @new_resource.password "hocus-pocus"
 
-      # Let these tests run #write_shadow_file
-      provider.unstub(:write_shadow_file)
     end
 
     it "should use its own shadow file writer to set the password" do
-      provider.should_receive(:write_shadow_file)
-      provider.stub(:shell_out!).and_return(true)
+      expect(provider).to receive(:write_shadow_file)
+      allow(provider).to receive(:shell_out!).and_return(true)
       provider.manage_user
     end
 
     it "should write out a modified version of the password file" do
+      # Let this test run #write_shadow_file
+      allow(provider).to receive(:write_shadow_file).and_call_original
       password_file = Tempfile.new("shadow")
       password_file.puts "adam:existingpassword:15441::::::"
       password_file.close
       provider.password_file = password_file.path
-      provider.stub(:shell_out!).and_return(true)
+      allow(provider).to receive(:shell_out!).and_return(true)
       # may not be able to write to /etc for tests...
       temp_file = Tempfile.new("shadow")
-      Tempfile.stub(:new).with("shadow", "/etc").and_return(temp_file)
+      allow(Tempfile).to receive(:new).with("shadow", "/etc").and_return(temp_file)
       @new_resource.password "verysecurepassword"
       provider.manage_user
-      ::File.open(password_file.path, "r").read.should =~ /adam:verysecurepassword:/
+      expect(::File.open(password_file.path, "r").read).to match(/adam:verysecurepassword:/)
       password_file.unlink
     end
   end
