@@ -19,6 +19,7 @@
 #
 
 require 'spec_helper'
+require 'chef/provider/user/useradd'
 
 describe Chef::Provider::User::Useradd do
 
@@ -37,4 +38,14 @@ describe Chef::Provider::User::Useradd do
   }
 
   include_examples "a useradd-based user provider", supported_useradd_options
+
+  describe "manage_user" do
+    # CHEF-5247: Chef::Provider::User::Solaris subclasses Chef::Provider::User::Useradd, but does not use usermod to change passwords.
+    # Thus, a call to Solaris#manage_user calls Solaris#manage_password and Useradd#manage_user, but the latter should be a no-op.
+    it "should not run the command if universal_options is an empty array" do
+      allow(provider).to receive(:universal_options).and_return([])
+      expect(provider).not_to receive(:shell_out!)
+      provider.manage_user
+    end
+  end
 end
