@@ -26,45 +26,45 @@ describe Chef::Resource::ErlCall do
   end
 
   it "should create a new Chef::Resource::ErlCall" do
-    @resource.should be_a_kind_of(Chef::Resource)
-    @resource.should be_a_kind_of(Chef::Resource::ErlCall)
+    expect(@resource).to be_a_kind_of(Chef::Resource)
+    expect(@resource).to be_a_kind_of(Chef::Resource::ErlCall)
   end
 
   it "should have a resource name of :erl_call" do
-    @resource.resource_name.should eql(:erl_call)
+    expect(@resource.resource_name).to eql(:erl_call)
   end
 
   it "should have a default action of run" do
-    @resource.action.should eql("run")
+    expect(@resource.action).to eql("run")
   end
 
   it "should accept run as an action" do
-    lambda { @resource.action :run }.should_not raise_error
+    expect { @resource.action :run }.not_to raise_error
   end
 
   it "should allow you to set the code attribute" do
     @resource.code "q()."
-    @resource.code.should eql("q().")
+    expect(@resource.code).to eql("q().")
   end
 
   it "should allow you to set the cookie attribute" do
     @resource.cookie "nomnomnom"
-    @resource.cookie.should eql("nomnomnom")
+    expect(@resource.cookie).to eql("nomnomnom")
   end
 
   it "should allow you to set the distributed attribute" do
     @resource.distributed true
-    @resource.distributed.should eql(true)
+    expect(@resource.distributed).to eql(true)
   end
 
   it "should allow you to set the name_type attribute" do
     @resource.name_type "sname"
-    @resource.name_type.should eql("sname")
+    expect(@resource.name_type).to eql("sname")
   end
 
   it "should allow you to set the node_name attribute" do
     @resource.node_name "chef@erlang"
-    @resource.node_name.should eql("chef@erlang")
+    expect(@resource.node_name).to eql("chef@erlang")
   end
 
   describe "when it has cookie and node_name" do
@@ -75,7 +75,7 @@ describe Chef::Resource::ErlCall do
     end
 
     it "returns the code as its identity" do
-      @resource.identity.should == "erl-call:function()"
+      expect(@resource.identity).to eq("erl-call:function()")
     end
   end
 end
