@@ -17,30 +17,34 @@
 #
 
 require 'spec_helper'
+require 'support/shared/unit/resource/static_provider_resolution'
 
 describe Chef::Resource::Git do
 
+  static_provider_resolution(
+    resource: Chef::Resource::Git,
+    provider: Chef::Provider::Git,
+    name: :git,
+    action: :sync,
+  )
+
   before(:each) do
     @git = Chef::Resource::Git.new("my awesome webapp")
   end
 
   it "is a kind of Scm Resource" do
-    @git.should be_a_kind_of(Chef::Resource::Scm)
-    @git.should be_an_instance_of(Chef::Resource::Git)
-  end
-
-  it "uses the git provider" do
-    @git.provider.should eql(Chef::Provider::Git)
+    expect(@git).to be_a_kind_of(Chef::Resource::Scm)
+    expect(@git).to be_an_instance_of(Chef::Resource::Git)
   end
 
   it "uses aliases revision as branch" do
     @git.branch "HEAD"
-    @git.revision.should eql("HEAD")
+    expect(@git.revision).to eql("HEAD")
   end
 
   it "aliases revision as reference" do
     @git.reference "v1.0 tag"
-    @git.revision.should eql("v1.0 tag")
+    expect(@git.revision).to eql("v1.0 tag")
   end
 
 end
