@@ -17,22 +17,16 @@
 #
 
 require 'spec_helper'
+require 'support/shared/unit/resource/static_provider_resolution'
 
 describe Chef::Resource::PacmanPackage, "initialize" do
 
-  before(:each) do
-    @resource = Chef::Resource::PacmanPackage.new("foo")
-  end
+  static_provider_resolution(
+    resource: Chef::Resource::PacmanPackage,
+    provider: Chef::Provider::Package::Pacman,
+    name: :pacman_package,
+    action: :install,
+    os: "linux",
+  )
 
-  it "should return a Chef::Resource::PacmanPackage" do
-    @resource.should be_a_kind_of(Chef::Resource::PacmanPackage)
-  end
-
-  it "should set the resource_name to :pacman_package" do
-    @resource.resource_name.should eql(:pacman_package)
-  end
-
-  it "should set the provider to Chef::Provider::Package::Pacman" do
-    @resource.provider.should eql(Chef::Provider::Package::Pacman)
-  end
 end
