@@ -19,24 +19,22 @@
 require 'spec_helper'
 
 describe Chef::ResourceDefinition do
-  before(:each) do
-    @def = Chef::ResourceDefinition.new()
-  end
+  let(:defn) { Chef::ResourceDefinition.new() }
 
   describe "initialize" do
     it "should be a Chef::ResourceDefinition" do
-      @def.should be_a_kind_of(Chef::ResourceDefinition)
+      expect(defn).to be_a_kind_of(Chef::ResourceDefinition)
     end
 
     it "should not initialize a new node if one is not provided" do
-      @def.node.should eql(nil)
+      expect(defn.node).to eql(nil)
     end
 
     it "should accept a node as an argument" do
       node = Chef::Node.new
       node.name("bobo")
-      @def = Chef::ResourceDefinition.new(node)
-      @def.node.name.should == "bobo"
+      defn = Chef::ResourceDefinition.new(node)
+      expect(defn.node.name).to eq("bobo")
     end
   end
 
@@ -44,76 +42,76 @@ describe Chef::ResourceDefinition do
     it "should set the node with node=" do
       node = Chef::Node.new
       node.name("bobo")
-      @def.node = node
-      @def.node.name.should == "bobo"
+      defn.node = node
+      expect(defn.node.name).to eq("bobo")
     end
 
     it "should return the node" do
-      @def.node = Chef::Node.new
-      @def.node.should be_a_kind_of(Chef::Node)
+      defn.node = Chef::Node.new
+      expect(defn.node).to be_a_kind_of(Chef::Node)
     end
   end
 
   it "should accept a new definition with a symbol for a name" do
-    lambda {
-      @def.define :smoke do
+    expect {
+      defn.define :smoke do
       end
-    }.should_not raise_error
-    lambda {
-      @def.define "george washington" do
+    }.not_to raise_error
+    expect {
+      defn.define "george washington" do
       end
-    }.should raise_error(ArgumentError)
-    @def.name.should eql(:smoke)
+    }.to raise_error(ArgumentError)
+    expect(defn.name).to eql(:smoke)
   end
 
   it "should accept a new definition with a hash" do
-    lambda {
-      @def.define :smoke, :cigar => "cuban", :cigarette => "marlboro" do
+    expect {
+      defn.define :smoke, :cigar => "cuban", :cigarette => "marlboro" do
       end
-    }.should_not raise_error
+    }.not_to raise_error
   end
 
   it "should expose the prototype hash params in the params hash" do
-    @def.define :smoke, :cigar => "cuban", :cigarette => "marlboro" do; end
-    @def.params[:cigar].should eql("cuban")
-    @def.params[:cigarette].should eql("marlboro")
+    defn.define :smoke, :cigar => "cuban", :cigarette => "marlboro" do; end
+    expect(defn.params[:cigar]).to eql("cuban")
+    expect(defn.params[:cigarette]).to eql("marlboro")
   end
 
   it "should store the block passed to define as a proc under recipe" do
-    @def.define :smoke do
+    defn.define :smoke do
       "I am what I am"
     end
-    @def.recipe.should be_a_kind_of(Proc)
-    @def.recipe.call.should eql("I am what I am")
+    expect(defn.recipe).to be_a_kind_of(Proc)
+    expect(defn.recipe.call).to eql("I am what I am")
   end
 
-  it "should set paramaters based on method_missing" do
-    @def.mind "to fly"
-    @def.params[:mind].should eql("to fly")
+  it "should set parameters based on method_missing" do
+    defn.mind "to fly"
+    expect(defn.params[:mind]).to eql("to fly")
   end
 
   it "should raise an exception if prototype_params is not a hash" do
-    lambda {
-      @def.define :monkey, Array.new do
+    expect {
+      defn.define :monkey, Array.new do
       end
-    }.should raise_error(ArgumentError)
+    }.to raise_error(ArgumentError)
   end
 
   it "should raise an exception if define is called without a block" do
-    lambda {
-      @def.define :monkey
-    }.should raise_error(ArgumentError)
+    expect {
+      defn.define :monkey
+    }.to raise_error(ArgumentError)
   end
 
   it "should load a description from a file" do
-    @def.from_file(File.join(CHEF_SPEC_DATA, "definitions", "test.rb"))
-    @def.name.should eql(:rico_suave)
-    @def.params[:rich].should eql("smooth")
+    defn.from_file(File.join(CHEF_SPEC_DATA, "definitions", "test.rb"))
+    expect(defn.name).to eql(:rico_suave)
+    expect(defn.params[:rich]).to eql("smooth")
   end
 
   it "should turn itself into a string based on the name with to_s" do
-    @def.name = :woot
-    @def.to_s.should eql("woot")
+    defn.name = :woot
+    expect(defn.to_s).to eql("woot")
   end
 
 end
